@@ -28,7 +28,6 @@
 #include <KMessageBox>
 #include <KMenu>
 #include <KRun>
-#include <KAction>
 #include <KHelpMenu>
 #include <KAboutData>
 
@@ -38,7 +37,7 @@
 static QString archiveMailCollectionPattern = QLatin1String( "ArchiveMailCollection \\d+" );
 
 ArchiveMailDialog::ArchiveMailDialog(QWidget *parent)
-    :KDialog(parent)
+    : KDialog(parent)
 {
     setCaption( i18n( "Configure Archive Mail Agent" ) );
     setWindowIcon( KIcon( QLatin1String("kmail") ) );
@@ -63,7 +62,7 @@ ArchiveMailDialog::ArchiveMailDialog(QWidget *parent)
                 QByteArray( KDEPIM_VERSION ),
                 ki18n( "Archive emails automatically." ),
                 KAboutData::License_GPL_V2,
-                ki18n( "Copyright (C) 2012, 2013 Laurent Montel" ) );
+                ki18n( "Copyright (C) 2012, 2013, 2014 Laurent Montel" ) );
 
     mAboutData->addAuthor( ki18n( "Laurent Montel" ),
                          ki18n( "Maintainer" ), "montel@kde.org" );
@@ -401,4 +400,3 @@ void ArchiveMailWidget::slotItemChanged(QTreeWidgetItem *item,int col)
     }
 }
 
-#include "archivemaildialog.moc"
