@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,11 +21,7 @@
 #include <KDialog>
 #include "sendlater_export.h"
 
-class KComboBox;
 class QCheckBox;
-class QSpinBox;
-class QDateTimeEdit;
-class QLabel;
 
 namespace Ui {
 class SendLaterWidget;
@@ -33,7 +29,6 @@ class SendLaterWidget;
 
 namespace SendLater {
 class SendLaterInfo;
-class SendLaterTimeDateWidget;
 class SENDLATER_EXPORT SendLaterDialog : public KDialog
 {
     Q_OBJECT
