@@ -31,22 +31,19 @@
 #include <akonadi/private/notificationmessage_p.h>
 
 #include <KDebug>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
-#include <KStandardDirs>
 #include <KStandardGuiItem>
 #include <KTextEdit>
 #include <KLineEdit>
 
 #include <QtCore/QFile>
 #include <QtCore/QPointer>
-#include <QGridLayout>
 #include <QMenu>
 #include <QPushButton>
 #include <QDBusInterface>
 #include <QDBusMessage>
 #include <QDBusReply>
-#include <QMetaObject>
 #include <QMetaMethod>
 #include <QResizeEvent>
 
@@ -351,7 +348,7 @@ void AgentWidget::cloneAgent( KJob* job )
       continue;
     const QString methodName = QString::fromLatin1( signature.left( signature.indexOf( '(' ) ) );
     const QDBusMessage reply = sourceIface.call( methodName );
-    if ( !reply.arguments().count() == 1 ) {
+    if ( reply.arguments().count() != 1 ) {
       kError() << "call to method" << signature << "failed: " << reply.arguments() << reply.errorMessage();
       continue;
     }
@@ -385,6 +382,9 @@ void AgentWidget::currentChanged()
     case AgentInstance::Broken: agentStatus =
         i18nc( "agent is broken somehow", "Broken" );
       break;
+    case AgentInstance::NotConfigured: agentStatus =
+        i18nc( "agent is not yet configured", "Not Configured" );
+      break;
     }
     ui.statusLabel->setText(
       i18nc( "Two statuses, for example \"Online, Running (66%)\" or \"Offline, Broken\"",
@@ -423,4 +423,3 @@ void AgentWidget::resizeEvent( QResizeEvent *event )
   ui.detailsBox->setVisible( event->size().height() > 400 );
 }
 
-#include "agentwidget.moc"
