@@ -23,7 +23,6 @@
 #include "collectioninternalspage.h"
 #include "collectionaclpage.h"
 #include "dbaccess.h"
-#include "settings.h"
 #include "akonadibrowsermodel.h"
 
 #include <akonadi/attributefactory.h>
@@ -45,6 +44,7 @@
 #include <akonadi/etmviewstatesaver.h>
 #include <akonadi/favoritecollectionsmodel.h>
 #include <akonadi_next/quotacolorproxymodel.h>
+#include <akonadi/tagmodel.h>
 #include <libkdepim/misc/statisticsproxymodel.h>
 #include <kviewstatemaintainer.h>
 
@@ -61,19 +61,12 @@
 #include <KToggleAction>
 #include <KActionCollection>
 
-#include <nepomuk2/resource.h>
-#include <nepomuk2/resourcemanager.h>
-#include <nepomuk2/variant.h>
-
 #include <QSplitter>
-#include <QTextEdit>
 #include <QVBoxLayout>
-#include <QStackedWidget>
-#include <QSortFilterProxyModel>
 #include <QStandardItemModel>
-#include <QSqlError>
 #include <QSqlQuery>
 #include <QTimer>
+#include <QSqlError>
 
 using namespace Akonadi;
 
@@ -86,7 +79,6 @@ Q_DECLARE_METATYPE( QSet<QByteArray> )
 BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget * parent) :
     QWidget( parent ),
     mAttrModel( 0 ),
-    mNepomukModel( 0 ),
     mStdActionManager( 0 ),
     mMonitor( 0 ),
     mCacheOnlyAction( 0 )
@@ -112,6 +104,14 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget * parent) :
 
   splitter->addWidget( splitter2 );
 
+  ChangeRecorder *tagRecorder = new ChangeRecorder( this );
+  tagRecorder->setTypeMonitored( Monitor::Tags );
+  tagRecorder->setChangeRecordingEnabled( false );
+  QTreeView *tagView = new QTreeView( this );
+  TagModel *tagModel = new Akonadi::TagModel( tagRecorder, this );
+  tagView->setModel( tagModel );
+  splitter2->addWidget( tagView );
+
   Session *session = new Session( "AkonadiConsole Browser Widget", this );
 
   // monitor collection changes
@@ -209,8 +209,6 @@ BrowserWidget::BrowserWidget(KXmlGuiWindow *xmlGuiWindow, QWidget * parent) :
   xmlGuiWindow->actionCollection()->addAction( "akonadiconsole_cacheonly", mCacheOnlyAction );
   connect( mCacheOnlyAction, SIGNAL(toggled(bool)), SLOT(updateItemFetchScope()) );
 
-  Nepomuk2::ResourceManager::instance()->init();
-
   m_stateMaintainer = new KViewStateMaintainer<ETMViewStateSaver>( KGlobal::config()->group("CollectionViewState"), this );
   m_stateMaintainer->setView( mCollectionView );
 
@@ -233,6 +231,7 @@ void BrowserWidget::clear()
   contentUi.size->clear();
   contentUi.modificationtime->clear();
   contentUi.flags->clear();
+  contentUi.tags->clear();
   contentUi.attrView->setModel( 0 );
 }
 
@@ -247,6 +246,7 @@ void BrowserWidget::itemActivated(const QModelIndex & index)
   ItemFetchJob *job = new ItemFetchJob( item, this );
   job->fetchScope().fetchFullPayload();
   job->fetchScope().fetchAllAttributes();
+  job->fetchScope().setFetchTags( true );
   connect( job, SIGNAL(result(KJob*)), SLOT(itemFetchDone(KJob*)), Qt::QueuedConnection );
 }
 
@@ -300,6 +300,11 @@ void BrowserWidget::setItem( const Akonadi::Item &item )
     flags << QString::fromUtf8( f );
   contentUi.flags->setItems( flags );
 
+  QStringList tags;
+  foreach ( const Tag &tag, item.tags() )
+    tags << tag.url().url();
+  contentUi.tags->setItems( tags );
+
   Attribute::List list = item.attributes();
   delete mAttrModel;
   mAttrModel = new QStandardItemModel( list.count(), 2 );
@@ -317,40 +322,6 @@ void BrowserWidget::setItem( const Akonadi::Item &item )
   }
   contentUi.attrView->setModel( mAttrModel );
 
-  if ( Settings::self()->nepomukEnabled() ) {
-    Nepomuk2::Resource res( item.url() );
-
-    contentUi.tagWidget->setTaggedResource( res );
-    contentUi.ratingWidget->setRating( int( res.rating() ) );
-
-    delete mNepomukModel;
-    mNepomukModel = 0;
-    if ( res.isValid() ) {
-      contentUi.rdfClassName->setText( res.type().toString().section( QRegExp( "[#:]" ), -1 ) );
-      QHash<QUrl, Nepomuk2::Variant> props = res.properties();
-      mNepomukModel = new QStandardItemModel( props.count(), 2, this );
-      QStringList labels;
-      labels << i18n( "Property" ) << i18n( "Value" );
-      mNepomukModel->setHorizontalHeaderLabels( labels );
-      int row = 0;
-      for ( QHash<QUrl, Nepomuk2::Variant>::ConstIterator it = props.constBegin(); it != props.constEnd(); ++it, ++row ) {
-        QModelIndex index = mNepomukModel->index( row, 0 );
-        Q_ASSERT( index.isValid() );
-        mNepomukModel->setData( index, it.key().toString() );
-        index = mNepomukModel->index( row, 1 );
-        Q_ASSERT( index.isValid() );
-        mNepomukModel->setData( index, it.value().toString() );
-      }
-      contentUi.nepomukView->setEnabled( true );
-    } else {
-      contentUi.nepomukView->setEnabled( false );
-    }
-    contentUi.nepomukView->setModel( mNepomukModel );
-    contentUi.nepomukTab->setEnabled( true );
-  } else {
-    contentUi.nepomukTab->setEnabled( false );
-  }
-
   if ( mMonitor )
     mMonitor->deleteLater(); // might be the one calling us
   mMonitor = new Monitor( this );
@@ -389,6 +360,10 @@ void BrowserWidget::save()
     item.clearFlag( f );
   foreach ( const QString &s, contentUi.flags->items() )
     item.setFlag( s.toUtf8() );
+  foreach ( const Tag &tag, mCurrentItem.tags() )
+    item.clearTag( tag );
+  foreach ( const QString &s, contentUi.tags->items() )
+    item.setTag( Tag::fromUrl( s ) );
   item.setPayloadFromData( data );
 
   item.clearAttributes();
@@ -405,11 +380,6 @@ void BrowserWidget::save()
 
   ItemModifyJob *store = new ItemModifyJob( item, this );
   connect( store, SIGNAL(result(KJob*)), SLOT(saveResult(KJob*)) );
-
-  if ( Settings::self()->nepomukEnabled() ) {
-    Nepomuk2::Resource res( item.url() );
-    res.setRating( contentUi.ratingWidget->rating() );
-  }
 }
 
 void BrowserWidget::saveResult(KJob * job)
@@ -491,4 +461,3 @@ void BrowserWidget::updateItemFetchScope()
   mBrowserMonitor->itemFetchScope().setCacheOnly( mCacheOnlyAction->isChecked() );
 }
 
-#include "browserwidget.moc"
