@@ -35,16 +35,15 @@
 #include <KDateTime>
 #include <KGlobal>
 #include <KIcon>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KUrl>
 #include <KMenu>
 #include <KColorScheme>
+#include <KLocale>
 
 #include <QApplication>
 #include <QContextMenuEvent>
 #include <QHeaderView>
-#include <QKeyEvent>
-#include <QList>
 #include <QMenu>
 #include <QPaintEvent>
 #include <QPalette>
@@ -598,4 +597,3 @@ void ArticleListView::setFilters( const std::vector<shared_ptr<const Filters::Ab
         m_proxy->setFilters( matchers );
 }
 
-#include "articlelistview.moc"
