@@ -63,7 +63,6 @@
 #include <kparts/browserrun.h>
 
 #include <QClipboard>
-#include <QKeySequence>
 #include <QGridLayout>
 
 #include <boost/bind.hpp>
@@ -773,5 +772,4 @@ void ArticleViewer::setArticleActionsEnabled(bool enabled)
 
 } // namespace Akregator
 
-#include "articleviewer.moc"
 
