@@ -31,7 +31,6 @@
 #include <kglobal.h>
 
 #include <QTimer>
-#include <QList>
 
 
 namespace Akregator {
@@ -138,4 +137,3 @@ NotificationManager* NotificationManager::self()
 
 } // namespace Akregator
 
-#include "notificationmanager.moc"
