@@ -32,7 +32,7 @@
 #include <QPointer>
 
 #include <KMenu>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KDebug>
 #include <KConfigGroup>
 
@@ -372,4 +372,3 @@ void Akregator::SubscriptionListView::startNodeRenaming( Akregator::TreeNode* no
     edit( current );
 }
 
-#include "subscriptionlistview.moc"
