@@ -40,7 +40,6 @@
 
 #include <QTableWidget>
 #include <QTimer>
-#include <QTextDocument>
 static const int TIMEOUT = 45000;
 
 class AddEditBlog::Private
@@ -635,4 +634,3 @@ void AddEditBlog::hideWaitWidget()
     d->wait = 0;
 }
 
-#include "addeditblog.moc"
