@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -22,11 +22,9 @@
 #define BLOGILOCOMPOSERWIDGET_H
 
 #include <QWidget>
+#include "pimcommon/widgets/customtoolswidget.h"
 class BlogiloComposerEditor;
 class BlogiloComposerView;
-namespace PimCommon {
-class TranslatorWidget;
-}
 class BlogiloComposerWidget : public QWidget
 {
     Q_OBJECT
@@ -37,11 +35,12 @@ public:
     BlogiloComposerEditor *editor() const;
 
 private Q_SLOTS:
-    void slotActivateTranslator();
+    void slotToolSwitched(PimCommon::CustomToolsWidget::ToolType);
+    void slotInsertShortUrl(const QString &shortUrl);
 
 private:
     BlogiloComposerEditor *mEditor;
-    PimCommon::TranslatorWidget *mTranslatorWidget;
+    PimCommon::CustomToolsWidget *mCustomToolsWidget;
 };
 
 #endif // BLOGILOCOMPOSERWIDGET_H
