@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -40,7 +40,7 @@
 
 
 #include <KToolInvocation>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KToggleAction>
 #include <KAction>
 #include <KSelectAction>
@@ -53,6 +53,7 @@
 #include <KFileDialog>
 #include <KPrintPreview>
 #include <kdeprintdialog.h>
+#include <KRun>
 
 #include <QAction>
 #include <QDBusInterface>
@@ -691,6 +692,14 @@ void ComposerViewPrivate::_k_slotEditLink()
     dlg.exec();
 }
 
+void ComposerViewPrivate::_k_slotOpenLink()
+{
+    const QString href = contextMenuResult.linkElement().attribute(QLatin1String("href"));
+    if (!href.isEmpty()) {
+        new KRun( KUrl(href), 0 );
+    }
+}
+
 void ComposerViewPrivate::_k_setFontSize(int fontSize)
 {
     execCommand(QLatin1String("fontSize"), QString::number(fontSize+1)); //Verify
