@@ -20,7 +20,7 @@
 #include "composercellsizewidget.h"
 
 #include <KComboBox>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KDebug>
 
 #include <QSpinBox>
@@ -167,4 +167,4 @@ void ComposerCellSizeWidget::setLabel(const QString& str)
 
 }
 
-#include "composercellsizewidget.moc"
+#include "moc_composercellsizewidget.cpp"
