@@ -21,7 +21,7 @@
 #include "findreplacebar.h"
 
 #include <KIcon>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KColorScheme>
 #include <KMessageBox>
 
@@ -325,4 +325,4 @@ void FindReplaceBar::showAndFocus()
 }
 
 }
-#include "findreplacebar.moc"
+#include "moc_findreplacebar.cpp"
