@@ -4,6 +4,7 @@
  * KonsoleKalendar is a command line interface to KDE calendars               *
  * Copyright (C) 2002-2004  Tuukka Pasanen <illuusio@mailcity.com>            *
  * Copyright (C) 2003-2009  Allen Winter <winter@kde.org>                     *
+ * Copyright (C) 2013       Sérgio Martins <iamsergio@gmail.com>              *
  *                                                                            *
  * This program is free software; you can redistribute it and/or modify       *
  * it under the terms of the GNU General Public License as published by       *
@@ -29,8 +30,13 @@
  * KonsoleKalendar main program.
  * @author Tuukka Pasanen
  * @author Allen Winter
+ * @author Sérgio Martins
  */
-#include <time.h>
+
+#include "konsolekalendar.h"
+#include "konsolekalendarepoch.h"
+
+#include "konsolekalendarvariables.h"
 
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
@@ -40,25 +46,20 @@
 #include <kstandarddirs.h>
 #include <kurl.h>
 #include <kdebug.h>
+#include <KApplication>
 
-#include <kcal/calformat.h>
-#include <kcal/calendarresources.h>
-#include <kcal/resourcelocal.h>
+#include <KCalCore/CalFormat>
 
 #include <QtCore/QDateTime>
 #include <QtCore/QFile>
 #include <QtCore/QFileInfo>
+#include <QtCore/QEventLoop>
 
 #include <stdlib.h>
 #include <iostream>
+#include <time.h>
 
-#include "stdcalendar.h"
-#include "konsolekalendar.h"
-#include "konsolekalendarepoch.h"
-
-#include "konsolekalendarvariables.h"
-
-using namespace KCal;
+using namespace KCalCore;
 using namespace std;
 
 //@cond IGNORE
@@ -105,8 +106,6 @@ int main( int argc, char *argv[] )
                ki18n( "Print what would have been done, but do not execute" ) );
   options.add( "allow-gui",
                ki18n( "Allow calendars which might need an interactive user interface" ) );
-  options.add( "file <calendar-file>",
-               ki18n( "Specify which calendar you want to use" ) );
   options.add( ":",
                ki18n( "Incidence types (these options can be combined):" ) );
   options.add( "event",
@@ -129,6 +128,8 @@ int main( int argc, char *argv[] )
                ki18n( "  Create new calendar file if one does not exist" ) );
   options.add( "import <import-file>",
                ki18n( "  Import this calendar to main calendar" ) );
+  options.add( "list-calendars",
+               ki18n( "  List available calendars" ) );
   options.add( ":",
                ki18n( "Operation modifiers:" ) );
   options.add( "all",
@@ -157,6 +158,8 @@ int main( int argc, char *argv[] )
                ki18n( "Add description to incidence (for add/change modes)" ) );
   options.add( "location <location>",
                ki18n( "  Add location to incidence (for add/change modes)" ) );
+  options.add( "calendar <calendar id>",
+               ki18n( "  Calendar to use when creating a new incidence" ) );
   options.add( ":",
                ki18n( "Export options:" ) );
   options.add( "export-type <export-type>",
@@ -168,7 +171,8 @@ int main( int argc, char *argv[] )
   options.add( "",
                ki18n( "Examples:\n"
                       "  konsolekalendar --view\n"
-                      "  konsolekalendar --add --date 2003-06-04 "
+                      "  konsolekalendar --list-collections\n"
+                      "  konsolekalendar --add --collection 42 --date 2003-06-04 "
                       "--time 10:00 --end-time 12:00 \\\n"
                       "                  --summary \"Doctor Visit\" "
                       "--description \"Get My Head Examined\"\n"
@@ -227,22 +231,22 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "export-list" ) ) {
     cout << endl;
     cout << i18n( "%1 supports these export formats:",
-                  QString(progDisplay) ).toLocal8Bit().data()
+                  QString::fromLatin1(progDisplay) ).toLocal8Bit().data()
          << endl;
     cout << i18nc( "the default export format", "  %1 [Default]",
-                   QString( "Text" ) ).toLocal8Bit().data()
+                   QString::fromLatin1( "Text" ) ).toLocal8Bit().data()
          << endl;
     cout << i18nc( "short text export", "  %1 (like %2, but more compact)",
-                   QString( "Short" ), QString( "Text" ) ).toLocal8Bit().data()
+                   QString::fromLatin1( "Short" ), QString::fromLatin1( "Text" ) ).toLocal8Bit().data()
          << endl;
     cout << i18nc( "HTML export", "  %1",
-                   QString( "HTML" ) ).toLocal8Bit().data()
+                   QString::fromLatin1( "HTML" ) ).toLocal8Bit().data()
          << endl;
     cout << i18nc( "HTMLmonth export", "  %1 (like %2, but in a month view)",
-                   QString( "HTMLmonth" ), QString( "HTML" ) ).toLocal8Bit().data()
+                   QString::fromLatin1( "HTMLmonth" ), QString::fromLatin1( "HTML" ) ).toLocal8Bit().data()
          << endl;
     cout << i18nc( "comma-separated values export", "  %1 (Comma-Separated Values)",
-                   QString( "CSV" ) ).toLocal8Bit().data()
+                   QString::fromLatin1( "CSV" ) ).toLocal8Bit().data()
          << endl;
     cout << endl;
     return 0;
@@ -284,19 +288,19 @@ int main( int argc, char *argv[] )
   if ( args->isSet( "export-type" ) ) {
     option = args->getOption( "export-type" );
 
-    if ( option.toUpper() == "HTML" ) {
+    if ( option.toUpper() == QLatin1String("HTML") ) {
       kDebug() << "main | export-type | Export to HTML";
       variables.setExportType( ExportTypeHTML );
-    } else if ( option.toUpper() == "HTMLMONTH" ) {
+    } else if ( option.toUpper() == QLatin1String("HTMLMONTH") ) {
       kDebug() << "main | export-type | Export to HTML by Month";
       variables.setExportType( ExportTypeMonthHTML );
-    } else if ( option.toUpper() == "CSV" ) {
+    } else if ( option.toUpper() == QLatin1String("CSV") ) {
       kDebug() << "main | export-type | Export to CSV";
       variables.setExportType( ExportTypeCSV );
-    } else if ( option.toUpper() == "TEXT" ) {
+    } else if ( option.toUpper() == QLatin1String("TEXT") ) {
       kDebug() << "main | export-type | Export to TEXT (default)";
       variables.setExportType( ExportTypeText );
-    } else if ( option.toUpper() == "SHORT" ) {
+    } else if ( option.toUpper() == QLatin1String("SHORT") ) {
       kDebug() << "main | export-type | Export to TEXT-SHORT";
       variables.setExportType( ExportTypeTextShort );
     } else {
@@ -399,6 +403,14 @@ int main( int argc, char *argv[] )
     variables.setDescription( option );
   }
 
+  if ( args->isSet( "calendar" ) ) {
+    option = args->getOption( "calendar" );
+    bool ok = false;
+    int colId = option.toInt(&ok);
+    if (ok)
+        variables.setCollectionId(colId);
+  }
+
   /*
    * If there is location information
    */
@@ -467,10 +479,10 @@ int main( int argc, char *argv[] )
              << "Start time before conversion :"
              << "(" << option << ")";
 
-    if ( option.toUpper() != "FLOAT" ) {
-      if ( option.count( ':' ) < 2 ) {
+    if ( option.toUpper() != QLatin1String("FLOAT") ) {
+      if ( option.count( QLatin1Char(':') ) < 2 ) {
         // need to append seconds
-        option.append( ":00" );
+        option.append( QLatin1String(":00") );
       }
       starttime = QTime::fromString( option, Qt::ISODate );
       if ( !starttime.isValid() ) {
@@ -544,10 +556,10 @@ int main( int argc, char *argv[] )
              << "End time before conversion:"
              << "(" << option << ")";
 
-    if ( option.toUpper() != "FLOAT" ) {
-      if ( option.count( ':' ) < 2 ) {
+    if ( option.toUpper() != QLatin1String("FLOAT") ) {
+      if ( option.count( QLatin1Char(':') ) < 2 ) {
         // need to append seconds
-        option.append( ":00" );
+        option.append( QLatin1String(":00") );
       }
       endtime = QTime::fromString( option, Qt::ISODate );
       if ( !endtime.isValid() ) {
@@ -613,86 +625,22 @@ int main( int argc, char *argv[] )
 
   KonsoleKalendar *konsolekalendar = new KonsoleKalendar( &variables );
 
-  if ( args->isSet( "file" ) ) {
-    // calendarFile = true;
-    option = args->getOption( "file" );
-    variables.setCalendarFile( option );
-
-    /*
-     * All modes need to know if the calendar file exists
-     * This must be done before we get to opening biz
-     */
-    bool exists, remote;
-    KUrl url( variables.getCalendarFile() );
-    if ( url.isLocalFile() ) {
-      variables.setCalendarFile( url.toLocalFile() );
-      exists = QFile::exists( variables.getCalendarFile() );
-      remote = false;
-    } else if ( url.protocol().isEmpty() ) {
-      QFileInfo info( variables.getCalendarFile() );
-      variables.setCalendarFile( info.absoluteFilePath() );
-      exists = QFile::exists( variables.getCalendarFile() );
-      remote = false;
-    } else {
-      exists = true; // really have no idea if the remote file exists
-      remote = true;
-    }
-
-    if ( create ) {
-
-      kDebug() << "main | createcalendar |"
-               << "check if calendar file already exists";
-
-      if ( remote ) {
-        cout << i18n( "Attempting to create a remote file %1",
-                      variables.getCalendarFile() ).toLocal8Bit().data()
-             << endl;
-        return 1;
-      } else {
-        if ( exists ) {
-          cout << i18n( "Calendar %1 already exists",
-                        variables.getCalendarFile() ).toLocal8Bit().data()
-               << endl;
-          return 1;
-        }
-      }
-
-      if ( konsolekalendar->createCalendar() ) {
-        cout << i18n( "Calendar %1 successfully created",
-                      variables.getCalendarFile() ).toLocal8Bit().data()
-             << endl;
-        return 0;
-      } else {
-        cout << i18n( "Unable to create calendar: %1",
-                      variables.getCalendarFile() ).toLocal8Bit().data()
-             << endl;
-        return 1;
-      }
-    }
-
-    if ( !exists ) {
-      cout << i18n( "Calendar file not found %1",
-                    variables.getCalendarFile() ).toLocal8Bit().data()
-           << endl;
-      cout << i18n( "Try --create to create new calendar file" ).toLocal8Bit().data()
-           << endl;
-      return 1;
-    }
+  if (args->isSet("list-calendars")) {
+      konsolekalendar->printCalendarList();
+      return 0;
   }
 
-  CalendarResources *calendarResource = NULL;
-  /*
-   * Should we use local calendar or resource?
-   */
-  if ( args->isSet( "file" ) ) {
-    calendarResource = new StdCalendar( variables.getCalendarFile(),
-                                        i18n( "Active Calendar" ) );
-  } else {
-    calendarResource = new StdCalendar( variables.allowGui() );
-  }
+  QEventLoop loop;
+  Akonadi::FetchJobCalendar::Ptr calendar = Akonadi::FetchJobCalendar::Ptr( new Akonadi::FetchJobCalendar() );
+  QObject::connect(calendar.data(), SIGNAL(loadFinished(bool,QString)), &loop, SLOT(quit()));
+  kDebug() << "Starting to load calendar";
+  QElapsedTimer t;
+  t.start();
+  loop.exec();
+  kDebug() << "Calendar loaded in" << t.elapsed() << "ms; success=" << calendar->isLoaded() << "; num incidences=" << calendar->incidences().count();
+
   if ( !args->isSet( "import" ) ) {
-    variables.setCalendar( calendarResource );
-    calendarResource->load();
+    variables.setCalendar( calendar );
   }
 
   /***************************************************************************
@@ -834,9 +782,9 @@ int main( int argc, char *argv[] )
    * Set our application name for use in unique IDs and error messages,
    * and product ID for incidence PRODID property
    */
-  QString prodId = "-//K Desktop Environment//NONSGML %1 %2//EN";
-  CalFormat::setApplication( progDisplay,
-                             prodId.arg( progDisplay ).arg( progVersion ) );
+  QString prodId = QLatin1String("-//K Desktop Environment//NONSGML %1 %2//EN");
+  CalFormat::setApplication( QLatin1String(progDisplay),
+                             prodId.arg( QLatin1String(progDisplay) ).arg( QLatin1String(progVersion) ) );
 
   if ( importFile ) {
     if ( konsolekalendar->importCalendar() ) {
@@ -874,7 +822,7 @@ int main( int argc, char *argv[] )
            << endl;
       return 1;
     }
-    if ( konsolekalendar->changeEvent() != true ) {
+    if ( !konsolekalendar->changeEvent() ) {
       cout << i18n( "No such event UID: change event failed" ).toLocal8Bit().data()
            << endl;
       return 1;
@@ -892,7 +840,7 @@ int main( int argc, char *argv[] )
            << endl;
       return 1;
     }
-    if ( konsolekalendar->deleteEvent() != true ) {
+    if ( !konsolekalendar->deleteEvent() ) {
       cout << i18n( "No such event UID: delete event failed" ).toLocal8Bit().data()
            << endl;
       return 1;
@@ -914,8 +862,6 @@ int main( int argc, char *argv[] )
 
   delete konsolekalendar;
 
-  calendarResource->close();
-  delete calendarResource;
 
   kDebug() << "main | exiting";
 
