@@ -59,7 +59,7 @@ private:
         SaveAndCreateNewTheme
     };
 
-    void loadTheme(const QString &directory);
+    bool loadTheme(const QString &directory);
     void readConfig();
     void updateActions();
     bool saveCurrentProject(ActionSaveTheme act);
