@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,9 +17,6 @@
 
 #include "contacteditorwidget.h"
 #include "defaultcompletion.h"
-#include <QStringListModel>
-#include <QCompleter>
-#include <QDebug>
 
 ContactEditorWidget::ContactEditorWidget(QWidget *parent)
     : GrantleeThemeEditor::EditorWidget(parent)
@@ -40,4 +37,3 @@ void ContactEditorWidget::createCompleterList(const QStringList &extraCompletion
     GrantleeThemeEditor::EditorWidget::createCompleterList(listWord);
 }
 
-#include "contacteditorwidget.moc"
