@@ -6,7 +6,7 @@
 #ifndef MAILREADERVIEW_H
 #define MAILREADERVIEW_H
 
-#include <QtGui/QWidget>
+#include <QWidget>
 
 #include "ui_mailreaderview.h"
 
@@ -71,7 +71,7 @@ signals:
 private slots:
     void switchColors();
     void settingsChanged();
-    void urlClicked( const KUrl& url, Qt::MouseButton button);
+    void urlClicked( const Akonadi::Item &, const KUrl& );
 };
 
 #endif // mailreaderVIEW_H
