@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,6 +21,9 @@
 #include <KDialog>
 class KTextEdit;
 
+namespace PimCommon {
+class RichTextEditorWidget;
+}
 namespace GrantleeThemeEditor {
 class ConfigureWidget;
 }
@@ -41,8 +44,8 @@ private Q_SLOTS:
 
 private:
     GrantleeThemeEditor::ConfigureWidget *mConfigureWidget;
-    KTextEdit *mDefaultTemplate;
-    KTextEdit *mDefaultEmail;
+    PimCommon::RichTextEditorWidget *mDefaultTemplate;
+    PimCommon::RichTextEditorWidget *mDefaultEmail;
 };
 
 #endif // THEMECONFIGUREDIALOG_H
