@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -31,10 +31,12 @@
 #include <KABC/Addressee>
 
 #include <KDebug>
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <QPrinter>
 #include <QTextDocument>
+#include <QFile>
+#include <QDir>
 
 using namespace KABPrinting;
 
@@ -80,8 +82,10 @@ GrantleePrintStyle::GrantleePrintStyle( const QString &themePath, PrintingWizard
 {
     mEngine = new Grantlee::Engine;
     mTemplateLoader = Grantlee::FileSystemTemplateLoader::Ptr( new Grantlee::FileSystemTemplateLoader );
-    //TODO themePath + preview.png ?
-    //setPreview( QLatin1String("") );
+    QFile previewFile(QString(themePath + QDir::separator() + QLatin1String("preview.png")));
+    if (previewFile.exists()) {
+        setPreview( previewFile.fileName() );
+    }
 
     mTemplateLoader->setTemplateDirs( QStringList() << themePath );
     mEngine->addTemplateLoader( mTemplateLoader );
@@ -135,4 +139,3 @@ QString GrantleeStyleFactory::description() const
     return mName;
 }
 
-#include "grantleeprintstyle.moc"
