@@ -19,7 +19,7 @@
  */
 
 #include "kalarm.h"
-#include "templatedlg.moc"
+#include "templatedlg.h"
 
 #include "editdlg.h"
 #include "alarmcalendar.h"
@@ -44,7 +44,6 @@
 #include <kmenu.h>
 
 #include <QPushButton>
-#include <QList>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QBoxLayout>
