@@ -71,12 +71,11 @@
 #include <KFileDialog>
 #include <KFind>
 #include <KFindDialog>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KReplaceDialog>
 #include <kselectionproxymodel.h>
 #include <KStandardDirs>
-#include <KTextBrowser>
 #include <KGlobalSettings>
 #include <KXMLGUIClient>
 #include <KProcess>
@@ -99,7 +98,7 @@
 #include <kdebug.h>
 
 #include <memory>
-#include "kjotslockattribute.h"
+#include "noteshared/attributes/notelockattribute.h"
 #include "localresourcecreator.h"
 #include <krandom.h>
 #include "kjotsbrowser.h"
@@ -148,7 +147,7 @@ KJotsWidget::KJotsWidget( QWidget * parent, KXMLGUIClient *xmlGuiClient, Qt::Win
   ItemFetchScope scope;
   scope.fetchFullPayload( true ); // Need to have full item when adding it to the internal data structure
   scope.fetchAttribute< EntityDisplayAttribute >();
-  scope.fetchAttribute< KJotsLockAttribute >();
+  scope.fetchAttribute< NoteShared::NoteLockAttribute >();
 
   ChangeRecorder *monitor = new ChangeRecorder( this );
   monitor->fetchCollection( true );
@@ -746,7 +745,7 @@ void KJotsWidget::deletePage()
   if ( !item.isValid() )
     return;
 
-  if( item.hasAttribute<KJotsLockAttribute>() ) {
+  if( item.hasAttribute<NoteShared::NoteLockAttribute>() ) {
 
         KMessageBox::information(topLevelWidget(),
             i18n("This page is locked. You can only delete it when you first unlock it."),
@@ -779,7 +778,7 @@ void KJotsWidget::deleteBook()
   if ( col.parentCollection() == Collection::root() )
     return;
 
-  if( col.hasAttribute<KJotsLockAttribute>() ) {
+  if( col.hasAttribute<NoteShared::NoteLockAttribute>() ) {
 
       KMessageBox::information(topLevelWidget(),
           i18n("This book is locked. You can only delete it when you first unlock it."),
@@ -1850,4 +1849,3 @@ void KJotsWidget::actionSortChildrenByDate()
   }
 }
 
-#include "kjotswidget.moc"
