@@ -42,8 +42,7 @@
 
 #include <kleo/stl_util.h>
 
-#include <KLocale>
-#include <KMessageBox>
+#include <KLocalizedString>
 #include <kdebug.h>
 
 #include <QStringList>
