@@ -35,7 +35,6 @@
 #include "smimevalidationconfigurationpage.h"
 #include "smimevalidationconfigurationwidget.h"
 
-#include <QLayout>
 #include <QVBoxLayout>
 #include <kmessagebox.h>
 #include <klocale.h>
@@ -84,4 +83,3 @@ extern "C" KDE_EXPORT KCModule *create_kleopatra_config_smimevalidation( QWidget
     return page;
 }
 
-#include "smimevalidationconfigurationpage.moc"
