@@ -56,7 +56,7 @@
 
 #include <kmime/kmime_header_parsing.h>
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <KDebug>
 #include <KMessageBox>
 
