@@ -46,7 +46,7 @@
 
 #include <gpgme++/key.h>
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <KConfigGroup>
 #include <KSharedConfig>
 #include <KDebug>
@@ -54,10 +54,10 @@
 #include <QLabel>
 #include <QPushButton>
 #include <QDialogButtonBox>
-#include <QLayout>
 #include <QItemSelectionModel>
 #include <QAbstractItemView>
 #include <QPointer>
+#include <QVBoxLayout>
 
 #include <boost/bind.hpp>
 
