@@ -65,7 +65,7 @@
 
 #include <KConfigGroup>
 #include <KGlobal>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KDebug>
 #include <KTempDir>
 #include <KMessageBox>
@@ -1483,5 +1483,4 @@ void AdvancedSettingsDialog::updateWidgetVisibility() {
     slotKeyMaterialSelectionChanged();
 }
 
-#include "moc_newcertificatewizard.cpp"
 #include "newcertificatewizard.moc"
