@@ -43,6 +43,9 @@ protected slots:
     void updateCollectionStatistic(Akonadi::Collection::Id, const Akonadi::CollectionStatistics& );
     void slotReindexing();
 
+private slots:
+    void onIndexedItemsReceived( qint64 num );
+
 private:
     void updateLabel( qint64 nbMail, qint64 nbUnreadMail, qint64 size );
 
