@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,10 +18,9 @@
 #include "configureagentswidget.h"
 
 #include "agents/sendlateragent/sendlaterutil.h"
-#include "agents/folderarchiveagent/folderarchiveutil.h"
 #include <akonadi/private/xdgbasedirs_p.h>
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <KDesktopFile>
 #include <KDebug>
 #include <KTextEdit>
@@ -121,7 +120,6 @@ void ConfigureAgentsWidget::initialize()
     createItem(QLatin1String("akonadi_sendlater_agent"), QLatin1String("/SendLaterAgent"), QLatin1String("sendlateragent.desktop"));
     createItem(QLatin1String("akonadi_archivemail_agent"), QLatin1String("/ArchiveMailAgent"), QLatin1String("archivemailagent.desktop"));
     createItem(QLatin1String("akonadi_newmailnotifier_agent"), QLatin1String("/NewMailNotifierAgent"), QLatin1String("newmailnotifieragent.desktop"));
-    createItem(QLatin1String("akonadi_folderarchive_agent"), QLatin1String("/FolderArchiveAgent"), QLatin1String("folderarchiveagent.desktop"));
 
     //Laurent readd when implement it in future kdepim version
     //createItem(QLatin1String("akonadi_followupreminder_agent"), QLatin1String("/FollowUpReminder"), QLatin1String("followupreminder.desktop"));
@@ -194,7 +192,6 @@ void ConfigureAgentsWidget::save()
             changeAgentActiveState((item->checkState(AgentState) == Qt::Checked), item->data(AgentName, InterfaceName).toString(), item->data(AgentName, PathName).toString());
     }
     SendLater::SendLaterUtil::forceReparseConfiguration();
-    FolderArchive::FolderArchiveUtil::forceReparseConfiguration();
 }
 
 QString ConfigureAgentsWidget::helpAnchor() const
@@ -228,4 +225,3 @@ void ConfigureAgentsWidget::doResetToDefaultsOther()
 }
 
 
-#include "configureagentswidget.moc"
