@@ -103,6 +103,7 @@ namespace PimCommon {
 class CustomToolsWidget;
 class LineEditWithAutoCorrection;
 class StorageServiceAbstract;
+class StorageServiceManager;
 }
 
 //-----------------------------------------------------------------------------
@@ -460,6 +461,7 @@ private slots:
     void slotUploadFileStart(PimCommon::StorageServiceAbstract *service);
 
     void slotActionFailed(const QString &serviceName, const QString &error);
+    void slotTransportChanged();
 public: // kmcommand
     // FIXME we need to remove these, but they're pure virtual in Composer.
     void addAttach( KMime::Content *msgPart );
@@ -694,6 +696,7 @@ private:
     Akonadi::Collection mCollectionForNewMessage;
     QMap<QByteArray, QString> mExtraHeaders;
     int mNumProgressUploadFile;
+    PimCommon::StorageServiceManager *mStorageManager;
 };
 
 #endif
