@@ -28,7 +28,7 @@
 
 #include <KAction>
 #include <KActionCollection>
-#include <KLocale>
+#include <KLocalizedString>
 
 using namespace KMail;
 using namespace MailCommon;
@@ -151,4 +151,3 @@ void FolderShortcutActionManager::shortcutChanged( const Akonadi::Collection &co
     command->setAction( action ); // will be deleted along with the command
 }
 
-#include "foldershortcutactionmanager.moc"
