@@ -59,7 +59,7 @@
 #include <kpimidentities/identity.h>
 #include <kpimidentities/signatureconfigurator.h>
 
-#include "messagecomposer/autocorrection/composerautocorrectionlanguage.h"
+#include "pimcommon/autocorrection/autocorrectionlanguage.h"
 
 #include <libkdepim/addressline/addresseelineedit.h>
 // libkleopatra:
@@ -118,10 +118,6 @@ IdentityDialog::IdentityDialog( QWidget * parent )
 #endif
     setDefaultButton( Ok );
 
-#ifdef Q_OS_WINCE
-    setWindowState( Qt::WindowFullScreen );
-#endif
-
     // tmp. vars:
     QWidget * tab;
     QLabel  * label;
@@ -201,7 +197,7 @@ IdentityDialog::IdentityDialog( QWidget * parent )
     KPIMUtils::EmailValidator* emailValidator = new KPIMUtils::EmailValidator( this );
     mEmailEdit->setValidator( emailValidator );
 
-    // "Email Aliases" stsring text edit and label:
+    // "Email Aliases" string text edit and label:
     ++row;
     mAliasEdit = new PimCommon::SimpleStringListEditor( tab );
     glay->addWidget( mAliasEdit, row, 1 );
@@ -377,6 +373,7 @@ IdentityDialog::IdentityDialog( QWidget * parent )
     // "Reply-To Address" line edit and label:
     ++row;
     mReplyToEdit = new KPIM::AddresseeLineEdit( tab, true );
+    mReplyToEdit->setClearButtonShown(true);
     mReplyToEdit->setObjectName( QLatin1String("mReplyToEdit") );
     glay->addWidget( mReplyToEdit, row, 1 );
     label = new QLabel ( i18n("&Reply-To address:"), tab );
@@ -400,6 +397,7 @@ IdentityDialog::IdentityDialog( QWidget * parent )
     // "CC addresses" line edit and label:
     ++row;
     mCcEdit = new KPIM::AddresseeLineEdit( tab, true );
+    mCcEdit->setClearButtonShown(true);
     mCcEdit->setObjectName( QLatin1String("mCcEdit") );
     glay->addWidget( mCcEdit, row, 1 );
     label = new QLabel( i18n("&CC addresses:"), tab );
@@ -420,6 +418,7 @@ IdentityDialog::IdentityDialog( QWidget * parent )
     // "BCC addresses" line edit and label:
     ++row;
     mBccEdit = new KPIM::AddresseeLineEdit( tab, true );
+    mBccEdit->setClearButtonShown(true);
     mBccEdit->setObjectName( QLatin1String("mBccEdit") );
     glay->addWidget( mBccEdit, row, 1 );
     label = new QLabel( i18n("&BCC addresses:"), tab );
@@ -491,7 +490,7 @@ IdentityDialog::IdentityDialog( QWidget * parent )
 
 
     ++row;
-    mAutoCorrectionLanguage = new MessageComposer::ComposerAutoCorrectionLanguage(tab);
+    mAutoCorrectionLanguage = new PimCommon::AutoCorrectionLanguage(tab);
     glay->addWidget( mAutoCorrectionLanguage, row, 1 );
     label = new QLabel( i18n("Autocorrection language:"), tab );
     label->setBuddy( mAutoCorrectionLanguage );
@@ -655,7 +654,7 @@ void IdentityDialog::slotButtonClicked( int button )
     // Validate email addresses
     const QString email = mEmailEdit->text().trimmed();
     if ( !KPIMUtils::isValidSimpleAddress( email ) ) {
-        QString errorMsg( KPIMUtils::simpleEmailAddressErrorMsg() );
+        const QString errorMsg( KPIMUtils::simpleEmailAddressErrorMsg() );
         KMessageBox::sorry( this, errorMsg, i18n("Invalid Email Address") );
         return;
     }
@@ -981,4 +980,3 @@ void IdentityDialog::updateVcardButton()
 
 }
 
-#include "identitydialog.moc"
