@@ -973,11 +973,8 @@ bool KMKernel::isOffline()
         return false;
 }
 
-void KMKernel::checkMailOnStartup()
+void KMKernel::verifyAccount()
 {
-    if ( !kmkernel->askToGoOnline() )
-        return;
-
     const QString resourceGroupPattern( QLatin1String("Resource %1") );
 
     const Akonadi::AgentInstance::List lst = MailCommon::Util::agentInstances();
@@ -997,6 +994,27 @@ void KMKernel::checkMailOnStartup()
     }
 }
 
+void KMKernel::slotCheckAccount(Akonadi::ServerManager::State state)
+{
+    if (state == Akonadi::ServerManager::Running) {
+        disconnect(Akonadi::ServerManager::self(), SIGNAL(stateChanged(Akonadi::ServerManager::State)));
+        verifyAccount();
+    }
+}
+
+void KMKernel::checkMailOnStartup()
+{
+    if ( !kmkernel->askToGoOnline() )
+        return;
+
+    if (Akonadi::ServerManager::state() != Akonadi::ServerManager::Running) {
+        connect(Akonadi::ServerManager::self(), SIGNAL(stateChanged(Akonadi::ServerManager::State)),
+                                       SLOT(slotCheckAccount(Akonadi::ServerManager::State)));
+    } else {
+        verifyAccount();
+    }
+}
+
 bool KMKernel::askToGoOnline()
 {
     // already asking means we are offline and need to wait anyhow
