@@ -1,7 +1,7 @@
 /*******************************************************************
  KNotes -- Notes for the KDE project
 
- Copyright (c) 1997-2006, The KNotes Developers
+ Copyright (c) 1997-2013, The KNotes Developers
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -23,33 +23,31 @@
 
 #include <QDomDocument>
 #include <QList>
-#include <QMap>
-#include <QString>
 #include <QWidget>
 
 #include <kapplication.h>
 #include <ksessionmanager.h>
 #include <kxmlguiclient.h>
 
-class QTcpServer;
+#include <Akonadi/Item>
+#include <QPointer>
 
-class KAction;
-class KFind;
+class KNoteFindDialog;
+class KNotesAkonadiTray;
 class KMenu;
 class KNote;
-class KNotesAlarm;
-class KNotesResourceManager;
 class KXMLGUIBuilder;
 class KXMLGUIFactory;
-class KNotesTray;
-
-namespace KCal {
-class Journal;
+namespace NoteShared {
+class NotesChangeRecorder;
+class NotesAkonadiTreeModel;
 }
+
 namespace DNSSD {
 class PublicService;
 }
-
+class KJob;
+class QModelIndex;
 class KNotesApp
         : public QWidget, public KSessionManager, virtual public KXMLGUIClient
 {
@@ -58,84 +56,64 @@ public:
     KNotesApp();
     ~KNotesApp();
 
-    void showNote( const QString &id ) const;
-    void hideNote( const QString &id ) const;
-
-    void killNote( const QString &id );
-    void killNote( const QString &id, bool force );
-
-    QString name( const QString &id ) const;
-    QString text( const QString &id ) const;
-
-    void setName( const QString &id, const QString &newName );
-    void setText( const QString &id, const QString &newText );
-
-    QVariantMap notes() const;
-
     bool commitData( QSessionManager & );
 
 public slots:
-    QString newNote( const QString &name = QString(),
+    void newNote( const QString &name = QString(),
                      const QString &text = QString() );
-    QString newNoteFromClipboard( const QString &name = QString() );
-
+    void newNoteFromClipboard( const QString &name = QString() );
     void hideAllNotes() const;
     void showAllNotes() const;
-
-protected slots:
-    void slotActivateRequested( bool, const QPoint& pos);
-    void slotSecondaryActivateRequested( const QPoint& );
-    void slotShowNote();
-    void slotWalkThroughNotes();
-
-    void slotOpenFindDialog();
-    void slotFindNext();
-
-    void slotPreferences();
-    void slotConfigureAccels();
-
-    void slotNoteKilled( KCal::Journal *journal );
-
-    void slotQuit();
+    void showNote( const Akonadi::Item::Id &id ) const;
+    void hideNote(const Akonadi::Item::Id &id ) const;
+    QString name( const Akonadi::Item::Id &id ) const;
+    QString text( const Akonadi::Item::Id &id ) const;
+    void setName(const Akonadi::Item::Id &id, const QString &newName );
+    void setText( const Akonadi::Item::Id &id, const QString &newText );
 
 private:
     void showNote( KNote *note ) const;
-    void saveConfigs();
 
-private slots:
+
+private Q_SLOTS:
+    void slotPreferences();
     void slotConfigUpdated();
-    void acceptConnection();
-    void saveNotes();
-    void saveNotes( const QString & uid );
+    void slotNoteDeleteFinished(KJob*);
+    void slotRowInserted(const QModelIndex &, int, int end);
+    void slotItemRemoved(const Akonadi::Item &item);
+    void slotItemChanged(const Akonadi::Item &item, const QSet<QByteArray> &);
     void updateNoteActions();
-
-    void createNote( KCal::Journal *journal );
-    void killNote( KCal::Journal *journal );
+    void slotActivateRequested( bool, const QPoint& pos);
+    void slotSecondaryActivateRequested( const QPoint& );
     void slotPrintSelectedNotes();
+    void slotQuit();
+    void slotConfigureAccels();
+    void slotShowNote();
+    void slotWalkThroughNotes();
+    void slotNoteKilled( Akonadi::Item::Id );
+    void slotOpenFindDialog();
+
+    void slotSelectNote(Akonadi::Item::Id);
+    void slotCollectionChanged(const Akonadi::Collection &, const QSet<QByteArray> &);
+    void slotItemFetchFinished(KJob *job);
 
 private:
+    void saveNotes(bool force = false, bool sync = false);
     void updateNetworkListener();
-    QMap<QString, KNote *> m_notes;
-    QList<QAction *>       m_noteActions;
-
-    KNotesResourceManager  *m_manager;
-    KNotesAlarm            *m_alarm;
-    QTcpServer             *m_listener;
-    DNSSD::PublicService   *m_publisher;
-
-    KFind           *m_find;
-    QMap<QString, KNote *>::iterator *m_findPos;
-
-    KMenu           *m_noteMenu;
-    KMenu           *m_contextMenu;
-
+    void updateSystray();
+    void createNote(const Akonadi::Item &item);
+    void fetchNotesFromCollection(const Akonadi::Collection &col);
     KXMLGUIFactory  *m_guiFactory;
     KXMLGUIBuilder  *m_guiBuilder;
-    KNotesTray *m_tray;
-    KAction         *m_findAction;
-
     QDomDocument    m_noteGUI;
-    QString m_noteUidModify;
+    KNotesAkonadiTray *mTray;
+    KMenu           *m_noteMenu;
+    QList<QAction *>       m_noteActions;
+    DNSSD::PublicService   *m_publisher;
+    QHash<Akonadi::Item::Id, KNote*> mNotes;
+    NoteShared::NotesChangeRecorder *mNoteRecorder;
+    NoteShared::NotesAkonadiTreeModel *mNoteTreeModel;
+    QPointer<KNoteFindDialog> mFindDialog;
 };
 
 #endif
