@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -22,9 +22,7 @@
 #include <qmetatype.h>
 #include "knotes_export.h"
 
-namespace KCal {
-class Journal;
-}
+#include <Akonadi/Item>
 
 class KNOTES_EXPORT KNotePrintObject : public QObject
 {
@@ -32,16 +30,23 @@ class KNOTES_EXPORT KNotePrintObject : public QObject
     Q_PROPERTY(QString description READ description)
     Q_PROPERTY(QString name READ name)
     Q_PROPERTY(QString currentDateTime READ currentDateTime)
+    Q_PROPERTY(bool hasAlarm READ hasAlarm)
+    Q_PROPERTY(QString alarm READ alarm)
+    Q_PROPERTY(bool isLock READ isLock)
+    Q_PROPERTY(QString backgroundColorName READ backgroundColorName)
 public:
-    explicit KNotePrintObject(KCal::Journal *journal, QObject *parent=0);
+    explicit KNotePrintObject(const Akonadi::Item &item, QObject *parent=0);
     ~KNotePrintObject();
 
     QString description() const;
     QString name() const;
     QString currentDateTime() const;
-
+    bool hasAlarm() const;
+    QString alarm() const;
+    bool isLock() const;
+    QString backgroundColorName() const;
 private:
-    KCal::Journal *mJournal;
+    Akonadi::Item mItem;
 };
 
 Q_DECLARE_METATYPE(QList<KNotePrintObject*>)
