@@ -3,7 +3,7 @@
 
   Copyright (C) 2002-2003 Daniel Molkentin <molkentin@kde.org>
   Copyright (C) 2004-2006 Michael Brade <brade@kde.org>
-  Copyright (C) 2013 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2014 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
@@ -22,26 +22,52 @@
 */
 
 #include "knotes_part.h"
+#include "notesharedglobalconfig.h"
+#include "noteshared/noteutils.h"
 #include "knoteseditdialog.h"
 #include "knotesadaptor.h"
+#include "noteshared/job/createnewnotejob.h"
 #include "knotesiconview.h"
 #include "knoteswidget.h"
 #include "knotesselectdeletenotesdialog.h"
-#include "knotetip.h"
 #include "knotes/configdialog/knoteconfigdialog.h"
-#include "knotes/network/knotesnetrecv.h"
 #include "knotes/print/knoteprinter.h"
 #include "knotes/print/knoteprintobject.h"
 #include "knotes/print/knoteprintselectthemedialog.h"
-#include "knotes/resource/resourcemanager.h"
 #include "knotes/knoteedit.h"
 #include "knotes/knotesglobalconfig.h"
 #include "knotes/configdialog/knotesimpleconfigdialog.h"
+#include "knotes/finddialog/knotefinddialog.h"
 #include "utils/knoteutils.h"
-#include "alarms/knotealarmdialog.h"
-#include "alarms/knotesalarm.h"
-#include <KCal/Journal>
-using namespace KCal;
+#include "alarms/notealarmdialog.h"
+#include "noteshared/resources/localresourcecreator.h"
+#include "noteshared/job/createnewnotejob.h"
+
+#include "noteshared/akonadi/notesakonaditreemodel.h"
+#include "noteshared/akonadi/noteschangerecorder.h"
+#include "noteshared/attributes/notealarmattribute.h"
+#include "noteshared/attributes/showfoldernotesattribute.h"
+#include "noteshared/attributes/notealarmattribute.h"
+#include "noteshared/attributes/notedisplayattribute.h"
+#include "noteshared/attributes/notelockattribute.h"
+
+#include "akonadi_next/note.h"
+
+#include <Akonadi/Session>
+#include <Akonadi/ChangeRecorder>
+#include <Akonadi/ETMViewStateSaver>
+#include <Akonadi/EntityDisplayAttribute>
+#include <Akonadi/ItemCreateJob>
+#include <Akonadi/ItemFetchJob>
+#include <KCheckableProxyModel>
+#include <akonadi/itemdeletejob.h>
+#include <Akonadi/ItemFetchScope>
+
+
+#include <KMime/KMimeMessage>
+
+#include <Akonadi/ItemModifyJob>
+#include <Akonadi/Control>
 
 #include <KActionCollection>
 #include <KAction>
@@ -56,28 +82,33 @@ using namespace KCal;
 
 #include <QApplication>
 #include <QClipboard>
-#include <QTcpServer>
 #include <QMenu>
 #include <QPointer>
 #include <QCheckBox>
 
 #include <dnssd/publicservice.h>
 
-KNotesPart::KNotesPart( KNotesResourceManager *manager, QObject *parent )
+KNotesPart::KNotesPart( QObject *parent )
     : KParts::ReadOnlyPart( parent ),
-      mNotesWidget( new KNotesWidget(this) ),
-      mNoteTip( new KNoteTip( mNotesWidget->notesView() ) ),
-      mManager( manager ),
-      mListener(0),
+      mNotesWidget( 0 ) ,
       mPublisher(0),
-      mAlarm(0),
-      mNotePrintPreview(0)
+      mNotePrintPreview(0),
+      mNoteTreeModel(0)
 {
     (void) new KNotesAdaptor( this );
     QDBusConnection::sessionBus().registerObject( QLatin1String("/KNotes"), this );
 
     setComponentData( KComponentData( "knotes" ) );
 
+    Akonadi::Control::widgetNeedsAkonadi(widget());
+
+    KNoteUtils::migrateToAkonadi();
+
+    if (KNotesGlobalConfig::self()->autoCreateResourceOnStart()) {
+        NoteShared::LocalResourceCreator *creator = new NoteShared::LocalResourceCreator( this );
+        creator->createIfMissing();
+    }
+
     // create the actions
     mNewNote = new KAction( KIcon( QLatin1String("knotes") ),
                             i18nc( "@action:inmenu create new popup note", "&New" ), this );
@@ -102,6 +133,7 @@ KNotesPart::KNotesPart( KNotesResourceManager *manager, QObject *parent )
 
     mNoteRename = new KAction( KIcon( QLatin1String("edit-rename") ),
                           i18nc( "@action:inmenu", "Rename..." ), this );
+    mNoteRename->setShortcut( QKeySequence( Qt::Key_F2 ) );
     actionCollection()->addAction( QLatin1String("edit_rename"), mNoteRename );
     connect( mNoteRename, SIGNAL(triggered(bool)), SLOT(renameNote()) );
     mNoteRename->setHelpText(
@@ -133,7 +165,6 @@ KNotesPart::KNotesPart( KNotesResourceManager *manager, QObject *parent )
                        "You will be prompted to print the selected popup note." ) );
 
     if(KPrintPreview::isAvailable()) {
-
         mNotePrintPreview = new KAction( KIcon( QLatin1String("document-print-preview") ),i18nc( "@action:inmenu", "Print Preview Selected Notes..." ), this );
         actionCollection()->addAction( QLatin1String("print_preview_note"), mNotePrintPreview );
 
@@ -175,72 +206,86 @@ KNotesPart::KNotesPart( KNotesResourceManager *manager, QObject *parent )
     connect( mReadOnly, SIGNAL(triggered(bool)), SLOT(slotUpdateReadOnly()) );
     mReadOnly->setCheckedState( KGuiItem( i18n( "Unlock" ), QLatin1String("object-unlocked") ) );
 
+    KStandardAction::find( this, SLOT(slotOpenFindDialog()), actionCollection());
 
-    // TODO icons: s/editdelete/knotes_delete/ or the other way round in knotes
+    Akonadi::Session *session = new Akonadi::Session( "KNotes Session", this );
+    mNoteRecorder = new NoteShared::NotesChangeRecorder(this);
+    mNoteRecorder->changeRecorder()->setSession(session);
+    mNoteTreeModel = new NoteShared::NotesAkonadiTreeModel(mNoteRecorder->changeRecorder(), this);
 
-    // set the view up
+    connect( mNoteTreeModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
+             SLOT(slotRowInserted(QModelIndex,int,int)));
+
+    connect( mNoteRecorder->changeRecorder(), SIGNAL(itemChanged(Akonadi::Item,QSet<QByteArray>)), SLOT(slotItemChanged(Akonadi::Item,QSet<QByteArray>)));
+    connect( mNoteRecorder->changeRecorder(), SIGNAL(itemRemoved(Akonadi::Item)), SLOT(slotItemRemoved(Akonadi::Item)) );
+    connect( mNoteRecorder->changeRecorder(), SIGNAL(collectionChanged(Akonadi::Collection,QSet<QByteArray>)), SLOT(slotCollectionChanged(Akonadi::Collection,QSet<QByteArray>)) );
+
+
+    mSelectionModel = new QItemSelectionModel( mNoteTreeModel );
+    mModelProxy = new KCheckableProxyModel( this );
+    mModelProxy->setSelectionModel( mSelectionModel );
+    mModelProxy->setSourceModel( mNoteTreeModel );
+
+    KSharedConfigPtr _config = KSharedConfig::openConfig( QLatin1String("kcmknotessummaryrc") );
+
+    mModelState =
+            new KViewStateMaintainer<Akonadi::ETMViewStateSaver>( _config->group( "CheckState" ), this );
+    mModelState->setSelectionModel( mSelectionModel );
+
+    mNotesWidget = new KNotesWidget(this,widget());
 
     connect( mNotesWidget->notesView(), SIGNAL(executed(QListWidgetItem*)),
              this, SLOT(editNote(QListWidgetItem*)) );
 
-    connect( mNotesWidget->notesView(), SIGNAL(entered(QModelIndex)),
-             this, SLOT(requestToolTip(QModelIndex)));
-
-    connect( mNotesWidget->notesView(), SIGNAL(viewportEntered()),
-             this, SLOT(hideToolTip()));
-
     connect( mNotesWidget->notesView(), SIGNAL(itemSelectionChanged()),
              this, SLOT(slotOnCurrentChanged()) );
-
     slotOnCurrentChanged();
 
     setWidget( mNotesWidget );
     setXMLFile( QLatin1String("knotes_part.rc") );
-
-    // connect the resource manager
-    connect( mManager, SIGNAL(sigRegisteredNote(KCal::Journal*)),
-             this, SLOT(createNote(KCal::Journal*)) );
-    connect( mManager, SIGNAL(sigDeregisteredNote(KCal::Journal*)),
-             this, SLOT(killNote(KCal::Journal*)) );
-    mManager->load();
-    mAlarm = new KNotesAlarm( mManager, this );
     updateNetworkListener();
 }
 
 KNotesPart::~KNotesPart()
 {
-    delete mListener;
-    mListener=0;
     delete mPublisher;
     mPublisher=0;
-    delete mNoteTip;
-    mNoteTip = 0;
+}
+
+void KNotesPart::slotItemRemoved(const Akonadi::Item &item)
+{
+    KNotesIconViewItem *iconView = mNotesWidget->notesView()->iconView(item.id());
+    delete iconView;
+}
+
+void KNotesPart::slotRowInserted(const QModelIndex &parent, int start, int end)
+{
+    for ( int i = start; i <= end; ++i) {
+        if ( mNoteTreeModel->hasIndex( i, 0, parent ) ) {
+            const QModelIndex child = mNoteTreeModel->index( i, 0, parent );
+            Akonadi::Collection parentCollection = mNoteTreeModel->data( child, Akonadi::EntityTreeModel::ParentCollectionRole).value<Akonadi::Collection>();
+            if (parentCollection.hasAttribute<NoteShared::ShowFolderNotesAttribute>()) {
+                Akonadi::Item item =
+                        mNoteTreeModel->data( child, Akonadi::EntityTreeModel::ItemRole ).value<Akonadi::Item>();
+                if ( !item.hasPayload<KMime::Message::Ptr>() )
+                    continue;
+                mNotesWidget->notesView()->addNote(item);
+            }
+        }
+    }
 }
 
 QStringList KNotesPart::notesList() const
 {
     QStringList notes;
-
-    QHashIterator<QString, KNotesIconViewItem*> i(mNoteList);
+    QHashIterator<Akonadi::Item::Id, KNotesIconViewItem*> i(mNotesWidget->notesView()->noteList());
     while ( i.hasNext() ) {
         i.next();
-        notes.append(i.value()->journal()->uid());
+        notes.append(QString::number(i.key()));
     }
     return notes;
 }
 
-void KNotesPart::requestToolTip( const QModelIndex &index )
-{
-    const QRect m_itemRect = mNotesWidget->notesView()->visualRect( index );
-    mNoteTip->setNote(
-                static_cast<KNotesIconViewItem *>( mNotesWidget->notesView()->itemAt( m_itemRect.topLeft() ) ) );
-}
-
-void KNotesPart::hideToolTip()
-{
-    mNoteTip->setNote( 0 );
-}
-
 void KNotesPart::slotPrintPreviewSelectedNotes()
 {
     printSelectedNotes(true);
@@ -262,7 +307,6 @@ void KNotesPart::printSelectedNotes(bool preview)
                     i18nc( "@title:window", "Print Popup Notes" ) );
         return;
     }
-
     KNotesGlobalConfig *globalConfig = KNotesGlobalConfig::self();
     QString printingTheme = globalConfig->theme();
     if (printingTheme.isEmpty()) {
@@ -273,10 +317,9 @@ void KNotesPart::printSelectedNotes(bool preview)
         delete dlg;
     }
     if (!printingTheme.isEmpty()) {
-
         QList<KNotePrintObject *> listPrintObj;
         foreach ( QListWidgetItem *item, lst ) {
-            listPrintObj.append(new KNotePrintObject(static_cast<KNotesIconViewItem *>( item )->journal()));
+            listPrintObj.append(new KNotePrintObject(static_cast<KNotesIconViewItem *>( item )->item()));
         }
         KNotePrinter printer;
         printer.printNotes( listPrintObj, printingTheme, preview );
@@ -291,91 +334,56 @@ bool KNotesPart::openFile()
 
 // public KNotes D-Bus interface implementation
 
-QString KNotesPart::newNote( const QString &name, const QString &text )
+void KNotesPart::newNote( const QString &name, const QString &text )
 {
-    // create the new note
-    Journal *journal = new Journal();
-
-    // new notes have the current date/time as title if none was given
-    if ( !name.isEmpty() ) {
-        journal->setSummary( name );
-    } else {
-        journal->setSummary( KGlobal::locale()->formatDateTime( QDateTime::currentDateTime() ) );
-    }
-
-    // the body of the note
-    journal->setDescription( text );
-
-    // Edit the new note if text is empty
-    if ( text.isNull() ) {
-        QPointer<KNoteEditDialog> dlg = new KNoteEditDialog( false, widget() );
-
-        dlg->setTitle( journal->summary() );
-        dlg->setText( journal->description() );
-
-
-        const QString property = journal->customProperty("KNotes", "RichText");
-        if ( !property.isNull() ) {
-            dlg->setAcceptRichText( property == QLatin1String("true") ? true : false );
-        } else {
-            KNotesGlobalConfig *globalConfig = KNotesGlobalConfig::self();
-            dlg->setAcceptRichText( globalConfig->richText());
-        }
-
-
-        dlg->noteEdit()->setFocus();
-        if ( dlg->exec() == QDialog::Accepted ) {
-            journal->setSummary( dlg->title() );
-            journal->setDescription( dlg->text() );
-            delete dlg;
-        } else {
-            delete dlg;
-            delete journal;
-            return QString();
-        }
-    }
-
-    mManager->addNewNote( journal );
-
-    KNotesIconViewItem *note = mNoteList.value( journal->uid() );
-    mNotesWidget->notesView()->scrollToItem( note );
-    mNotesWidget->notesView()->setCurrentItem( note );
-    mManager->save();
-    return journal->uid();
+    NoteShared::CreateNewNoteJob *job = new NoteShared::CreateNewNoteJob(this, widget());
+    job->setRichText(KNotesGlobalConfig::self()->richText());
+    job->setNote(name, text);
+    job->start();
 }
 
-QString KNotesPart::newNoteFromClipboard( const QString &name )
+void KNotesPart::slotNoteCreationFinished(KJob* job)
+{
+    if (job->error()) {
+        kWarning() << job->errorString();
+        NoteShared::NoteSharedGlobalConfig::self()->setDefaultFolder(-1);
+        NoteShared::NoteSharedGlobalConfig::self()->writeConfig();
+        KMessageBox::error(widget(), i18n("Note was not created."), i18n("Create new note"));
+        return;
+    }
+}
+
+void KNotesPart::newNoteFromClipboard( const QString &name )
 {
     const QString &text = QApplication::clipboard()->text();
-    return newNote( name, text );
+    newNote( name, text );
 }
 
-void KNotesPart::killNote( const QString &id )
+void KNotesPart::killNote( Akonadi::Item::Id id )
 {
     killNote( id, false );
 }
 
-void KNotesPart::killNote( const QString &id, bool force )
+void KNotesPart::killNote( Akonadi::Item::Id id, bool force )
 {
-    KNotesIconViewItem *note = mNoteList.value( id );
-
+    KNotesIconViewItem *note = mNotesWidget->notesView()->iconView(id);
     if ( note &&
          ( (!force && KMessageBox::warningContinueCancelList(
                 mNotesWidget,
                 i18nc( "@info", "Do you really want to delete this note?" ),
-                QStringList( mNoteList.value( id )->text() ),
+                QStringList( note->realName() ),
                 i18nc( "@title:window", "Confirm Delete" ),
                 KStandardGuiItem::del() ) == KMessageBox::Continue )
            || force ) ) {
-        KNoteUtils::removeNote(mNoteList.value( id )->journal(), 0);
-        mManager->deleteNote( mNoteList.value( id )->journal() );
-        mManager->save();
+
+            Akonadi::ItemDeleteJob *job = new Akonadi::ItemDeleteJob(note->item());
+            connect(job, SIGNAL(result(KJob*)), SLOT(slotDeleteNotesFinished(KJob*)) );
     }
 }
 
-QString KNotesPart::name( const QString &id ) const
+QString KNotesPart::name( Akonadi::Item::Id id ) const
 {
-    KNotesIconViewItem *note = mNoteList.value( id );
+    KNotesIconViewItem *note = mNotesWidget->notesView()->iconView(id);
     if ( note ) {
         return note->text();
     } else {
@@ -383,42 +391,40 @@ QString KNotesPart::name( const QString &id ) const
     }
 }
 
-QString KNotesPart::text( const QString &id ) const
+QString KNotesPart::text( Akonadi::Item::Id id ) const
 {
-    KNotesIconViewItem *note = mNoteList.value( id );
+    //TODO return plaintext ?
+    KNotesIconViewItem *note = mNotesWidget->notesView()->iconView( id );
     if ( note ) {
-        return note->journal()->description();
+        return note->description();
     } else {
         return QString();
     }
 }
 
-void KNotesPart::setName( const QString &id, const QString &newName )
+void KNotesPart::setName(Akonadi::Entity::Id id, const QString &newName )
 {
-    KNotesIconViewItem *note = mNoteList.value( id );
+    KNotesIconViewItem *note = mNotesWidget->notesView()->iconView(id);
     if ( note ) {
         note->setIconText( newName );
-        mManager->save();
     }
 }
 
-void KNotesPart::setText( const QString &id, const QString &newText )
+void KNotesPart::setText( Akonadi::Item::Id id, const QString &newText )
 {
-    KNotesIconViewItem *note = mNoteList.value( id );
+    KNotesIconViewItem *note = mNotesWidget->notesView()->iconView( id );
     if ( note ) {
-        note->journal()->setDescription( newText );
-        mManager->save();
+        note->setDescription( newText );
     }
 }
 
 QMap<QString, QString> KNotesPart::notes() const
 {
     QMap<QString, QString> notes;
-
-    QHashIterator<QString, KNotesIconViewItem*> i(mNoteList);
+    QHashIterator<Akonadi::Item::Id, KNotesIconViewItem*> i(mNotesWidget->notesView()->noteList());
     while ( i.hasNext() ) {
         i.next();
-        notes.insert( i.value()->journal()->uid(), i.value()->journal()->summary() );
+        notes.insert(QString::number(i.key()), i.value()->realName());
     }
     return notes;
 }
@@ -440,24 +446,31 @@ void KNotesPart::killSelectedNotes()
 
     if (items.isEmpty())
         return;
-
     QPointer<KNotesSelectDeleteNotesDialog> dlg = new KNotesSelectDeleteNotesDialog(items, widget());
     if (dlg->exec()) {
+        Akonadi::Item::List lst;
         QListIterator<KNotesIconViewItem*> kniviIt( items );
         while ( kniviIt.hasNext() ) {
             KNotesIconViewItem *iconViewIcon = kniviIt.next();
             if (!iconViewIcon->readOnly()) {
-                Journal *journal = iconViewIcon->journal();
-                KNoteUtils::removeNote(journal, 0);
-                mManager->deleteNote( journal );
+                lst.append(iconViewIcon->item());
             }
         }
-        mManager->save();
+        if (!lst.isEmpty()) {
+            Akonadi::ItemDeleteJob *job = new Akonadi::ItemDeleteJob(lst);
+            connect(job, SIGNAL(result(KJob*)), SLOT(slotDeleteNotesFinished(KJob*)) );
+        }
     }
-
     delete dlg;
 }
 
+void KNotesPart::slotDeleteNotesFinished(KJob* job)
+{
+    if ( job->error() ) {
+        qDebug()<<" problem during delete job note:"<<job->errorString();
+    }
+}
+
 void KNotesPart::popupRMB( QListWidgetItem *item, const QPoint &pos, const QPoint &globalPos )
 {
     Q_UNUSED( item );
@@ -502,45 +515,31 @@ void KNotesPart::popupRMB( QListWidgetItem *item, const QPoint &pos, const QPoin
     delete contextMenu;
 }
 
-// TODO: also with takeItem, clear(),
-
-// create and kill the icon view item corresponding to the note, edit the note
-
-void KNotesPart::createNote( KCal::Journal *journal )
+void KNotesPart::editNote(Akonadi::Entity::Id id)
 {
-    mNoteList.insert( journal->uid(), new KNotesIconViewItem( mNotesWidget->notesView(), journal ) );
-}
-
-void KNotesPart::killNote( KCal::Journal *journal )
-{
-    KNotesIconViewItem *item = mNoteList.take( journal->uid() );
-    delete item;
+    KNotesIconViewItem *knoteItem = mNotesWidget->notesView()->iconView(id);
+    if (knoteItem) {
+        mNotesWidget->notesView()->setCurrentItem(knoteItem);
+        editNote(knoteItem);
+    }
 }
 
 void KNotesPart::editNote( QListWidgetItem *item )
 {
     KNotesIconViewItem * knotesItem = static_cast<KNotesIconViewItem *>( item );
     QPointer<KNoteEditDialog> dlg = new KNoteEditDialog( knotesItem->readOnly(), widget() );
-    Journal *journal = knotesItem->journal();
-    dlg->setTitle( journal->summary() );
-    dlg->setText( journal->description() );
+    dlg->setTitle( knotesItem->realName() );
+    dlg->setText( knotesItem->description() );
+    dlg->setColor( knotesItem->textForegroundColor(), knotesItem->textBackgroundColor() );
 
-    const QString property = journal->customProperty("KNotes", "RichText");
-    if ( !property.isNull() ) {
-        dlg->setAcceptRichText( property == QLatin1String("true") ? true : false );
-    } else {
-        KNotesGlobalConfig *globalConfig = KNotesGlobalConfig::self();
-        dlg->setAcceptRichText( globalConfig->richText());
-    }
+    dlg->setAcceptRichText(knotesItem->isRichText());
     dlg->setTabSize(knotesItem->tabSize());
     dlg->setAutoIndentMode(knotesItem->autoIndent());
     dlg->setTextFont(knotesItem->textFont());
 
     dlg->noteEdit()->setFocus();
     if ( dlg->exec() == QDialog::Accepted ) {
-        static_cast<KNotesIconViewItem *>( item )->setIconText( dlg->title() );
-        journal->setDescription( dlg->text() );
-        mManager->save();
+        knotesItem->setChangeIconTextAndDescription(dlg->title(), dlg->text());
     }
     delete dlg;
 }
@@ -565,7 +564,6 @@ void KNotesPart::renameNote()
                                    oldName, &ok, mNotesWidget );
     if ( ok && ( newName != oldName ) ) {
         knoteItem->setIconText( newName );
-        mManager->save();
     }
 }
 
@@ -594,23 +592,23 @@ void KNotesPart::slotNotePreferences()
 {
     if (!mNotesWidget->notesView()->currentItem())
         return;
-
     KNotesIconViewItem *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
-    const QString name = knoteItem->realName();
-    QPointer<KNoteSimpleConfigDialog> dialog = new KNoteSimpleConfigDialog( knoteItem->config(), name, widget(), knoteItem->journal()->uid() );
-    connect( dialog, SIGNAL(settingsChanged(QString)) , this,
-             SLOT(slotApplyConfig()) );
-    dialog->exec();
+    QPointer<KNoteSimpleConfigDialog> dialog = new KNoteSimpleConfigDialog( knoteItem->realName(), widget() );
+    Akonadi::Item item = knoteItem->item();
+    dialog->load(item, knoteItem->isRichText());
+    if (dialog->exec() ) {
+        KNoteUtils::updateConfiguration();
+        bool isRichText;
+        dialog->save(item, isRichText);
+        KMime::Message::Ptr message = item.payload<KMime::Message::Ptr>();
+        message->contentType( true )->setMimeType( isRichText ? "text/html" : "text/plain" );
+        message->assemble();
+        Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(item);
+        connect( job, SIGNAL(result(KJob*)), SLOT(slotNoteSaved(KJob*)) );
+    }
     delete dialog;
 }
 
-void KNotesPart::slotApplyConfig()
-{
-    KNotesIconViewItem *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
-    knoteItem->updateSettings();
-    mManager->save();
-}
-
 void KNotesPart::slotPreferences()
 {
     // create a new preferences dialog...
@@ -619,6 +617,11 @@ void KNotesPart::slotPreferences()
     dialog->show();
 }
 
+void KNotesPart::updateConfig()
+{
+    updateNetworkListener();
+}
+
 void KNotesPart::slotConfigUpdated()
 {
     updateNetworkListener();
@@ -629,7 +632,7 @@ void KNotesPart::slotMail()
     if (!mNotesWidget->notesView()->currentItem())
         return;
     KNotesIconViewItem *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
-    KNoteUtils::sendMail(widget(),knoteItem->realName(), knoteItem->journal()->description());
+    NoteShared::NoteUtils::sendToMail(widget(),knoteItem->realName(), knoteItem->description());
 }
 
 void KNotesPart::slotSendToNetwork()
@@ -637,51 +640,60 @@ void KNotesPart::slotSendToNetwork()
     if (!mNotesWidget->notesView()->currentItem())
         return;
     KNotesIconViewItem *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
-    KNoteUtils::sendToNetwork(widget(),knoteItem->realName(), knoteItem->journal()->description());
+    NoteShared::NoteUtils::sendToNetwork(widget(), knoteItem->realName(), knoteItem->description());
 }
 
 void KNotesPart::updateNetworkListener()
 {
-    delete mListener;
-    mListener=0;
     delete mPublisher;
     mPublisher=0;
 
-    if ( KNotesGlobalConfig::receiveNotes() ) {
+    if ( NoteShared::NoteSharedGlobalConfig::receiveNotes() ) {
         // create the socket and start listening for connections
-        mListener = KSocketFactory::listen( QLatin1String("knotes") , QHostAddress::Any,
-                                           KNotesGlobalConfig::port() );
-        connect( mListener, SIGNAL(newConnection()), SLOT(slotAcceptConnection()) );
-        mPublisher=new DNSSD::PublicService(KNotesGlobalConfig::senderID(), QLatin1String("_knotes._tcp"), KNotesGlobalConfig::port());
+        mPublisher=new DNSSD::PublicService(NoteShared::NoteSharedGlobalConfig::senderID(), QLatin1String("_knotes._tcp"), NoteShared::NoteSharedGlobalConfig::port());
         mPublisher->publishAsync();
     }
 }
 
-void KNotesPart::slotAcceptConnection()
-{
-    // Accept the connection and make KNotesNetworkReceiver do the job
-    QTcpSocket *s = mListener->nextPendingConnection();
-
-    if ( s ) {
-        KNotesNetworkReceiver *recv = new KNotesNetworkReceiver( s );
-        connect( recv,SIGNAL(sigNoteReceived(QString,QString)), SLOT(newNote(QString,QString)) );
-    }
-}
-
 void KNotesPart::slotSetAlarm()
 {
     if (!mNotesWidget->notesView()->currentItem())
         return;
     KNotesIconViewItem *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
-
-    QPointer<KNoteAlarmDialog> dlg = new KNoteAlarmDialog( knoteItem->realName(), widget() );
-    dlg->setIncidence( knoteItem->journal() );
+    QPointer<NoteShared::NoteAlarmDialog> dlg = new NoteShared::NoteAlarmDialog( knoteItem->realName(), widget() );
+    Akonadi::Item item = knoteItem->item();
+    if (item.hasAttribute<NoteShared::NoteAlarmAttribute>()) {
+        dlg->setAlarm(item.attribute<NoteShared::NoteAlarmAttribute>()->dateTime());
+    }
     if ( dlg->exec() ) {
-        mManager->save();
+        bool needToModify = true;
+        KDateTime dateTime = dlg->alarm();
+        if (dateTime.isValid()) {
+            NoteShared::NoteAlarmAttribute *attribute =  item.attribute<NoteShared::NoteAlarmAttribute>( Akonadi::Entity::AddIfMissing );
+            attribute->setDateTime(dateTime);
+        } else {
+            if (item.hasAttribute<NoteShared::NoteAlarmAttribute>()) {
+                item.removeAttribute<NoteShared::NoteAlarmAttribute>();
+            } else {
+                needToModify = false;
+            }
+        }
+        if (needToModify) {
+            Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(item);
+            connect( job, SIGNAL(result(KJob*)), SLOT(slotNoteSaved(KJob*)) );
+        }
     }
     delete dlg;
 }
 
+void KNotesPart::slotNoteSaved(KJob *job)
+{
+    qDebug()<<" void KNote::slotNoteSaved(KJob *job)";
+    if ( job->error() ) {
+        qDebug()<<" problem during save note:"<<job->errorString();
+    }
+}
+
 void KNotesPart::slotNewNoteFromClipboard()
 {
     const QString &text = KApplication::clipboard()->text();
@@ -728,9 +740,11 @@ void KNotesPart::slotSaveAs()
     if ( file.open( QIODevice::WriteOnly ) ) {
         QTextStream stream( &file );
         QTextDocument doc;
-        doc.setHtml(knoteItem->journal()->description());
+        doc.setHtml(knoteItem->description());
         if ( htmlFormatAndSaveAsHtml ) {
-            stream << doc.toHtml();
+            QString htmlStr = doc.toHtml();
+            htmlStr.replace(QLatin1String("meta name=\"qrichtext\" content=\"1\""), QLatin1String("meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\""));
+            stream <<  htmlStr;
         } else {
             stream << knoteItem->realName() + QLatin1Char('\n');
             stream << doc.toPlainText();
@@ -740,15 +754,89 @@ void KNotesPart::slotSaveAs()
 
 void KNotesPart::slotUpdateReadOnly()
 {
-    if (!mNotesWidget->notesView()->currentItem())
+    QListWidgetItem *item = mNotesWidget->notesView()->currentItem();
+    if (!item)
         return;
-    KNotesIconViewItem *knoteItem = static_cast<KNotesIconViewItem *>(mNotesWidget->notesView()->currentItem());
+    KNotesIconViewItem *knoteItem = static_cast<KNotesIconViewItem *>(item);
 
     const bool readOnly = mReadOnly->isChecked();
 
     mNoteEdit->setText(readOnly ? i18n("Show Note...") : i18nc( "@action:inmenu", "Edit..." ));
-
     knoteItem->setReadOnly( readOnly );
 }
 
-#include "knotes_part.moc"
+void KNotesPart::slotItemChanged(const Akonadi::Item &item, const QSet<QByteArray> & set)
+{
+    KNotesIconViewItem *knoteItem = mNotesWidget->notesView()->iconView(item.id());
+    if (knoteItem) {
+        knoteItem->setChangeItem(item, set);
+    }
+}
+
+void KNotesPart::slotOpenFindDialog()
+{
+    if (!mNoteFindDialog) {
+        mNoteFindDialog = new KNoteFindDialog(widget());
+        connect(mNoteFindDialog, SIGNAL(noteSelected(Akonadi::Item::Id)), this, SLOT(slotSelectNote(Akonadi::Item::Id)));
+    }
+    QHash<Akonadi::Item::Id , Akonadi::Item> lst;
+    QHashIterator<Akonadi::Item::Id, KNotesIconViewItem*> i(mNotesWidget->notesView()->noteList());
+    while (i.hasNext()) {
+        i.next();
+        lst.insert(i.key(), i.value()->item());
+    }
+    mNoteFindDialog->setExistingNotes(lst);
+    mNoteFindDialog->show();
+}
+
+void KNotesPart::slotSelectNote(Akonadi::Item::Id id)
+{
+    editNote(id);
+}
+
+void KNotesPart::slotCollectionChanged(const Akonadi::Collection &col, const QSet<QByteArray> & set)
+{
+    if (set.contains("showfoldernotesattribute")) {
+        //qDebug()<<" collection Changed "<<set<<" col "<<col;
+        if (col.hasAttribute<NoteShared::ShowFolderNotesAttribute>()) {
+            fetchNotesFromCollection(col);
+        } else {
+            QHashIterator<Akonadi::Item::Id, KNotesIconViewItem*> i(mNotesWidget->notesView()->noteList());
+            while (i.hasNext()) {
+                i.next();
+                Akonadi::Item item = i.value()->item();
+                if (item.parentCollection() == col) {
+                    slotItemRemoved(item);
+                }
+            }
+        }
+    }
+}
+
+void KNotesPart::fetchNotesFromCollection(const Akonadi::Collection &col)
+{
+    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob( col );
+    job->fetchScope().fetchFullPayload(true);
+    job->fetchScope().fetchAttribute<NoteShared::NoteLockAttribute>();
+    job->fetchScope().fetchAttribute<NoteShared::NoteDisplayAttribute>();
+    job->fetchScope().fetchAttribute<NoteShared::NoteAlarmAttribute>();
+    job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
+    connect( job, SIGNAL(result(KJob*)), SLOT(slotItemFetchFinished(KJob*)) );
+}
+
+void KNotesPart::slotItemFetchFinished(KJob *job)
+{
+    if ( job->error() ) {
+        qDebug() << "Error occurred during item fetch:"<<job->errorString();
+        return;
+    }
+
+    Akonadi::ItemFetchJob *fetchJob = qobject_cast<Akonadi::ItemFetchJob*>( job );
+
+    const Akonadi::Item::List items = fetchJob->items();
+    foreach ( const Akonadi::Item &item, items ) {
+        if ( !item.hasPayload<KMime::Message::Ptr>() )
+            continue;
+        mNotesWidget->notesView()->addNote(item);
+    }
+}
