@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -27,7 +27,7 @@ KNotesWidget::KNotesWidget(KNotesPart *part, QWidget *parent)
     QVBoxLayout *lay = new QVBoxLayout;
     KNotesListWidgetSearchLine *searchLine = new KNotesListWidgetSearchLine;
     lay->addWidget(searchLine);
-    mIconView = new KNotesIconView(part);
+    mIconView = new KNotesIconView(part, parent);
     searchLine->setListWidget(mIconView);
     lay->addWidget(mIconView);
     setLayout(lay);
@@ -43,4 +43,3 @@ KNotesIconView *KNotesWidget::notesView() const
     return mIconView;
 }
 
-#include "knoteswidget.moc"
