@@ -30,7 +30,7 @@
 
 #include <calendarsupport/utils.h>
 #include <calendarsupport/calendarsingleton.h>
-
+#include <Akonadi/Calendar/ETMCalendar>
 #include <Akonadi/ItemFetchJob>
 #include <Akonadi/ItemFetchScope>
 #include <Akonadi/EntityDisplayAttribute>
@@ -40,12 +40,12 @@
 #include <KCalCore/Calendar>
 
 #include <KMenu>
+#include <KLocalizedString>
 #include <KLocale>
 #include <KUrlLabel>
 #include <KIconLoader>
 #include <KConfigGroup>
 #include <KToolInvocation>
-#include <KSystemTimeZones>
 #include <KHolidays/Holidays>
 
 #include <QDate>
@@ -161,7 +161,7 @@ SDSummaryWidget::SDSummaryWidget( KontactInterface::Plugin *plugin, QWidget *par
   connect( mPlugin->core(), SIGNAL(dayChanged(QDate)),
            this, SLOT(updateView()) );
 
-  connect( mCalendar.data(), SIGNAL(calendarChanged()),
+  connect( mCalendar, SIGNAL(calendarChanged()),
            this, SLOT(updateView()) );
   connect( mPlugin->core(), SIGNAL(dayChanged(QDate)),
            this, SLOT(updateView()) );
@@ -750,4 +750,3 @@ QStringList SDSummaryWidget::configModules() const
   return QStringList() << QLatin1String("kcmsdsummary.desktop" );
 }
 
-#include "sdsummarywidget.moc"
