@@ -34,6 +34,7 @@
 #include <calendarsupport/categoryconfig.h>
 
 #include <incidenceeditor-ng/globalsettings.h>
+#include <widgets/tagwidgets.h>
 
 #include <Akonadi/AgentFilterProxyModel>
 #include <Akonadi/AgentInstanceCreateJob>
@@ -867,9 +868,7 @@ KOPrefsDialogColorsAndFonts::KOPrefsDialogColorsAndFonts( const KComponentData &
   unsetCategoryColor->label()->setWhatsThis( unsetCategoryColor->button()->whatsThis() );
   unsetCategoryColor->label()->setToolTip( unsetCategoryColor->button()->toolTip() );
 
-  mCategoryCombo = new KComboBox( categoryGroup );
-  mCategoryCombo->addItems(
-    CalendarSupport::CategoryConfig( KOPrefs::instance() ).customCategories() );
+  mCategoryCombo = new KPIM::TagCombo( categoryGroup );
   mCategoryCombo->setWhatsThis(
     i18nc( "@info:whatsthis",
            "Select here the event category you want to modify. "
@@ -990,9 +989,6 @@ void KOPrefsDialogColorsAndFonts::usrReadConfig()
 
 void KOPrefsDialogColorsAndFonts::updateCategories()
 {
-  mCategoryCombo->clear();
-  mCategoryCombo->addItems(
-    CalendarSupport::CategoryConfig( KOPrefs::instance() ).customCategories() );
   updateCategoryColor();
 }
 
@@ -1007,6 +1003,7 @@ void KOPrefsDialogColorsAndFonts::updateCategoryColor()
   const QString cat = mCategoryCombo->currentText();
   QColor color = mCategoryDict.value( cat );
   if ( !color.isValid() ) {
+    //TODO get this from the tag
     color = CalendarSupport::KCalPrefs::instance()->categoryColor( cat );
   }
   if ( color.isValid() ) {
@@ -1352,22 +1349,20 @@ void KOPrefsDialogPlugins::usrReadConfig()
   QTreeWidgetItem *decorations =
     new QTreeWidgetItem( mTreeWidget, QStringList(
                            i18nc( "@title:group", "Calendar Decorations" ) ) );
-  QTreeWidgetItem *printPlugins =
-    new QTreeWidgetItem( mTreeWidget, QStringList(
-                           i18nc( "@title:group", "Print Plugins" ) ) );
   QTreeWidgetItem *others =
     new QTreeWidgetItem( mTreeWidget, QStringList(
                            i18nc( "@title:group", "Other Plugins" ) ) );
 
   KService::List::ConstIterator it;
   for ( it = plugins.constBegin(); it != plugins.constEnd(); ++it ) {
-    QTreeWidgetItem *item;
+    QTreeWidgetItem *item = 0;
     if ( (*it)->hasServiceType( EventViews::CalendarDecoration::Decoration::serviceType() ) ) {
       item = new PluginItem( decorations, *it );
-    } else if ( (*it)->hasServiceType( KOrg::PrintPlugin::serviceType() ) ){
-      item = new PluginItem( printPlugins, *it );
-    } else {
+    } else if ( !(*it)->hasServiceType( QLatin1String( "KOrganizer/PrintPlugin"  ) ) ) {
+      // we specifically skip print plugins since we no longer support them
       item = new PluginItem( others, *it );
+    } else {
+      continue;
     }
     if ( selectedPlugins.contains( (*it)->desktopEntryName() ) ) {
       item->setCheckState( 0, Qt::Checked );
@@ -1377,7 +1372,6 @@ void KOPrefsDialogPlugins::usrReadConfig()
   }
 
   decorations->setExpanded( true );
-  printPlugins->setExpanded( true );
   others->setExpanded( true );
 
   mDecorationsAtMonthViewTop = KOPrefs::instance()->decorationsAtMonthViewTop().toSet();
@@ -1586,4 +1580,3 @@ QString KOPrefsDesignerFields::applicationName()
   return QLatin1String("KORGANIZER");
 }
 
-#include "koprefsdialog.moc"
