@@ -366,8 +366,6 @@ void KOViewManager::connectTodoView( KOTodoView *todoView )
            mMainView, SLOT(todo_unsub()) );
   connect( todoView, SIGNAL(unAllSubTodoSignal()),
            mMainView, SLOT(makeSubTodosIndependent()) );
-  connect( mMainView, SIGNAL(categoryConfigChanged()),
-           todoView, SLOT(updateCategories()) );
 
   connect( todoView, SIGNAL(fullViewChanged(bool)),
            mMainView, SLOT(changeFullView(bool)) );
@@ -639,7 +637,7 @@ QDate KOViewManager::currentSelectionDate()
 {
   QDate qd;
   if ( mCurrentView ) {
-    DateList qvl = mCurrentView->selectedIncidenceDates();
+    KCalCore::DateList qvl = mCurrentView->selectedIncidenceDates();
     if ( !qvl.isEmpty() ) {
       qd = qvl.first();
     }
@@ -699,5 +697,4 @@ bool KOViewManager::agendaIsSelected() const
         ( mAgendaViewTabs && mCurrentView == mAgendaViewTabs->currentWidget() );
 }
 
-#include "koviewmanager.moc"
 
