@@ -36,7 +36,7 @@ K_EXPORT_PLUGIN( DatenumsFactory )
 Datenums::Datenums()
   : mDisplayedInfo( DayOfYear | DaysRemaining )
 {
-  KConfig _config( "korganizerrc", KConfig::NoGlobals );
+  KConfig _config( QLatin1String("korganizerrc"), KConfig::NoGlobals );
   KConfigGroup config( &_config, "Calendar/Datenums Plugin" );
   mDisplayedInfo = (DayNumbers)config.readEntry(
     "DayNumbers", int( DayOfYear | DaysRemaining ) );
@@ -64,17 +64,17 @@ Element::List Datenums::createDayElements( const QDate &date )
   StoredElement *e;
   switch ( mDisplayedInfo ) {
   case DayOfYear: // only day of year
-    e = new StoredElement( "main element", QString::number( dayOfYear ) );
+    e = new StoredElement( QLatin1String("main element"), QString::number( dayOfYear ) );
     break;
   case DaysRemaining: // only days until end of year
-    e = new StoredElement( "main element", QString::number( remainingDays ),
+    e = new StoredElement( QLatin1String("main element"), QString::number( remainingDays ),
                            i18np( "1 day before the end of the year",
                                   "%1 days before the end of the year",
                                   remainingDays ) );
     break;
   case DayOfYear + DaysRemaining: // both day of year and days till end of year
   default:
-    e = new StoredElement( "main element", QString::number( dayOfYear ),
+    e = new StoredElement( QLatin1String("main element"), QString::number( dayOfYear ),
                            i18nc( "dayOfYear / daysTillEndOfYear", "%1 / %2",
                                   dayOfYear, remainingDays ),
                            i18np( "1 day since the beginning of the year,\n",
@@ -156,16 +156,16 @@ Element::List Datenums::createWeekElements( const QDate &date )
   StoredElement *e;
   switch ( mDisplayedInfo ) {
     case DayOfYear: // only week of year
-      e = new StoredElement( "main element", weekOfYearShort, weekOfYearLong,
+      e = new StoredElement( QLatin1String("main element"), weekOfYearShort, weekOfYearLong,
                               weekOfYearExtensive );
       break;
     case DaysRemaining: // only weeks until end of year
-      e = new StoredElement( "main element", remainingWeeksShort,
+      e = new StoredElement( QLatin1String("main element"), remainingWeeksShort,
                              remainingWeeksLong, remainingWeeksExtensive );
       break;
     case DayOfYear + DaysRemaining: // both week of year and weeks till end of year
     default:
-      e = new StoredElement( "main element", weekOfYearShort,
+      e = new StoredElement( QLatin1String("main element"), weekOfYearShort,
                              weekOfYearAndRemainingWeeksShort,
                              i18nc( "n weeks since the beginning of the year\n"
                                     "n weeks until the end of the year",
