@@ -141,7 +141,7 @@ class TaskView::Private
 public:
 Private() :
     mStorage( new timetrackerstorage() ),
-    mFocusTrackingActive( false ) {}
+    mFocusTrackingActive( false ), mLastTaskWithFocus(0), mPopupPercentageMenu(0), mPopupPriorityMenu(0) {}
 
     ~Private()
     {
