@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,12 +21,10 @@
 #include "sieveactionwidgetlister.h"
 #include "sieveeditorgraphicalmodewidget.h"
 
-#include <KLocale>
+#include <KLocalizedString>
+#include <KSharedConfig>
 
-#include <QVBoxLayout>
-#include <QListWidget>
-#include <QSplitter>
-#include <QStackedWidget>
+#include <QKeyEvent>
 
 using namespace KSieveUi;
 
@@ -76,4 +74,16 @@ void AutoCreateScriptDialog::writeConfig()
     group.writeEntry( "Size", size() );
 }
 
-#include "autocreatescriptdialog.moc"
+bool AutoCreateScriptDialog::event(QEvent* e)
+{
+    const bool shortCutOverride = (e->type() == QEvent::ShortcutOverride);
+    if (shortCutOverride || e->type() == QEvent::KeyPress ) {
+        QKeyEvent* kev = static_cast<QKeyEvent* >(e);
+        if (kev->key() == Qt::Key_Escape) {
+            e->ignore();
+            return true;
+        }
+    }
+    return KDialog::event(e);
+}
+
