@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -32,6 +32,9 @@ public:
     bool isNegative() const;
     void setCode(const QString &code, const QString &name, QString &error);
 
+Q_SIGNALS:
+    void valueChanged();
+
 private:
     void initialize();
     bool mHasRegexCapability;
