@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -16,12 +16,13 @@
 */
 
 #include "sieveactionkeep.h"
+#include "editor/sieveeditorutil.h"
 #include "widgets/selectflagswidget.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <QLabel>
 #include <QHBoxLayout>
 #include <QDomNode>
@@ -71,6 +72,7 @@ QWidget *SieveActionKeep::createParamWidget( QWidget *parent ) const
         lay->addWidget(addFlags);
 
         SelectFlagsWidget *flagsWidget = new SelectFlagsWidget;
+        connect(flagsWidget, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
         flagsWidget->setObjectName(QLatin1String("flagswidget"));
         lay->addWidget(flagsWidget);
         return w;
@@ -122,4 +124,8 @@ QStringList SieveActionKeep::needRequires(QWidget *) const
     return requiresLst;
 }
 
-#include "sieveactionkeep.moc"
+QString SieveActionKeep::href() const
+{
+    return SieveEditorUtil::helpUrl(SieveEditorUtil::strToVariableName(name()));
+}
+
