@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -28,6 +28,10 @@ class AddressLineEdit : public KLineEdit
 public:
     explicit AddressLineEdit(QWidget *parent = 0);
     ~AddressLineEdit();
+
+Q_SIGNALS:
+    void valueChanged();
+
 protected:
     void focusOutEvent(QFocusEvent *ev);
 
