@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,8 +19,9 @@
 #include "autocreatescripts/commonwidgets/selectmatchtypecombobox.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
 #include "widgets/selectdatewidget.h"
+#include "editor/sieveeditorutil.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <KLineEdit>
 
 #include <QHBoxLayout>
@@ -48,6 +49,7 @@ QWidget *SieveConditionDate::createParamWidget( QWidget *parent ) const
 
     SelectMatchTypeComboBox *matchTypeCombo = new SelectMatchTypeComboBox;
     matchTypeCombo->setObjectName(QLatin1String("matchtype"));
+    connect(matchTypeCombo, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
     lay->addWidget(matchTypeCombo);
 
     QGridLayout *grid = new QGridLayout;
@@ -57,10 +59,12 @@ QWidget *SieveConditionDate::createParamWidget( QWidget *parent ) const
     grid->addWidget(lab, 0, 0);
 
     KLineEdit *header = new KLineEdit;
+    connect(header, SIGNAL(textChanged(QString)), this, SIGNAL(valueChanged()));
     header->setObjectName(QLatin1String("header"));
     grid->addWidget(header, 0, 1);
 
     SelectDateWidget *dateWidget = new SelectDateWidget;
+    connect(dateWidget, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
     dateWidget->setObjectName(QLatin1String("datewidget"));
     grid->addWidget(dateWidget, 1, 0, 1, 2);
 
@@ -146,5 +150,9 @@ bool SieveConditionDate::setParamWidgetValue(const QDomElement &element, QWidget
     return true;
 }
 
-#include "sieveconditiondate.moc"
+QString SieveConditionDate::href() const
+{
+    return SieveEditorUtil::helpUrl(SieveEditorUtil::strToVariableName(name()));
+}
+
 
