@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -16,8 +16,8 @@
 */
 
 #include "sieveconditionservermetadataexists.h"
-
-#include <KLocale>
+#include "editor/sieveeditorutil.h"
+#include <KLocalizedString>
 #include <KLineEdit>
 
 #include <QHBoxLayout>
@@ -48,6 +48,7 @@ QWidget *SieveConditionServerMetaDataExists::createParamWidget( QWidget *parent
 
     KLineEdit *value = new KLineEdit;
     value->setObjectName(QLatin1String("value"));
+    connect(value, SIGNAL(textChanged(QString)), this, SIGNAL(valueChanged()));
     lay->addWidget(value);
 
     return w;
@@ -104,4 +105,8 @@ bool SieveConditionServerMetaDataExists::setParamWidgetValue(const QDomElement &
     }
     return true;
 }
-#include "sieveconditionservermetadataexists.moc"
+
+QString SieveConditionServerMetaDataExists::href() const
+{
+    return SieveEditorUtil::helpUrl(SieveEditorUtil::strToVariableName(name()));
+}
