@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -34,6 +34,9 @@ public:
     QString code() const;
     void setCode(const QString &type, const QString &content, const QString &name, QString &error);
 
+Q_SIGNALS:
+    void valueChanged();
+
 private Q_SLOTS:
     void slotBodyTypeChanged(int);
 
