@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,11 +18,11 @@
 #include "selectcomparatorcombobox.h"
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
-#include <QDebug>
 
 SelectComparatorComboBox::SelectComparatorComboBox(QWidget *parent)
     : KComboBox(parent)
 {
+    connect(this, SIGNAL(activated(int)), this, SIGNAL(valueChanged()));
     initialize();
 }
 
@@ -69,4 +69,3 @@ void SelectComparatorComboBox::setCode(const QString &code, const QString &name,
     }
 }
 
-#include "selectcomparatorcombobox.moc"
