@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,7 +18,7 @@
 #include "selectsizetypecombobox.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 using namespace KSieveUi;
 
@@ -26,6 +26,7 @@ SelectSizeTypeComboBox::SelectSizeTypeComboBox(QWidget *parent)
     : KComboBox(parent)
 {
     initialize();
+    connect(this, SIGNAL(activated(int)), this, SIGNAL(valueChanged()));
 }
 
 SelectSizeTypeComboBox::~SelectSizeTypeComboBox()
@@ -56,4 +57,3 @@ void SelectSizeTypeComboBox::setCode(const QString &code, const QString &name, Q
     }
 }
 
-#include "selectsizetypecombobox.moc"
