@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -34,8 +34,10 @@ SelectSizeWidget::SelectSizeWidget(QWidget *parent)
     mSpinBoxSize->setMinimum(1);
     mSpinBoxSize->setMaximum(9999);
     hbox->addWidget(mSpinBoxSize);
+    connect(mSpinBoxSize, SIGNAL(valueChanged(int)), this, SIGNAL(valueChanged()));
 
     mSelectSizeType = new SelectSizeTypeComboBox;
+    connect(mSelectSizeType, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
     hbox->addWidget(mSelectSizeType);
 
     setLayout(hbox);
@@ -66,4 +68,3 @@ void SelectSizeWidget::setCode(qlonglong value, const QString &identifier, const
 }
 
 
-#include "selectsizewidget.moc"
