@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,9 +17,12 @@
 
 #include "sieveglobalvariablewidget.h"
 #include "sievescriptblockwidget.h"
+#include "autocreatescriptutil_p.h"
+#include "commonwidgets/sievehelpbutton.h"
+#include "editor/sieveeditorutil.h"
 
 #include <KPushButton>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KLineEdit>
 
 #include <QGridLayout>
@@ -67,13 +70,16 @@ void SieveGlobalVariableActionWidget::initWidget()
     mLayout->addWidget( lab, 1, 0 );
 
     mVariableName = new KLineEdit;
+    connect(mVariableName, SIGNAL(textChanged(QString)), this, SIGNAL(valueChanged()));
     mLayout->addWidget( mVariableName, 1, 1 );
 
     mSetValueTo = new QCheckBox(i18n("Set value to:"));
+    connect(mSetValueTo, SIGNAL(toggled(bool)), this, SIGNAL(valueChanged()));
     mLayout->addWidget( mSetValueTo, 1, 2 );
     mSetValueTo->setChecked(false);
 
     mVariableValue = new KLineEdit;
+    connect(mVariableValue, SIGNAL(textChanged(QString)), this, SIGNAL(valueChanged()));
     mVariableValue->setEnabled(false);
     mLayout->addWidget( mVariableValue, 1, 3 );
 
@@ -133,11 +139,13 @@ void SieveGlobalVariableActionWidget::loadScript(const QDomElement &element, QSt
 void SieveGlobalVariableActionWidget::slotAddWidget()
 {
     emit addWidget( this );
+    Q_EMIT valueChanged();
 }
 
 void SieveGlobalVariableActionWidget::slotRemoveWidget()
 {
     emit removeWidget( this );
+    Q_EMIT valueChanged();
 }
 
 void SieveGlobalVariableActionWidget::updateAddRemoveButton( bool addButtonEnabled, bool removeButtonEnabled )
@@ -150,13 +158,12 @@ SieveGlobalVariableWidget::SieveGlobalVariableWidget(QWidget *parent)
     : SieveWidgetPageAbstract(parent)
 {
     QVBoxLayout *lay = new QVBoxLayout;
-    QToolButton *helpButton = new QToolButton;
-    helpButton->setToolTip(i18n("Help"));
-    lay->addWidget( helpButton );
-    helpButton->setIcon( KIcon( QLatin1String("help-hint") ) );
-    connect(helpButton, SIGNAL(clicked()), this, SLOT(slotHelp()));
+    mHelpButton = new SieveHelpButton;
+    lay->addWidget( mHelpButton );
+    connect(mHelpButton, SIGNAL(clicked()), this, SLOT(slotHelp()));
 
     mIncludeLister = new SieveGlobalVariableLister;
+    connect(mIncludeLister, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
     lay->addWidget(mIncludeLister,0, Qt::AlignTop);
     setPageType(KSieveUi::SieveScriptBlockWidget::GlobalVariable);
     setLayout(lay);
@@ -169,7 +176,9 @@ SieveGlobalVariableWidget::~SieveGlobalVariableWidget()
 void SieveGlobalVariableWidget::slotHelp()
 {
     const QString help = i18n("A variable has global scope in all scripts that have declared it with the \"global\" command.  If a script uses that variable name without declaring it global, the name specifies a separate, non-global variable within that script.");
-    QWhatsThis::showText( QCursor::pos(), help );
+    const QString href = KSieveUi::SieveEditorUtil::helpUrl(KSieveUi::SieveEditorUtil::GlobalVariable);
+    const QString fullWhatsThis = AutoCreateScriptUtil::createFullWhatsThis(help,href);
+    QWhatsThis::showText( QCursor::pos(), fullWhatsThis, mHelpButton );
 }
 
 void SieveGlobalVariableWidget::generatedScript(QString &script, QStringList &requires)
@@ -260,11 +269,15 @@ void SieveGlobalVariableLister::reconnectWidget(SieveGlobalVariableActionWidget
              this, SLOT(slotAddWidget(QWidget*)), Qt::UniqueConnection );
     connect( w, SIGNAL(removeWidget(QWidget*)),
              this, SLOT(slotRemoveWidget(QWidget*)), Qt::UniqueConnection );
+    connect( w, SIGNAL(valueChanged()),
+             this, SIGNAL(valueChanged()), Qt::UniqueConnection );
 }
 
 void SieveGlobalVariableLister::clearWidget( QWidget *aWidget )
 {
+    Q_UNUSED(aWidget);
     //TODO
+    Q_EMIT valueChanged();
 }
 
 QWidget *SieveGlobalVariableLister::createWidget( QWidget *parent )
@@ -320,4 +333,3 @@ void SieveGlobalVariableLister::loadSetVariable(const QDomElement &element, QStr
 
 }
 
-#include "sieveglobalvariablewidget.moc"
