@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,12 +19,8 @@
 #include "pimcommon/util/pimutil.h"
 #include "pimcommon/texteditor/richtexteditor/richtexteditorwidget.h"
 
-#include <KFileDialog>
-#include <KLocale>
-#include <KMessageBox>
-
-#include <QPointer>
-#include <QTextStream>
+#include <KLocalizedString>
+#include <KSharedConfig>
 
 #include <errno.h>
 
@@ -78,5 +74,4 @@ void SieveScriptParsingErrorDialog::slotSaveAs()
     PimCommon::Util::saveTextAs(mTextEdit->toPlainText(), filter, this);
 }
 
-#include "sievescriptparsingerrordialog.moc"
 
