@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -42,6 +42,9 @@ public:
     virtual void setPageType(PageType type);
     PageType pageType() const;
 
+Q_SIGNALS:
+    void valueChanged();
+
 private:
     PageType mType;
 };
