@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,9 +20,8 @@
 #include "ksieveui/scriptsparsing/parsingutil.h"
 #include <kmanagesieve/sievejob.h>
 
-#include <KLocale>
+#include <KLocalizedString>
 
-#include <QDebug>
 
 using namespace KSieveUi;
 ParseUserScriptJob::ParseUserScriptJob(QObject *parent)
@@ -127,4 +126,3 @@ QString ParseUserScriptJob::loadInclude(const QDomElement &element)
     return scriptName;
 }
 
-#include "parseuserscriptjob.moc"
