@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,7 +17,7 @@
 
 #include "managesievetreeview.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 using namespace KSieveUi;
 
@@ -25,6 +25,11 @@ ManageSieveTreeView::ManageSieveTreeView(QWidget *parent)
     : PimCommon::CustomTreeView(parent)
 {
     setDefaultText(i18n( "No imap server configured..." ));
+    setRootIsDecorated( true );
+    setAlternatingRowColors( true );
+    setSelectionMode( QAbstractItemView::SingleSelection );
+    setHeaderLabel( i18n( "Available Scripts" ) );
+    setContextMenuPolicy(Qt::CustomContextMenu);
 }
 
 ManageSieveTreeView::~ManageSieveTreeView()
@@ -34,9 +39,17 @@ ManageSieveTreeView::~ManageSieveTreeView()
 void ManageSieveTreeView::setNoImapFound(bool found)
 {
     if (mShowDefaultText != found) {
+        setDefaultText(i18n( "No imap server configured..." ));
         mShowDefaultText = found;
         update();
     }
 }
 
-#include "managesievetreeview.moc"
+void ManageSieveTreeView::setNetworkDown(bool state)
+{
+    if (!state) {
+        setDefaultText(i18n("Network down."));
+    }
+    update();
+}
+
