@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -21,20 +21,18 @@
 
 
 #include "pimcommon/widgets/customtreeview.h"
-class QPaintEvent;
+#include "ksieveui_export.h"
 
 namespace KSieveUi {
-class ManageSieveTreeView : public PimCommon::CustomTreeView
+class KSIEVEUI_EXPORT ManageSieveTreeView : public PimCommon::CustomTreeView
 {
     Q_OBJECT
 public:
     explicit ManageSieveTreeView(QWidget *parent = 0);
     ~ManageSieveTreeView();
 
-    void setNoImapFound(bool found);
-
-private:
-    bool mImapFound;
+    void setNoImapFound(bool found);    
+    void setNetworkDown(bool state);
 };
 }
 
