@@ -22,15 +22,6 @@
 
 #include "filteractionwithstringlist.h"
 
-namespace Nepomuk2
-{
-namespace Query
-{
-class Result;
-class QueryServiceClient;
-}
-}
-
 namespace MailCommon {
 
 //=============================================================================
@@ -39,31 +30,31 @@ namespace MailCommon {
 //=============================================================================
 class FilterActionAddTag: public FilterAction
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit FilterActionAddTag( QObject *parent = 0 );
-    virtual ReturnCode process( ItemContext &context ) const;
+    ReturnCode process( ItemContext &context, bool applyOnOutbound ) const;
     SearchRule::RequiredPart requiredPart() const;
 
     static FilterAction* newAction();
 
-    virtual bool isEmpty() const;
+    bool isEmpty() const;
 
-    virtual void argsFromString( const QString &argsStr );
-    virtual QString argsAsString() const;
-    virtual QString displayString() const;
-    virtual bool argsFromStringInteractive( const QString &argsStr, const QString& filterName );
+    void argsFromString( const QString &argsStr );
+    QString argsAsString() const;
+    QString displayString() const;
+    bool argsFromStringInteractive( const QString &argsStr, const QString& filterName );
 
-    virtual QWidget *createParamWidget( QWidget *parent ) const;
-    virtual void applyParamWidgetValue( QWidget *paramWidget );
-    virtual void setParamWidgetValue( QWidget *paramWidget ) const;
-    virtual void clearParamWidget( QWidget *paramWidget ) const;
+    QWidget *createParamWidget( QWidget *parent ) const;
+    void applyParamWidgetValue( QWidget *paramWidget );
+    void setParamWidgetValue( QWidget *paramWidget ) const;
+    void clearParamWidget( QWidget *paramWidget ) const;
 
 
-  private Q_SLOTS:
+private Q_SLOTS:
     void slotTagListingFinished();
 
-  private:
+private:
     void initializeTagList();
     mutable QMap<QUrl, QString> mList;
     QString mParameter;
