@@ -26,12 +26,12 @@ namespace MailCommon {
 
 class FilterActionBeep : public FilterActionWithNone
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit FilterActionBeep( QObject *parent = 0 );
-    virtual ReturnCode process( ItemContext &context ) const;
+    ReturnCode process( ItemContext &context, bool applyOnOutbound ) const;
     static FilterAction* newAction();
-    virtual SearchRule::RequiredPart requiredPart() const;
+    SearchRule::RequiredPart requiredPart() const;
 };
 
 }
