@@ -29,13 +29,14 @@ namespace MailCommon {
 //=============================================================================
 class FilterActionDelete : public FilterActionWithNone
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     explicit FilterActionDelete( QObject *parent = 0 );
-    virtual ReturnCode process( ItemContext &context ) const;
-    virtual SearchRule::RequiredPart requiredPart() const;
+    ReturnCode process( ItemContext &context, bool applyOnOutbound ) const;
+    SearchRule::RequiredPart requiredPart() const;
     static FilterAction* newAction();
     QWidget* createParamWidget( QWidget *parent ) const;
+    QString sieveCode() const;
 };
 
 }
