@@ -38,10 +38,8 @@ using MailCommon::FilterImporterExporter;
 #include <Akonadi/AgentType>
 #include <Akonadi/ItemFetchJob>
 
-#include <KComboBox>
 #include <KConfigGroup>
 #include <KDebug>
-#include <KIconDialog>
 #include <KIconLoader>
 #include <KInputDialog>
 #include <KJob>
@@ -52,6 +50,7 @@ using MailCommon::FilterImporterExporter;
 #include <KPushButton>
 #include <KTabWidget>
 #include <KWindowSystem>
+#include <KIconButton>
 
 #include <QApplication>
 #include <QHeaderView>
@@ -67,6 +66,7 @@ using MailCommon::FilterImporterExporter;
 #include <QShortcut>
 #include <QSplitter>
 #include <QPointer>
+#include <QKeyEvent>
 
 Q_DECLARE_METATYPE(MailCommon::FilterImporterExporter::FilterType)
 using namespace MailCommon;
@@ -627,6 +627,24 @@ void KMFilterDialog::accept()
     }
 }
 
+bool KMFilterDialog::event(QEvent* e)
+{
+    // Close the bar when pressing Escape.
+    // Not using a QShortcut for this because it could conflict with
+    // window-global actions (e.g. Emil Sedgh binds Esc to "close tab").
+    // With a shortcut override we can catch this before it gets to kactions.
+    const bool shortCutOverride = (e->type() == QEvent::ShortcutOverride);
+    if (shortCutOverride || e->type() == QEvent::KeyPress ) {
+        QKeyEvent* kev = static_cast<QKeyEvent* >(e);
+        if (kev->key() == Qt::Key_Escape) {
+            e->ignore();
+            return true;
+        }
+    }
+    return KDialog::event(e);
+}
+
+
 void KMFilterDialog::slotApply()
 {
     enableButtonApply( false );
@@ -1723,4 +1741,3 @@ void KMFilterDialog::slotExportAsSieveScript()
 
 }
 
-#include "kmfilterdialog.moc"
