@@ -146,10 +146,10 @@ void FavoriteCollectionWidget::slotChangeMode(bool)
 
     switch(mode) {
     case MailCommon::MailCommonSettings::EnumFavoriteCollectionViewMode::IconMode:
-        setViewMode(IconMode);
+        changeViewMode(IconMode);
         break;
     case MailCommon::MailCommonSettings::EnumFavoriteCollectionViewMode::ListMode:
-        setViewMode(ListMode);
+        changeViewMode(ListMode);
         break;
     }
 
@@ -157,6 +157,13 @@ void FavoriteCollectionWidget::slotChangeMode(bool)
     MailCommon::MailCommonSettings::self()->writeConfig();
 }
 
+void FavoriteCollectionWidget::changeViewMode(QListView::ViewMode mode)
+{
+    setViewMode(mode);
+    setDragEnabled(true);
+    setAcceptDrops(true);
+}
+
 void FavoriteCollectionWidget::slotChangeIconSize(bool )
 {
     QAction *act = dynamic_cast< QAction * >( sender() );
