@@ -34,7 +34,7 @@ class QTimer;
 
 namespace Akonadi
 {
-  class MessageStatus;
+class MessageStatus;
 }
 
 namespace MessageList
@@ -63,26 +63,26 @@ class Widget;
  */
 class MESSAGELIST_EXPORT View : public QTreeView
 {
-  friend class Model;
-  friend class ModelPrivate;
-  Q_OBJECT
+    friend class Model;
+    friend class ModelPrivate;
+    Q_OBJECT
 public:
-  explicit View( Widget *parent );
-  ~View();
+    explicit View( Widget *parent );
+    ~View();
 
-  /**
+    /**
    * Returns the Model attacched to this View. You probably never need to manipulate
    * it directly.
    */
-  Model * model() const;
+    Model * model() const;
 
-  /**
+    /**
    * Returns the Delegate attacched to this View. You probably never need to manipulate
    * it directly. Model uses it to obtain size hints.
    */
-  Delegate * delegate() const;
+    Delegate * delegate() const;
 
-  /**
+    /**
    * Sets the StorageModel to be displayed in this view. The StorageModel may be 0 (so no content is displayed).
    * Setting the StorageModel will obviously trigger a view reload.
    * Be sure to set the Aggregation and the Theme BEFORE calling this function.
@@ -90,72 +90,72 @@ public:
    * Pre-selection is the action of automatically selecting a message just after the folder
    * has finished loading. See Model::setStorageModel() for more information.
    */
-  void setStorageModel( StorageModel * storageModel, PreSelectionMode preSelectionMode = PreSelectLastSelected );
+    void setStorageModel( StorageModel * storageModel, PreSelectionMode preSelectionMode = PreSelectLastSelected );
 
-  /**
+    /**
    * Returns the currently displayed StorageModel. May be 0.
    */
-  StorageModel * storageModel() const;
+    StorageModel * storageModel() const;
 
-  /**
+    /**
    * Sets the aggregation for this view.
    * Does not trigger a reload of the view: you *MUST* trigger it manually.
    */
-  void setAggregation( const Aggregation * aggregation );
+    void setAggregation( const Aggregation * aggregation );
 
-  /**
+    /**
    * Sets the specified theme for this view.
    * Does not trigger a reload of the view: you *MUST* trigger it manually.
    */
-  void setTheme( Theme * theme );
+    void setTheme( Theme * theme );
 
-  /**
+    /**
    * Sets the specified sort order.
    * Does not trigger a reload of the view: you *MUST* trigger it manually.
    */
-  void setSortOrder( const SortOrder * sortOrder );
+    void setSortOrder( const SortOrder * sortOrder );
 
-  /**
+    /**
    * Triggers a reload of the view in order to re-display the current folder.
    * Call this function after changing the Aggregation or the Theme.
    */
-  void reload();
+    void reload();
 
-  /**
+    /**
    * Returns the current MessageItem (that is bound to current StorageModel).
    * May return 0 if there is no current message or no current StorageModel.
    * If the current message item isn't currently selected (so is only focused)
    * then it's selected when this function is called, unless selectIfNeeded is false.
    */
-  MessageItem * currentMessageItem( bool selectIfNeeded = true ) const;
+    MessageItem * currentMessageItem( bool selectIfNeeded = true ) const;
 
-  /**
+    /**
    * Returns the current Item (that is bound to current StorageModel).
    * May return 0 if there is no current item or no current StorageModel.
    * If the current item isn't currently selected (so is only focused)
    * then it's selected when this function is called.
    */
-  Item * currentItem() const;
+    Item * currentItem() const;
 
-  /**
+    /**
    * Sets the current message item.
    */
-  void setCurrentMessageItem( MessageItem * it, bool center = false );
+    void setCurrentMessageItem( MessageItem * it, bool center = false );
 
-  /**
+    /**
    * Returns true if the specified item is currently displayed in the tree
    * and has all the parents expanded. This means that the user can
    * see the message (by eventually scrolling the view).
    */
-  bool isDisplayedWithParentsExpanded( Item * it ) const;
+    bool isDisplayedWithParentsExpanded( Item * it ) const;
 
-  /**
+    /**
    * Makes sure that the specified is currently viewable by the user.
    * This means that the user can see the message (by eventually scrolling the view).
    */
-  void ensureDisplayedWithParentsExpanded( Item * it );
+    void ensureDisplayedWithParentsExpanded( Item * it );
 
-  /**
+    /**
    * Returns the currently selected MessageItems (bound to current StorageModel).
    * The list may be empty if there are no selected messages or no StorageModel.
    *
@@ -166,9 +166,9 @@ public:
    * to the main even loop. Don't store it for any longer. If you need to reference
    * this set of messages at a later stage then take a look at createPersistentSet().
    */
-  QList< MessageItem * > selectionAsMessageItemList( bool includeCollapsedChildren = true ) const;
+    QList< MessageItem * > selectionAsMessageItemList( bool includeCollapsedChildren = true ) const;
 
-  /**
+    /**
    * Returns the MessageItems bound to the current StorageModel that
    * are part of the current thread. The current thread is the thread
    * that contains currentMessageItem().
@@ -178,20 +178,20 @@ public:
    * to the main even loop. Don't store it for any longer. If you need to reference
    * this set of messages at a later stage then take a look at createPersistentSet().
    */
-  QList< MessageItem * > currentThreadAsMessageItemList() const;
+    QList< MessageItem * > currentThreadAsMessageItemList() const;
 
-  /**
+    /**
    * Fast function that determines if the selection is empty
    */
-  bool selectionEmpty() const;
+    bool selectionEmpty() const;
 
-  /**
+    /**
    * Selects the specified MessageItems. The current selection is NOT removed.
    * Use clearSelection() for that purpose.
    */
-  void selectMessageItems( const QList< MessageItem * > &list );
+    void selectMessageItems( const QList< MessageItem * > &list );
 
-  /**
+    /**
    * Creates a persistent set for the specified MessageItems and
    * returns its reference. Later you can use this reference
    * to retrieve the list of MessageItems that are still valid.
@@ -201,58 +201,58 @@ public:
    * while manipulating the view) so be sure to call deletePersistentSet()
    * when you no longer need it.
    */
-  MessageItemSetReference createPersistentSet( const QList< MessageItem * > &items );
+    MessageItemSetReference createPersistentSet( const QList< MessageItem * > &items );
 
-  /**
+    /**
    * Returns the list of MessageItems that are still existing in the
    * set pointed by the specified reference. This list will contain
    * at most the messages that you have passed to createPersistentSet()
    * but may contain less (even 0) if these MessageItem object were removed
    * from the view for some reason.
    */
-  QList< MessageItem * > persistentSetCurrentMessageItemList( MessageItemSetReference ref );
+    QList< MessageItem * > persistentSetCurrentMessageItemList( MessageItemSetReference ref );
 
-  /**
+    /**
    * Deletes the persistent set pointed by the specified reference.
    * If the set does not exist anymore, nothing happens.
    */
-  void deletePersistentSet( MessageItemSetReference ref );
+    void deletePersistentSet( MessageItemSetReference ref );
 
-  /**
+    /**
    * If bMark is true this function marks the messages as "about to be removed"
    * so they appear dimmer and aren't selectable in the view.
    * If bMark is false then this function clears the "about to be removed" state
    * for the specified MessageItems.
    */
-  void markMessageItemsAsAboutToBeRemoved( QList< MessageItem * > &items, bool bMark );
+    void markMessageItemsAsAboutToBeRemoved( QList< MessageItem * > &items, bool bMark );
 
-  /**
+    /**
    * Returns true if the current Aggregation is threaded, false otherwise
    * (or if there is no current Aggregation).
    */
-  bool isThreaded() const;
+    bool isThreaded() const;
 
-  /**
+    /**
    * If expand is true then it expands the current thread, otherwise
    * collapses it.
    */
-  void setCurrentThreadExpanded( bool expand );
+    void setCurrentThreadExpanded( bool expand );
 
-  /**
+    /**
    * If expand is true then it expands all the threads, otherwise
    * collapses them.
    */
-  void setAllThreadsExpanded( bool expand );
+    void setAllThreadsExpanded( bool expand );
 
-  /**
+    /**
    * If expand is true then it expands all the groups (only the toplevel
    * group item: inner threads are NOT expanded). If expand is false
    * then it collapses all the groups. If no grouping is in effect
    * then this function does nothing.
    */
-  void setAllGroupsExpanded( bool expand );
+    void setAllGroupsExpanded( bool expand );
 
-  /**
+    /**
    * Selects the next message item in the view.
    *
    * messageTypeFilter can be used to limit the selection to
@@ -269,14 +269,14 @@ public:
    * \sa MessageList::Core::MessageTypeFilter
    * \sa MessageList::Core::ExistingSelectionBehaviour
    */
-  bool selectNextMessageItem(
-      MessageTypeFilter messageTypeFilter,
-      ExistingSelectionBehaviour existingSelectionBehaviour,
-      bool centerItem,
-      bool loop
-    );
+    bool selectNextMessageItem(
+            MessageTypeFilter messageTypeFilter,
+            ExistingSelectionBehaviour existingSelectionBehaviour,
+            bool centerItem,
+            bool loop
+            );
 
-  /**
+    /**
    * Selects the previous message item in the view.
    *
    * messageTypeFilter can be used to limit the selection to
@@ -293,14 +293,14 @@ public:
    * \sa MessageList::Core::MessageTypeFilter
    * \sa MessageList::Core::ExistingSelectionBehaviour
    */
-  bool selectPreviousMessageItem(
-      MessageTypeFilter messageTypeFilter,
-      ExistingSelectionBehaviour existingSelectionBehaviour,
-      bool centerItem,
-      bool loop
-    );
+    bool selectPreviousMessageItem(
+            MessageTypeFilter messageTypeFilter,
+            ExistingSelectionBehaviour existingSelectionBehaviour,
+            bool centerItem,
+            bool loop
+            );
 
-  /**
+    /**
    * Focuses the next message item in the view without actually selecting it.
    *
    * messageTypeFilter can be used to limit the selection to
@@ -311,9 +311,9 @@ public:
    * If loop is true then the "next" algorithm will restart from the beginning
    * of the list if the end is reached, otherwise it will just stop returning false.
    */
-  bool focusNextMessageItem( MessageTypeFilter messageTypeFilter, bool centerItem, bool loop );
+    bool focusNextMessageItem( MessageTypeFilter messageTypeFilter, bool centerItem, bool loop );
 
-  /**
+    /**
    * Focuses the previous message item in the view without actually selecting it.
    * If unread is true then focuses the previous unread message item.
    * If centerItem is true then the specified item will be positioned
@@ -321,167 +321,168 @@ public:
    * If loop is true then the "previous" algorithm will restart from the end
    * of the list if the beginning is reached, otherwise it will just stop returning false.
    */
-  bool focusPreviousMessageItem( MessageTypeFilter messageTypeFilter, bool centerItem, bool loop );
+    bool focusPreviousMessageItem( MessageTypeFilter messageTypeFilter, bool centerItem, bool loop );
 
-  /**
+    /**
    * Selects the currently focused message item. If the currently focused
    * message is already selected (which is very likely) nothing happens.
    * If centerItem is true then the specified item will be positioned
    * at the center of the view, if possible.
    */
-  void selectFocusedMessageItem( bool centerItem );
+    void selectFocusedMessageItem( bool centerItem );
 
-  /**
+    /**
    * Selects the first message item in the view that matches messageTypeFilter.
    * If centerItem is true then the specified item will be positioned
    * at the center of the view, if possible.
    */
-  bool selectFirstMessageItem( MessageTypeFilter messageTypeFilter, bool centerItem );
+    bool selectFirstMessageItem( MessageTypeFilter messageTypeFilter, bool centerItem );
 
-  /**
+    /**
    * Selects the last message item in the view that matches messageTypeFilter.
    * If centerItem is true then the specified item will be positioned
    * at the center of the view, if possible.
    */
-  bool selectLastMessageItem( MessageTypeFilter messageTypeFilter, bool centerItem );
+    bool selectLastMessageItem( MessageTypeFilter messageTypeFilter, bool centerItem );
 
-  /**
+    /**
    * Sets the focus on the quick search line of the currently active tab.
    */
-  void focusQuickSearch();
+    void focusQuickSearch();
 
-  /**
+    /**
    * Returns the Akonadi::MessageStatus in the current quicksearch field.
    */
-  Akonadi::MessageStatus currentFilterStatus() const;
+    QList<Akonadi::MessageStatus> currentFilterStatus() const;
 
-  /**
+    /**
    * Returns the search term in the current quicksearch field.
    */
-  QString currentFilterSearchString() const;
+    QString currentFilterSearchString() const;
 
-  /**
+    /**
    * Called to hide or show the specified row from the view.
    * @reimp
    */
-  virtual void setRowHidden( int row, const QModelIndex & parent, bool hide );
+    virtual void setRowHidden( int row, const QModelIndex & parent, bool hide );
 
-  void sortOrderMenuAboutToShow(KMenu *menu);
+    void sortOrderMenuAboutToShow(KMenu *menu);
 
-  void aggregationMenuAboutToShow(KMenu *menu);
+    void aggregationMenuAboutToShow(KMenu *menu);
 
-  void themeMenuAboutToShow(KMenu *menu);
+    void themeMenuAboutToShow(KMenu *menu);
 
-  void setCollapseItem(const QModelIndex& index);
-  void setExpandItem(const QModelIndex& index);
+    void setCollapseItem(const QModelIndex& index);
+    void setExpandItem(const QModelIndex& index);
 
+    void setQuickSearchClickMessage(const QString &msg);
 
 protected:
-  /**
+    /**
    * Reimplemented in order to catch QHelpEvent
    */
-  virtual bool event( QEvent *e );
+    virtual bool event( QEvent *e );
 
-  /**
+    /**
    * Reimplemented in order to catch palette, font and style changes
    */
-  virtual void changeEvent( QEvent *e );
+    virtual void changeEvent( QEvent *e );
 
-  /**
+    /**
    * Reimplemented in order to apply theme column widths on the first show
    */
-  virtual void showEvent( QShowEvent *e );
+    virtual void showEvent( QShowEvent *e );
 
-  /**
+    /**
    * Reimplemented in order to handle clicks with sub-item precision.
    */
-  virtual void mousePressEvent( QMouseEvent * e );
+    virtual void mousePressEvent( QMouseEvent * e );
 
-  /**
+    /**
    * Reimplemented in order to handle double clicks with sub-item precision.
    */
-  virtual void mouseDoubleClickEvent( QMouseEvent * e );
+    virtual void mouseDoubleClickEvent( QMouseEvent * e );
 
-  /**
+    /**
    * Reimplemented in order to handle DnD
    */
-  virtual void mouseMoveEvent( QMouseEvent * e );
+    virtual void mouseMoveEvent( QMouseEvent * e );
 
-  /**
+    /**
    * Reimplemented in order to handle context menu request via keyboard
    */
-  virtual void contextMenuEvent( QContextMenuEvent* e );
+    virtual void contextMenuEvent( QContextMenuEvent* e );
 
-  /**
+    /**
    * Reimplemented in order to handle message DnD
    */
-  virtual void dragEnterEvent( QDragEnterEvent * e );
+    virtual void dragEnterEvent( QDragEnterEvent * e );
 
-  /**
+    /**
    * Reimplemented in order to handle message DnD
    */
-  virtual void dragMoveEvent( QDragMoveEvent * e );
+    virtual void dragMoveEvent( QDragMoveEvent * e );
 
-  /**
+    /**
    * Reimplemented in order to handle message DnD
    */
-  virtual void dropEvent( QDropEvent * e );
+    virtual void dropEvent( QDropEvent * e );
 
-  /**
+    /**
    * Reimplemented in order to resize columns when header is not visible
    */
-  virtual void resizeEvent( QResizeEvent * e );
+    virtual void resizeEvent( QResizeEvent * e );
 
-  /**
+    /**
    * Reimplemented in order to kill the QTreeView column auto-resizing
    */
-  virtual int sizeHintForColumn( int logicalColumnIndex ) const;
+    virtual int sizeHintForColumn( int logicalColumnIndex ) const;
 
-  /**
+    /**
    * Reimplemented in order to disable update of the geometries
    * while a job step is running (as it takes a very long time and it's called for every item insertion...)
    * TODO: not true anymore, it's called after a delay.
    */
-  virtual void updateGeometries();
+    virtual void updateGeometries();
 
-  /**
+    /**
    * Returns true if the vertical scrollbar should keep to the top or bottom
    * while inserting items.
    */
-  bool isScrollingLocked() const;
+    bool isScrollingLocked() const;
 
-  /**
+    /**
    *  Used to enable/disable the ignoring of updateGeometries() calls.
    */
-  void ignoreUpdateGeometries( bool ignore );
+    void ignoreUpdateGeometries( bool ignore );
 
-  /**
+    /**
    * This is called by the model from inside setFolder().
    * It's called just after the model has been reset but before
    * any row has been inserted. This allows us to call updateThemeColumns() as needed.
    */
-  void modelHasBeenReset();
+    void modelHasBeenReset();
 
-  void modelAboutToEmitLayoutChanged();
-  void modelEmittedLayoutChanged();
+    void modelAboutToEmitLayoutChanged();
+    void modelEmittedLayoutChanged();
 
-  /**
+    /**
    * Recursive helper for currentThreadAsMessageItemList()
    */
-  void appendMessageItemChildren( MessageItem * par, QList< MessageItem * > &list );
+    void appendMessageItemChildren( MessageItem * par, QList< MessageItem * > &list );
 
-  /**
+    /**
    * This is called by the model to insulate us from certain QTreeView signals
    * This is because they may be spurious (caused by Model item rearrangements).
    */
-  void ignoreCurrentChanges( bool ignore );
+    void ignoreCurrentChanges( bool ignore );
 
-  /**
+    /**
    * Expands or collapses the children of the specified item, recursively.
    */
-  void setChildrenExpanded( const Item * parent, bool expand );
+    void setChildrenExpanded( const Item * parent, bool expand );
 
-  /**
+    /**
    * Finds the next message item with respect to the current item.
    * If there is no current item then the search starts from the beginning.
    * Returns 0 if no next message could be found.
@@ -491,9 +492,9 @@ protected:
    * If loop is true then restarts from the beginning if end is
    * reached, otherwise it just returns 0 in this case.
    */
-  Item * nextMessageItem( MessageTypeFilter messageTypeFilter, bool loop );
+    Item * nextMessageItem( MessageTypeFilter messageTypeFilter, bool loop );
 
-  /**
+    /**
    * Finds message item that comes "after" the reference item.
    * If reference item is 0 then the search starts from the beginning.
    * Returns 0 if no next message could be found.
@@ -503,9 +504,9 @@ protected:
    * If loop is true then restarts from the beginning if end is
    * reached, otherwise it just returns 0 in this case.
    */
-  Item * messageItemAfter( Item * referenceItem, MessageTypeFilter messageTypeFilter, bool loop );
+    Item * messageItemAfter( Item * referenceItem, MessageTypeFilter messageTypeFilter, bool loop );
 
-  /**
+    /**
    * Finds the first message item in the view.
    *
    * messageTypeFilter can be used to limit the selection to
@@ -513,10 +514,10 @@ protected:
    *
    * Returns 0 if the view is empty.
    */
-  Item * firstMessageItem( MessageTypeFilter messageTypeFilter )
+    Item * firstMessageItem( MessageTypeFilter messageTypeFilter )
     { return messageItemAfter( 0, messageTypeFilter, false ); }
 
-  /**
+    /**
    * Finds the previous message item with respect to the current item.
    * If there is no current item then the search starts from the end.
    * Returns 0 if no previous message could be found.
@@ -526,15 +527,15 @@ protected:
    * If loop is true then restarts from the end if beginning is
    * reached, otherwise it just return 0 in this case.
    */
-  Item * previousMessageItem( MessageTypeFilter messageTypeFilter, bool loop );
+    Item * previousMessageItem( MessageTypeFilter messageTypeFilter, bool loop );
 
-  /**
+    /**
    * Returns the deepest child that is visible (i.e. not in a collapsed tree) of
    * the specified reference item.
    */
-  Item * deepestExpandedChild( Item * referenceItem ) const;
+    Item * deepestExpandedChild( Item * referenceItem ) const;
 
-  /**
+    /**
    * Finds message item that comes "before" the reference item.
    * If reference item is 0 then the search starts from the end.
    * Returns 0 if no next message could be found.
@@ -544,9 +545,9 @@ protected:
    * If loop is true then restarts from the beginning if end is
    * reached, otherwise it just returns 0 in this case.
    */
-  Item * messageItemBefore( Item * referenceItem, MessageTypeFilter messageTypeFilter, bool loop );
+    Item * messageItemBefore( Item * referenceItem, MessageTypeFilter messageTypeFilter, bool loop );
 
-  /**
+    /**
    * Finds the last message item in the view.
    *
    * messageTypeFilter can be used to limit the selection to
@@ -554,50 +555,50 @@ protected:
    *
    * Returns 0 if the view is empty.
    */
-  Item * lastMessageItem( MessageTypeFilter messageTypeFilter )
+    Item * lastMessageItem( MessageTypeFilter messageTypeFilter )
     { return messageItemBefore( 0, messageTypeFilter, false ); }
 
-  /**
+    /**
    * This is called by Model to signal a start of a lengthy job batch.
    * Note that this is NOT called for jobs that can be completed in a single step.
    */
-  void modelJobBatchStarted();
+    void modelJobBatchStarted();
 
-  /**
+    /**
    * This is called by Model to signal the end of a lengthy job batch.
    * Note that this is NOT called for jobs that can be completed in a single step.
    */
-  void modelJobBatchTerminated();
+    void modelJobBatchTerminated();
 
-  /**
+    /**
    * This is called by Model to signal that the initial loading stage of a newly
    * attached StorageModel is terminated.
    */
-  void modelFinishedLoading();
+    void modelFinishedLoading();
 
-  /**
+    /**
    * Performs a change in the specified MessageItem status.
    * It first applies the change to the cached state in MessageItem and
    * then requests our parent widget to act on the storage.
    */
-  void changeMessageStatus( MessageItem * it, const Akonadi::MessageStatus &set, const Akonadi::MessageStatus &unset );
-  void changeMessageStatusRead( MessageItem *it, bool read );
+    void changeMessageStatus( MessageItem * it, const Akonadi::MessageStatus &set, const Akonadi::MessageStatus &unset );
+    void changeMessageStatusRead( MessageItem *it, bool read );
 
-  /**
+    /**
    * Starts a short-delay timer connected to saveThemeColumnState().
    * Used to accumulate consecutive changes and break out of the call stack
    * up to the main event loop (since in the call stack the column state might be left undefined).
    */
-  void triggerDelayedSaveThemeColumnState();
+    void triggerDelayedSaveThemeColumnState();
 
-  /**
+    /**
    * Starts a short-delay timer connected to applyThemeColumns().
    * Used to accumulate consecutive changes and break out of the call stack
    * up to the main event loop (since multiple resize events tend to be sent by Qt at startup).
    */
-  void triggerDelayedApplyThemeColumns();
+    void triggerDelayedApplyThemeColumns();
 
-  /**
+    /**
    * This is used by the selection functions to grow/shrink the existing selection
    * according to the newly selected item passed as parameter.
    * If movingUp is true then: if the newly selected item is above the current selection top
@@ -605,86 +606,86 @@ protected:
    * newly selected item is below the current selection bottom then the selection is expanded
    * otherwise it's shrunk.
    */
-  void growOrShrinkExistingSelection( const QModelIndex &newSelectedIndex, bool movingUp );
+    void growOrShrinkExistingSelection( const QModelIndex &newSelectedIndex, bool movingUp );
 
 public slots:
-  /**
+    /**
    * Collapses all the group headers (if present in the current Aggregation)
    */
-  void slotCollapseAllGroups();
+    void slotCollapseAllGroups();
 
-  /**
+    /**
    * Expands all the group headers (if present in the current Aggregation)
    */
-  void slotExpandAllGroups();
+    void slotExpandAllGroups();
 
-  /**
+    /**
    * Expands the currect item.
    * If it's a Message, it expands its thread, if its a group header it expands the group
    */
-  void slotExpandCurrentItem();
+    void slotExpandCurrentItem();
 
-  /**
+    /**
    * Collapses the currect item.
    * If it's a Message, it collapses its thread, if its a group header it collapses the group
    */
-  void slotCollapseCurrentItem();
+    void slotCollapseCurrentItem();
 
 protected slots:
 
-  /**
+    /**
    * Handles context menu requests for the header.
    */
-  void slotHeaderContextMenuRequested( const QPoint &pnt );
+    void slotHeaderContextMenuRequested( const QPoint &pnt );
 
-  /**
+    /**
    * Handles the actions of the header context menu for showing/hiding a column.
    */
-  void slotShowHideColumn( int columnIndex );
+    void slotShowHideColumn( int columnIndex );
 
-  /**
+    /**
    * Handles the Adjust Column Sizes action of the header context menu.
    */
-  void slotAdjustColumnSizes();
+    void slotAdjustColumnSizes();
 
-  /**
+    /**
    * Handles the Show Default Columns action of the header context menu.
    */
-  void slotShowDefaultColumns();
+    void slotShowDefaultColumns();
 
-  /**
+    /**
    * Handles the Display Tooltips action of the header context menu.
    */
-  void slotDisplayTooltips( bool showTooltips );
+    void slotDisplayTooltips( bool showTooltips );
 
-  /**
+    /**
    * Handles section resizes in order to save the column widths
    */
-  void slotHeaderSectionResized( int logicalIndex, int oldWidth, int newWidth );
+    void slotHeaderSectionResized( int logicalIndex, int oldWidth, int newWidth );
 
-  /**
+    /**
    * Handles selection item management
    */
-  void slotSelectionChanged( const QItemSelection &current, const QItemSelection & );
+    void slotSelectionChanged( const QItemSelection &current, const QItemSelection & );
 
-  /**
+    /**
    * Saves the state of the columns (width and visility) to the currently selected theme object.
    */
-  void saveThemeColumnState();
+    void saveThemeColumnState();
 
-  /**
+    /**
    * Applies the theme columns to this view.
    * Columns visible by default are shown, the other are hidden.
    * Visible columns are assigned space inside the view by using the size hints and some heuristics.
    */
-  void applyThemeColumns();
+    void applyThemeColumns();
 
 private:
-  /// expand the whole thread (including all child messages)
-  Q_PRIVATE_SLOT(d, void expandFullThread( const QModelIndex& ))
+    /// expand the whole thread (including all child messages)
+    Q_PRIVATE_SLOT(d, void expandFullThread( const QModelIndex& ))
 
-  class Private;
-  Private * d;
+    class Private;
+    Private * d;
 }; // class View
 
 } // namespace Core
