@@ -174,7 +174,6 @@ Widget::~Widget()
 void Widget::changeQuicksearchVisibility(bool show)
 {
     KLineEdit * const lineEdit = d->quickSearchLine->searchEdit();
-    QWidget * const comboBox = d->quickSearchLine->tagFilterComboBox();
     if ( !show ) {
         //if we hide it we do not want to apply the filter,
         //otherwise someone is maybe stuck with x new emails
@@ -191,9 +190,7 @@ void Widget::changeQuicksearchVisibility(bool show)
             resetFilter();
         }
     }
-    lineEdit->setVisible( show );
-    comboBox->setVisible( show );
-    d->quickSearchLine->lockSearch()->setVisible( show );
+    d->quickSearchLine->changeQuicksearchVisibility(show);
     Settings::self()->setShowQuickSearch( show );
 }
 
@@ -984,6 +981,10 @@ void Widget::searchTimerFired()
         d->mFilter = new Filter();
 
     const QString text = d->quickSearchLine->searchEdit()->text();
+    if (!text.isEmpty()) {
+        KCompletion *comp = d->quickSearchLine->searchEdit()->completionObject();
+        comp->addItem(text);
+    }
 
     d->mFilter->setCurrentFolder( d->mCurrentFolder );
     d->mFilter->setSearchString( text, d->quickSearchLine->searchOptions() );
