@@ -231,4 +231,53 @@ void QuickSearchLineTest::shouldSearchToOrFrom()
     QCOMPARE(searchLine.searchOptions(), options);
 }
 
+void QuickSearchLineTest::shouldHideShowWidgetWhenWeChangeVisibility()
+{
+    QuickSearchLine searchLine;
+    searchLine.show();
+
+    QWidget *widget = qFindChild<QWidget *>(&searchLine, QLatin1String("extraoptions"));
+
+    KPushButton *moreButton = qFindChild<KPushButton *>(&searchLine, QLatin1String("moreoptions"));
+    QWidget *quickSearchFilterWidget = qFindChild<QWidget *>(&searchLine, QLatin1String("quicksearchfilterwidget"));
+    searchLine.changeQuicksearchVisibility(false);
+    QCOMPARE(quickSearchFilterWidget->isVisible(), false);
+    QCOMPARE(moreButton->isVisible(), false);
+    QCOMPARE(widget->isVisible(), false);
+    QCOMPARE(searchLine.searchEdit()->isVisible(), false);
+    QCOMPARE(searchLine.tagFilterComboBox()->isVisible(), false);
+
+
+    searchLine.changeQuicksearchVisibility(true);
+    QCOMPARE(quickSearchFilterWidget->isVisible(), false);
+    QCOMPARE(moreButton->isVisible(), true);
+    QCOMPARE(widget->isVisible(), false);
+    QCOMPARE(searchLine.searchEdit()->isVisible(), true);
+    QCOMPARE(searchLine.tagFilterComboBox()->isVisible(), false);
+
+    //Fill Combobox
+    searchLine.tagFilterComboBox()->addItems(QStringList()<<QLatin1String("1")<<QLatin1String("2"));
+    searchLine.changeQuicksearchVisibility(false);
+    QCOMPARE(searchLine.tagFilterComboBox()->isVisible(), false);
+
+    searchLine.changeQuicksearchVisibility(true);
+    QCOMPARE(searchLine.tagFilterComboBox()->isVisible(), true);
+}
+
+void QuickSearchLineTest::shouldNotShowComboboxWhenWeAddNewItemWhenWeHiddedQuickSearchBarWidget()
+{
+    QuickSearchLine searchLine;
+    searchLine.show();
+    searchLine.tagFilterComboBox()->addItems(QStringList()<<QLatin1String("1")<<QLatin1String("2"));
+    searchLine.updateComboboxVisibility();
+    QCOMPARE(searchLine.tagFilterComboBox()->isVisible(), true);
+
+    searchLine.changeQuicksearchVisibility(false);
+    searchLine.tagFilterComboBox()->addItems(QStringList()<<QLatin1String("1")<<QLatin1String("2"));
+    searchLine.updateComboboxVisibility();
+    QCOMPARE(searchLine.tagFilterComboBox()->isVisible(), false);
+
+}
+
+
 QTEST_KDEMAIN( QuickSearchLineTest, GUI )
