@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,10 +20,12 @@
 
 #include <QWidget>
 #include "messageviewer_export.h"
-
-class QTreeWidget;
 class QWebFrame;
+namespace PimCommon {
+class CustomTreeView;
+}
 namespace MessageViewer {
+
 class MESSAGEVIEWER_EXPORT AdBlockBlockableItemsWidget : public QWidget
 {
     Q_OBJECT
@@ -75,7 +77,7 @@ private:
     void adaptSrc(QString &src,const QString &hostName);
 
 private:
-    QTreeWidget *mListItems;
+    PimCommon::CustomTreeView *mListItems;
 };
 }
 
