@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,7 +17,7 @@
 
 #include "adblocklistwidget.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <KGlobalSettings>
 
 #include <QPainter>
@@ -65,4 +65,3 @@ void AdBlockListWidget::paintEvent( QPaintEvent *event )
 }
 
 
-#include "adblocklistwidget.moc"
