@@ -1,4 +1,4 @@
-/* Copyright (C) 2012,2013 Laurent Montel <montel@kde.org>
+/* Copyright (C) 2012,2013,2014 Laurent Montel <montel@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -30,7 +30,7 @@ ContactDisplayMessageMemento::ContactDisplayMessageMemento( const QString &email
 {
     if( !emailAddress.isEmpty() ) {
         Akonadi::ContactSearchJob *searchJob = new Akonadi::ContactSearchJob();
-        searchJob->setQuery( Akonadi::ContactSearchJob::Email, emailAddress.toLower() );
+        searchJob->setQuery( Akonadi::ContactSearchJob::Email, emailAddress.toLower(), Akonadi::ContactSearchJob::ExactMatch );
         connect( searchJob, SIGNAL(result(KJob*)),
                  this, SLOT(slotSearchJobFinished(KJob*)) );
     } else {
@@ -79,16 +79,6 @@ bool ContactDisplayMessageMemento::allowToRemoteContent() const
     return mMailAllowToRemoteContent;
 }
 
-bool ContactDisplayMessageMemento::forceToHtml() const
-{
-    return ( mForceDisplayTo == Viewer::Html );
-}
-
-bool ContactDisplayMessageMemento::forceToText() const
-{
-    return ( mForceDisplayTo == Viewer::Text );
-}
-
 void ContactDisplayMessageMemento::searchPhoto(const KABC::AddresseeList &list)
 {
     Q_FOREACH (const KABC::Addressee &addressee, list) {
