@@ -82,11 +82,6 @@
 
 #include <sys/utsname.h>
 
-#ifdef Q_OS_WINCE
-#include <windows.h>
-#include <Shellapi.h>
-#endif
-
 #define VIEW(model) {                        \
   QTreeView *view = new QTreeView( this );   \
   view->setWindowFlags( Qt::Window );        \
@@ -732,35 +727,15 @@ void KDeclarativeMainView::openDocumentation( const QString &relativePath )
 
 void KDeclarativeMainView::openLicenses()
 {
-#ifdef Q_WS_MAEMO_5
-  d->openHtml( KGlobal::dirs()->findResource( "data", QLatin1String("kontact-touch/licenses.html") ) );
-#else
   KDeclarativeMainView::openAttachment( KGlobal::dirs()->findResource( "data", QLatin1String("kontact-touch/licenses.pdf") ),
                                         QLatin1String( "application/pdf" ) );
-#endif
 }
 
 void KDeclarativeMainView::openAttachment( const QString &url, const QString &mimeType )
 {
   qDebug() << "opening attachment: " << url;
-#ifndef Q_OS_WINCE
-   KRun::runUrl( KUrl( url ), mimeType, this );
-#else
-   SHELLEXECUTEINFO execinfo;
-   WCHAR wfile[2048];
-   int num = KUrl(url).toLocalFile().toWCharArray(wfile);
-   wfile[num] = '\0';
 
-   memset(&execinfo, 0, sizeof(SHELLEXECUTEINFO));
-   execinfo.cbSize = sizeof(SHELLEXECUTEINFO);
-   execinfo.lpVerb = L"open";
-   execinfo.lpFile = wfile;
-   execinfo.lpParameters = L"";
-   execinfo.lpDirectory = L"";
-   execinfo.nShow = SW_SHOWNORMAL;
-   execinfo.fMask = SEE_MASK_NOCLOSEPROCESS; // don't close process after ShellExecuteEx function exits
-   ShellExecuteEx(&execinfo);
-#endif
+  KRun::runUrl( KUrl( url ), mimeType, this );
 }
 
 void KDeclarativeMainView::saveAttachment( const QString &url, const QString &defaultFileName )
@@ -1030,4 +1005,4 @@ AgentActionManager* KDeclarativeMainView::createAgentActionManager(QItemSelectio
   return manager;
 }
 
-#include "kdeclarativemainview.moc"
+#include "moc_kdeclarativemainview.cpp"
