@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -23,12 +23,10 @@ class QTextCursor;
 class QTextEdit;
 namespace NoteShared
 {
-class NOTESHARED_EXPORT NoteEditorUtils
-{
-public:
-    NoteEditorUtils();
-    void addCheckmark( QTextCursor &cursor);
-    void insertDate( QTextEdit *editor );
-};
+namespace NoteEditorUtils {
+NOTESHARED_EXPORT void addCheckmark( QTextCursor &cursor);
+NOTESHARED_EXPORT void insertDate( QTextEdit *editor );
 }
+}
+
 #endif // NOTEEDITORUTILS_H
