@@ -69,6 +69,9 @@ void CreateNewNoteJob::start()
         QPointer<SelectedNotefolderDialog> dlg = new SelectedNotefolderDialog(mWidget);
         if (dlg->exec()) {
             col = dlg->selectedCollection();
+        } else {
+            deleteLater();
+            return;
         }
         if (dlg->useFolderByDefault()) {
             NoteShared::NoteSharedGlobalConfig::self()->setDefaultFolder(col.id());
@@ -85,7 +88,7 @@ void CreateNewNoteJob::start()
 void CreateNewNoteJob::slotFetchCollection(KJob* job)
 {
     if (job->error()) {
-        qDebug()<<" Error during fetch";
+        qDebug()<<" Error during fetch: "<<job->errorString();
         deleteLater();
         return;
     }
