@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2013 Montel Laurent <montel@kde.org>
   code based on calligra autocorrection.
   
   This program is free software; you can redistribute it and/or modify it
@@ -63,7 +63,7 @@ AutoCorrection::~AutoCorrection()
 {
 }
 
-void AutoCorrection::selectPreviousWord(QTextCursor &cursor, int cursorPosition)
+void AutoCorrection::selectWord(QTextCursor &cursor, int cursorPosition)
 {
     cursor.setPosition(cursorPosition);
     QTextBlock block = cursor.block();
@@ -91,51 +91,33 @@ void AutoCorrection::selectPreviousWord(QTextCursor &cursor, int cursorPosition)
 }
 
 
-bool AutoCorrection::autocorrect(bool htmlMode, QTextDocument& document, int &position)
+void AutoCorrection::autocorrect(bool htmlMode, QTextDocument& document, int &position)
 {
     if (!mEnabled)
-        return true;
+        return;
     mCursor =  QTextCursor(&document);
-    mCursor.setPosition(position);
-
-    //If we already have a space not necessary to look at other autocorrect feature.
-    if (!singleSpaces())
-        return false;
-
     int oldPosition = position;
-    selectPreviousWord(mCursor,position);
+    selectWord(mCursor,position);
     mWord = mCursor.selectedText();
-    if (mWord.isEmpty()) {
-        return true;
-    }
+    if (mWord.isEmpty())
+        return;
     mCursor.beginEditBlock();
     bool done = false;
     if (htmlMode) {
         done = autoFormatURLs();
         if (!done) {
             done = autoBoldUnderline();
-            //We replace */- by format => remove cursor position by 2
-            if (done) {
-                oldPosition -= 2;
-            }
         }
         if (!done) {
             superscriptAppendix();
         }
     }
-    if (!done) {
+    if (!done)
+        done = singleSpaces();
+    if (!done)
         done = autoFractions();
-        //We replace three characters with 1
-        if (done) {
-            oldPosition -= 2;
-        }
-    }
-    if (!done) {
-        const int newPos = advancedAutocorrect();
-        if (newPos != -1) {
-            oldPosition = newPos;
-        }
-    }
+    if (!done)
+        advancedAutocorrect();
     if (!done)
         uppercaseFirstCharOfSentence();
     if (!done)
@@ -149,7 +131,6 @@ bool AutoCorrection::autocorrect(bool htmlMode, QTextDocument& document, int &po
         mCursor.insertText(mWord);
     position = oldPosition;
     mCursor.endEditBlock();
-    return true;
 }
 
 void AutoCorrection::readConfig()
@@ -211,91 +192,6 @@ void AutoCorrection::setAutocorrectEntries(const QHash<QString, QString> &entrie
     mAutocorrectEntries = entries;
 }
 
-void AutoCorrection::setAutoFormatUrl(bool b)
-{
-    mAutoFormatUrl = b;
-}
-
-void AutoCorrection::setAutoBoldUnderline(bool b)
-{
-    mAutoBoldUnderline = b;
-}
-
-void AutoCorrection::setSuperScript(bool b)
-{
-    mSuperScriptAppendix = b;
-}
-
-void AutoCorrection::setAddNonBreakingSpace(bool b)
-{
-    mAddNonBreakingSpace = b;
-}
-
-bool AutoCorrection::isEnabledAutoCorrection() const
-{
-    return mEnabled;
-}
-
-bool AutoCorrection::isUppercaseFirstCharOfSentence() const
-{
-    return mUppercaseFirstCharOfSentence;
-}
-
-bool AutoCorrection::isFixTwoUppercaseChars() const
-{
-    return mFixTwoUppercaseChars;
-}
-
-bool AutoCorrection::isSingleSpaces() const
-{
-    return mSingleSpaces;
-}
-
-bool AutoCorrection::isAutoFractions() const
-{
-    return mAutoFractions;
-}
-
-bool AutoCorrection::isCapitalizeWeekDays() const
-{
-    return mCapitalizeWeekDays;
-}
-
-bool AutoCorrection::isReplaceDoubleQuotes() const
-{
-    return mReplaceDoubleQuotes;
-}
-
-bool AutoCorrection::isReplaceSingleQuotes() const
-{
-    return mReplaceSingleQuotes;
-}
-
-bool AutoCorrection::isAdvancedAutocorrect() const
-{
-    return mAdvancedAutocorrect;
-}
-
-bool AutoCorrection::isAutoFormatUrl() const
-{
-    return mAutoFormatUrl;
-}
-
-bool AutoCorrection::isAutoBoldUnderline() const
-{
-    return mAutoBoldUnderline;
-}
-
-bool AutoCorrection::isSuperScript() const
-{
-    return mSuperScriptAppendix;
-}
-
-bool AutoCorrection::isAddNonBreakingSpace() const
-{
-    return mAddNonBreakingSpace;
-}
-
 AutoCorrection::TypographicQuotes AutoCorrection::typographicDefaultSingleQuotes() const
 {
     AutoCorrection::TypographicQuotes quote;
@@ -387,6 +283,7 @@ bool AutoCorrection::autoBoldUnderline()
 {
     if (!mAutoBoldUnderline)
         return false;
+
     const QString trimmed = mWord.trimmed();
 
     if (trimmed.length() < 3)
@@ -412,6 +309,7 @@ bool AutoCorrection::autoBoldUnderline()
         // if no letter/number found, don't apply autocorrection like in OOo 2.x
         if (!foundLetterNumber)
             return false;
+
         mCursor.setPosition(startPos);
         mCursor.setPosition(startPos + trimmed.length(), QTextCursor::KeepAnchor);
         mCursor.insertText(replacement);
@@ -426,7 +324,15 @@ bool AutoCorrection::autoBoldUnderline()
 
         // to avoid the selection being replaced by mWord
         mWord = mCursor.selectedText();
-        return true;
+
+        // don't do this again if the text is already underlined and bold
+        if (mCursor.charFormat().fontUnderline()
+                && mCursor.charFormat().fontWeight() == QFont::Bold
+                && mCursor.charFormat().fontStrikeOut()) {
+            return true;
+        } else {
+            return autoBoldUnderline();
+        }
     }
     else
         return false;
@@ -575,20 +481,20 @@ void AutoCorrection::fixTwoUppercaseChars()
 }
 
 
-//Return true if we can add space
 bool AutoCorrection::singleSpaces()
 {
     if (!mSingleSpaces)
-        return true;
-    if (!mCursor.atBlockStart()) {
+        return false;
+    if (!mCursor.atBlockStart() && mWord.length() == 1 && mWord.at(0) == QLatin1Char(' ')) {
         // then when the prev char is also a space, don't insert one.
         const QTextBlock block = mCursor.block();
         const QString text = block.text();
         if (text.at(mCursor.position() -1 - block.position()) == QLatin1Char(' ')) {
-            return false;
+            mWord.clear();
+            return true;
         }
     }
-    return true;
+    return false;
 }
 
 void AutoCorrection::capitalizeWeekDays()
@@ -642,17 +548,17 @@ void AutoCorrection::uppercaseFirstCharOfSentence()
 
         while (constIter != text.constBegin()) {
             while (constIter != text.begin() && constIter->isSpace()) {
-                --constIter;
-                --position;
+                constIter--;
+                position--;
             }
 
             if (constIter != text.constBegin() && (*constIter == QLatin1Char('.') || *constIter == QLatin1Char('!') || *constIter == QLatin1Char('?'))) {
                 constIter--;
                 while (constIter != text.constBegin() && !(constIter->isLetter())) {
-                    --position;
-                    --constIter;
+                    position--;
+                    constIter--;
                 }
-                selectPreviousWord(mCursor, --position);
+                selectWord(mCursor, --position);
                 const QString prevWord = mCursor.selectedText();
 
                 // search for exception
@@ -700,10 +606,10 @@ bool AutoCorrection::autoFractions()
     return true;
 }
 
-int AutoCorrection::advancedAutocorrect()
+void AutoCorrection::advancedAutocorrect()
 {
     if (!mAdvancedAutocorrect)
-        return -1;
+        return;
 
     const int startPos = mCursor.selectionStart();
     const int length = mWord.length();
@@ -712,7 +618,7 @@ int AutoCorrection::advancedAutocorrect()
     QString actualWord = trimmedWord;
 
     if (actualWord.isEmpty())
-        return -1;
+        return;
 
     // If the last char is punctuation, drop it for now
     bool hasPunctuation = false;
@@ -763,11 +669,8 @@ int AutoCorrection::advancedAutocorrect()
         mCursor.setPosition(startPos + length, QTextCursor::KeepAnchor);
         mCursor.insertText(mWord);
         mCursor.setPosition(startPos); // also restore the selection
-        const int newPosition = startPos + mWord.length();
-        mCursor.setPosition(newPosition, QTextCursor::KeepAnchor);
-        return newPosition;
+        mCursor.setPosition(startPos + mWord.length(), QTextCursor::KeepAnchor);
     }
-    return -1;
 }
 
 void AutoCorrection::replaceTypographicQuotes()
@@ -1046,16 +949,6 @@ QString AutoCorrection::language() const
     return mAutoCorrectLang;
 }
 
-AutoCorrection::TypographicQuotes AutoCorrection::typographicSingleQuotes() const
-{
-    return mTypographicSingleQuotes;
-}
-
-AutoCorrection::TypographicQuotes AutoCorrection::typographicDoubleQuotes() const
-{
-    return mTypographicDoubleQuotes;
-}
-
 void AutoCorrection::setLanguage(const QString &lang, bool forceGlobal)
 {
     if (mAutoCorrectLang != lang || forceGlobal) {
@@ -1065,61 +958,6 @@ void AutoCorrection::setLanguage(const QString &lang, bool forceGlobal)
     }
 }
 
-void AutoCorrection::setEnabledAutoCorrection(bool b)
-{
-    mEnabled = b;
-}
-
-void AutoCorrection::setUppercaseFirstCharOfSentence(bool b)
-{
-    mUppercaseFirstCharOfSentence = b;
-}
-
-void AutoCorrection::setFixTwoUppercaseChars(bool b)
-{
-    mFixTwoUppercaseChars = b;
-}
-
-void AutoCorrection::setSingleSpaces(bool b)
-{
-    mSingleSpaces = b;
-}
-
-void AutoCorrection::setAutoFractions(bool b)
-{
-    mAutoFractions = b;
-}
-
-void AutoCorrection::setCapitalizeWeekDays(bool b)
-{
-    mCapitalizeWeekDays = b;
-}
-
-void AutoCorrection::setReplaceDoubleQuotes(bool b)
-{
-    mReplaceDoubleQuotes = b;
-}
-
-void AutoCorrection::setReplaceSingleQuotes(bool b)
-{
-    mReplaceSingleQuotes = b;
-}
-
-void AutoCorrection::setAdvancedAutocorrect(bool b)
-{
-    mAdvancedAutocorrect = b;
-}
-
-void AutoCorrection::setTypographicSingleQuotes(AutoCorrection::TypographicQuotes singleQuote)
-{
-    mTypographicSingleQuotes = singleQuote;
-}
-
-void AutoCorrection::setTypographicDoubleQuotes(AutoCorrection::TypographicQuotes doubleQuote)
-{
-    mTypographicDoubleQuotes = doubleQuote;
-}
-
 bool AutoCorrection::isFrenchLanguage() const
 {
     return (mAutoCorrectLang == QLatin1String("FR_fr") || mAutoCorrectLang == QLatin1String("fr"));
