@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,7 +17,7 @@
 
 #include "abstractshorturl.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 using namespace PimCommon;
 AbstractShortUrl::AbstractShortUrl(QObject *parent)
@@ -42,11 +42,11 @@ void AbstractShortUrl::shortUrl(const QString &url)
 void AbstractShortUrl::slotErrorFound(QNetworkReply::NetworkError error)
 {
     mErrorFound = true;
-    Q_EMIT shortUrlFailed(i18n("Error reported by server: \'%1\'", error));
+    QNetworkReply *reply = qobject_cast<QNetworkReply*>(sender());
+    Q_EMIT shortUrlFailed(i18n("Error reported by server:\n\'%1\'", (reply ? reply->errorString() : QString::number(error)) ));
 }
 
-void AbstractShortUrl::slotShortUrlFinished(QNetworkReply *reply)
+void AbstractShortUrl::slotShortUrlFinished(QNetworkReply */*reply*/)
 {
 }
 
-#include "abstractshorturl.moc"
