@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -29,9 +29,11 @@ public:
     ~GoogleShortUrl();
 
     void start();
+    QString shortUrlName() const;
 
 private Q_SLOTS:
     void slotShortUrlFinished(QNetworkReply*reply);
+    void slotSslErrors(QNetworkReply *, const QList<QSslError> &error);    
 };
 }
 
