@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,10 +18,7 @@
 
 #include "tinyurlshorturl.h"
 
-#include <QNetworkAccessManager>
 #include <QNetworkRequest>
-#include <QUrl>
-#include <QDebug>
 
 
 using namespace PimCommon;
@@ -35,6 +32,11 @@ TinyurlShortUrl::~TinyurlShortUrl()
 {
 }
 
+QString TinyurlShortUrl::shortUrlName() const
+{
+    return QLatin1String("TinyURL.com");
+}
+
 void TinyurlShortUrl::start()
 {
     const QString requestUrl = QString::fromLatin1("http://tinyurl.com/api-create.php?url=%1").arg(mOriginalUrl);
@@ -54,4 +56,3 @@ void TinyurlShortUrl::slotShortUrlFinished(QNetworkReply *reply)
     }
 }
 
-#include "tinyurlshorturl.moc"
