@@ -66,7 +66,7 @@ void DropBoxJob::initializeToken(const QString &accessToken, const QString &acce
 
 void DropBoxJob::requestTokenAccess()
 {
-    mActionType = PimCommon::StorageServiceAbstract::RequestToken;
+    mActionType = PimCommon::StorageServiceAbstract::RequestTokenAction;
     mError = false;
     QNetworkRequest request(QUrl(mApiPath + QLatin1String("oauth/request_token")));
     request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
@@ -86,7 +86,7 @@ void DropBoxJob::requestTokenAccess()
 
 void DropBoxJob::getTokenAccess()
 {
-    mActionType = PimCommon::StorageServiceAbstract::AccessToken;
+    mActionType = PimCommon::StorageServiceAbstract::AccessTokenAction;
     mError = false;
     QNetworkRequest request(QUrl(mApiPath + QLatin1String("oauth/access_token")));
     request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
@@ -119,37 +119,37 @@ void DropBoxJob::slotSendDataFinished(QNetworkReply *reply)
             case PimCommon::StorageServiceAbstract::NoneAction:
                 deleteLater();
                 break;
-            case PimCommon::StorageServiceAbstract::RequestToken:
+            case PimCommon::StorageServiceAbstract::RequestTokenAction:
                 Q_EMIT authorizationFailed(errorStr);
                 deleteLater();
                 break;
-            case PimCommon::StorageServiceAbstract::AccessToken:
+            case PimCommon::StorageServiceAbstract::AccessTokenAction:
                 Q_EMIT authorizationFailed(errorStr);
                 deleteLater();
                 break;
-            case PimCommon::StorageServiceAbstract::UploadFile:
+            case PimCommon::StorageServiceAbstract::UploadFileAction:
                 Q_EMIT uploadFileFailed(errorStr);
                 errorMessage(mActionType, errorStr);
                 deleteLater();
                 break;
-            case PimCommon::StorageServiceAbstract::DownLoadFile:
+            case PimCommon::StorageServiceAbstract::DownLoadFileAction:
                 Q_EMIT downLoadFileFailed(errorStr);
                 errorMessage(mActionType, errorStr);
                 deleteLater();
                 break;
-            case PimCommon::StorageServiceAbstract::CreateFolder:
-            case PimCommon::StorageServiceAbstract::AccountInfo:
-            case PimCommon::StorageServiceAbstract::ListFolder:
-            case PimCommon::StorageServiceAbstract::ShareLink:
-            case PimCommon::StorageServiceAbstract::CreateServiceFolder:
-            case PimCommon::StorageServiceAbstract::DeleteFile:
-            case PimCommon::StorageServiceAbstract::DeleteFolder:
-            case PimCommon::StorageServiceAbstract::RenameFolder:
-            case PimCommon::StorageServiceAbstract::RenameFile:
-            case PimCommon::StorageServiceAbstract::MoveFolder:
-            case PimCommon::StorageServiceAbstract::MoveFile:
-            case PimCommon::StorageServiceAbstract::CopyFile:
-            case PimCommon::StorageServiceAbstract::CopyFolder:
+            case PimCommon::StorageServiceAbstract::CreateFolderAction:
+            case PimCommon::StorageServiceAbstract::AccountInfoAction:
+            case PimCommon::StorageServiceAbstract::ListFolderAction:
+            case PimCommon::StorageServiceAbstract::ShareLinkAction:
+            case PimCommon::StorageServiceAbstract::CreateServiceFolderAction:
+            case PimCommon::StorageServiceAbstract::DeleteFileAction:
+            case PimCommon::StorageServiceAbstract::DeleteFolderAction:
+            case PimCommon::StorageServiceAbstract::RenameFolderAction:
+            case PimCommon::StorageServiceAbstract::RenameFileAction:
+            case PimCommon::StorageServiceAbstract::MoveFolderAction:
+            case PimCommon::StorageServiceAbstract::MoveFileAction:
+            case PimCommon::StorageServiceAbstract::CopyFileAction:
+            case PimCommon::StorageServiceAbstract::CopyFolderAction:
                 errorMessage(mActionType, errorStr);
                 deleteLater();
                 break;
@@ -163,55 +163,55 @@ void DropBoxJob::slotSendDataFinished(QNetworkReply *reply)
     switch(mActionType) {
     case PimCommon::StorageServiceAbstract::NoneAction:
         break;
-    case PimCommon::StorageServiceAbstract::RequestToken:
+    case PimCommon::StorageServiceAbstract::RequestTokenAction:
         parseRequestToken(data);
         break;
-    case PimCommon::StorageServiceAbstract::AccessToken:
+    case PimCommon::StorageServiceAbstract::AccessTokenAction:
         parseResponseAccessToken(data);
         break;
-    case PimCommon::StorageServiceAbstract::UploadFile:
+    case PimCommon::StorageServiceAbstract::UploadFileAction:
         parseUploadFile(data);
         break;
-    case PimCommon::StorageServiceAbstract::CreateFolder:
+    case PimCommon::StorageServiceAbstract::CreateFolderAction:
         parseCreateFolder(data);
         break;
-    case PimCommon::StorageServiceAbstract::AccountInfo:
+    case PimCommon::StorageServiceAbstract::AccountInfoAction:
         parseAccountInfo(data);
         break;
-    case PimCommon::StorageServiceAbstract::ListFolder:
+    case PimCommon::StorageServiceAbstract::ListFolderAction:
         parseListFolder(data);
         break;
-    case PimCommon::StorageServiceAbstract::ShareLink:
+    case PimCommon::StorageServiceAbstract::ShareLinkAction:
         parseShareLink(data);
         break;
-    case PimCommon::StorageServiceAbstract::CreateServiceFolder:
+    case PimCommon::StorageServiceAbstract::CreateServiceFolderAction:
         deleteLater();
         break;
-    case PimCommon::StorageServiceAbstract::DeleteFile:
+    case PimCommon::StorageServiceAbstract::DeleteFileAction:
         parseDeleteFile(data);
         break;
-    case PimCommon::StorageServiceAbstract::DeleteFolder:
+    case PimCommon::StorageServiceAbstract::DeleteFolderAction:
         parseDeleteFolder(data);
         break;
-    case PimCommon::StorageServiceAbstract::DownLoadFile:
+    case PimCommon::StorageServiceAbstract::DownLoadFileAction:
         parseDownLoadFile(data);
         break;
-    case PimCommon::StorageServiceAbstract::RenameFolder:
+    case PimCommon::StorageServiceAbstract::RenameFolderAction:
         parseRenameFolder(data);
         break;
-    case PimCommon::StorageServiceAbstract::RenameFile:
+    case PimCommon::StorageServiceAbstract::RenameFileAction:
         parseRenameFile(data);
         break;
-    case PimCommon::StorageServiceAbstract::MoveFolder:
+    case PimCommon::StorageServiceAbstract::MoveFolderAction:
         parseMoveFolder(data);
         break;
-    case PimCommon::StorageServiceAbstract::MoveFile:
+    case PimCommon::StorageServiceAbstract::MoveFileAction:
         parseMoveFile(data);
         break;
-    case PimCommon::StorageServiceAbstract::CopyFile:
+    case PimCommon::StorageServiceAbstract::CopyFileAction:
         parseCopyFile(data);
         break;
-    case PimCommon::StorageServiceAbstract::CopyFolder:
+    case PimCommon::StorageServiceAbstract::CopyFolderAction:
         parseCopyFolder(data);
         break;
     }
@@ -386,7 +386,7 @@ void DropBoxJob::createFolderJob(const QString &foldername, const QString &desti
 
 void DropBoxJob::createFolder(const QString &foldername, const QString &destination)
 {
-    mActionType = PimCommon::StorageServiceAbstract::CreateFolder;
+    mActionType = PimCommon::StorageServiceAbstract::CreateFolderAction;
     mError = false;
     createFolderJob(foldername, destination);
 }
@@ -395,7 +395,7 @@ QNetworkReply *DropBoxJob::uploadFile(const QString &filename, const QString &up
 {
     QFile *file = new QFile(filename);
     if (file->exists()) {
-        mActionType = PimCommon::StorageServiceAbstract::UploadFile;
+        mActionType = PimCommon::StorageServiceAbstract::UploadFileAction;
         mError = false;
         if (file->open(QIODevice::ReadOnly)) {
             const QString defaultDestination = (destination.isEmpty() ? PimCommon::StorageServiceJobConfig::self()->defaultUploadFolder() : destination);
@@ -417,7 +417,7 @@ QNetworkReply *DropBoxJob::uploadFile(const QString &filename, const QString &up
 
 void DropBoxJob::accountInfo()
 {
-    mActionType = PimCommon::StorageServiceAbstract::AccountInfo;
+    mActionType = PimCommon::StorageServiceAbstract::AccountInfoAction;
     mError = false;
     QUrl url(mApiPath + QLatin1String("account/info"));
     addDefaultUrlItem(url);
@@ -430,7 +430,7 @@ void DropBoxJob::accountInfo()
 
 void DropBoxJob::listFolder(const QString &folder)
 {
-    mActionType = PimCommon::StorageServiceAbstract::ListFolder;
+    mActionType = PimCommon::StorageServiceAbstract::ListFolderAction;
     mError = false;
     QUrl url(mApiPath + QLatin1String("metadata/dropbox/") + folder);
     addDefaultUrlItem(url);
@@ -465,7 +465,7 @@ void DropBoxJob::parseUploadFile(const QString &data)
 
 void DropBoxJob::shareLink(const QString &root, const QString &path)
 {
-    mActionType = PimCommon::StorageServiceAbstract::ShareLink;
+    mActionType = PimCommon::StorageServiceAbstract::ShareLinkAction;
     mError = false;
 
     QUrl url = QUrl(mApiPath + QString::fromLatin1("shares/%1/%2").arg(root).arg(path));
@@ -479,7 +479,7 @@ void DropBoxJob::shareLink(const QString &root, const QString &path)
 
 void DropBoxJob::createServiceFolder()
 {
-    mActionType = PimCommon::StorageServiceAbstract::CreateServiceFolder;
+    mActionType = PimCommon::StorageServiceAbstract::CreateServiceFolderAction;
     mError = false;
     createFolderJob(PimCommon::StorageServiceJobConfig::self()->defaultUploadFolder(), QString());
 }
@@ -487,7 +487,7 @@ void DropBoxJob::createServiceFolder()
 QNetworkReply *DropBoxJob::downloadFile(const QString &name, const QString &fileId, const QString &destination)
 {
     Q_UNUSED(fileId);
-    mActionType = PimCommon::StorageServiceAbstract::DownLoadFile;
+    mActionType = PimCommon::StorageServiceAbstract::DownLoadFileAction;
     mError = false;
     const QString defaultDestination = (destination.isEmpty() ? PimCommon::StorageServiceJobConfig::self()->defaultUploadFolder() : destination);
     delete mDownloadFile;
@@ -512,7 +512,7 @@ QNetworkReply *DropBoxJob::downloadFile(const QString &name, const QString &file
 
 void DropBoxJob::deleteFile(const QString &filename)
 {
-    mActionType = PimCommon::StorageServiceAbstract::DeleteFile;
+    mActionType = PimCommon::StorageServiceAbstract::DeleteFileAction;
     mError = false;
     QUrl url = QUrl(mApiPath + QLatin1String("fileops/delete"));
     url.addQueryItem(QLatin1String("root"), mRootPath);
@@ -525,7 +525,7 @@ void DropBoxJob::deleteFile(const QString &filename)
 
 void DropBoxJob::deleteFolder(const QString &foldername)
 {
-    mActionType = PimCommon::StorageServiceAbstract::DeleteFolder;
+    mActionType = PimCommon::StorageServiceAbstract::DeleteFolderAction;
     mError = false;
     QUrl url = QUrl(mApiPath + QLatin1String("fileops/delete"));
     url.addQueryItem(QLatin1String("root"), mRootPath);
@@ -538,7 +538,7 @@ void DropBoxJob::deleteFolder(const QString &foldername)
 
 void DropBoxJob::renameFolder(const QString &source, const QString &destination)
 {
-    mActionType = PimCommon::StorageServiceAbstract::RenameFolder;
+    mActionType = PimCommon::StorageServiceAbstract::RenameFolderAction;
     mError = false;
     QUrl url = QUrl(mApiPath + QLatin1String("fileops/move"));
     url.addQueryItem(QLatin1String("root"), mRootPath);
@@ -568,7 +568,7 @@ void DropBoxJob::renameFolder(const QString &source, const QString &destination)
 
 void DropBoxJob::renameFile(const QString &oldName, const QString &newName)
 {
-    mActionType = PimCommon::StorageServiceAbstract::RenameFile;
+    mActionType = PimCommon::StorageServiceAbstract::RenameFileAction;
     mError = false;
     QUrl url = QUrl(mApiPath + QLatin1String("fileops/move"));
     url.addQueryItem(QLatin1String("root"), mRootPath);
@@ -600,7 +600,7 @@ void DropBoxJob::renameFile(const QString &oldName, const QString &newName)
 
 void DropBoxJob::moveFolder(const QString &source, const QString &destination)
 {
-    mActionType = PimCommon::StorageServiceAbstract::MoveFolder;
+    mActionType = PimCommon::StorageServiceAbstract::MoveFolderAction;
     mError = false;
     QUrl url = QUrl(mApiPath + QLatin1String("fileops/move"));
     url.addQueryItem(QLatin1String("root"), mRootPath);
@@ -615,7 +615,7 @@ void DropBoxJob::moveFolder(const QString &source, const QString &destination)
 
 void DropBoxJob::moveFile(const QString &source, const QString &destination)
 {
-    mActionType = PimCommon::StorageServiceAbstract::MoveFile;
+    mActionType = PimCommon::StorageServiceAbstract::MoveFileAction;
     mError = false;
     QUrl url = QUrl(mApiPath + QLatin1String("fileops/move"));
     url.addQueryItem(QLatin1String("root"), mRootPath);
@@ -630,7 +630,7 @@ void DropBoxJob::moveFile(const QString &source, const QString &destination)
 
 void DropBoxJob::copyFile(const QString &source, const QString &destination)
 {
-    mActionType = PimCommon::StorageServiceAbstract::CopyFile;
+    mActionType = PimCommon::StorageServiceAbstract::CopyFileAction;
     mError = false;
     QUrl url = QUrl(mApiPath + QLatin1String("fileops/copy"));
     url.addQueryItem(QLatin1String("root"), mRootPath);
@@ -645,7 +645,7 @@ void DropBoxJob::copyFile(const QString &source, const QString &destination)
 
 void DropBoxJob::copyFolder(const QString &source, const QString &destination)
 {
-    mActionType = PimCommon::StorageServiceAbstract::CopyFolder;
+    mActionType = PimCommon::StorageServiceAbstract::CopyFolderAction;
     mError = false;
     QUrl url = QUrl(mApiPath + QLatin1String("fileops/copy"));
     url.addQueryItem(QLatin1String("root"), mRootPath);
