@@ -115,7 +115,7 @@ bool DropBoxStorageService::checkNeedAuthenticate()
 void DropBoxStorageService::storageServiceShareLink(const QString &root, const QString &path)
 {
     if (checkNeedAuthenticate()) {
-        mNextAction->setNextActionType(ShareLink);
+        mNextAction->setNextActionType(ShareLinkAction);
         mNextAction->setRootPath(root);
         mNextAction->setPath(path);
         storageServiceauthentication();
@@ -131,7 +131,7 @@ void DropBoxStorageService::storageServiceShareLink(const QString &root, const Q
 void DropBoxStorageService::storageServicecreateServiceFolder()
 {
     if (checkNeedAuthenticate()) {
-        mNextAction->setNextActionType(CreateServiceFolder);
+        mNextAction->setNextActionType(CreateServiceFolderAction);
         storageServiceauthentication();
     } else {
         DropBoxJob *job = new DropBoxJob(this);
@@ -166,7 +166,7 @@ void DropBoxStorageService::slotAuthorizationDone(const QString &accessToken, co
 void DropBoxStorageService::storageServicelistFolder(const QString &folder)
 {
     if (checkNeedAuthenticate()) {
-        mNextAction->setNextActionType(ListFolder);
+        mNextAction->setNextActionType(ListFolderAction);
         mNextAction->setNextActionFolder(folder);
         storageServiceauthentication();
     } else {
@@ -181,7 +181,7 @@ void DropBoxStorageService::storageServicelistFolder(const QString &folder)
 void DropBoxStorageService::storageServiceaccountInfo()
 {
     if (checkNeedAuthenticate()) {
-        mNextAction->setNextActionType(AccountInfo);
+        mNextAction->setNextActionType(AccountInfoAction);
         storageServiceauthentication();
     } else {
         DropBoxJob *job = new DropBoxJob(this);
@@ -195,7 +195,7 @@ void DropBoxStorageService::storageServiceaccountInfo()
 void DropBoxStorageService::storageServicecreateFolder(const QString &name, const QString &destination)
 {
     if (checkNeedAuthenticate()) {
-        mNextAction->setNextActionType(CreateFolder);
+        mNextAction->setNextActionType(CreateFolderAction);
         mNextAction->setNextActionName(name);
         mNextAction->setNextActionFolder(destination);
         storageServiceauthentication();
@@ -211,7 +211,7 @@ void DropBoxStorageService::storageServicecreateFolder(const QString &name, cons
 void DropBoxStorageService::storageServiceuploadFile(const QString &filename, const QString &uploadAsName, const QString &destination)
 {
     if (checkNeedAuthenticate()) {
-        mNextAction->setNextActionType(UploadFile);
+        mNextAction->setNextActionType(UploadFileAction);
         mNextAction->setNextActionName(filename);
         mNextAction->setNextActionFolder(destination);
         mNextAction->setUploadAsName(uploadAsName);
@@ -291,7 +291,7 @@ QString DropBoxStorageService::storageServiceName() const
 void DropBoxStorageService::storageServicedownloadFile(const QString &name, const QString &fileId, const QString &destination)
 {
     if (checkNeedAuthenticate()) {
-        mNextAction->setNextActionType(DownLoadFile);
+        mNextAction->setNextActionType(DownLoadFileAction);
         mNextAction->setNextActionName(name);
         mNextAction->setDownloadDestination(destination);
         mNextAction->setFileId(fileId);
@@ -310,7 +310,7 @@ void DropBoxStorageService::storageServicedownloadFile(const QString &name, cons
 void DropBoxStorageService::storageServicedeleteFile(const QString &filename)
 {
     if (checkNeedAuthenticate()) {
-        mNextAction->setNextActionType(DeleteFile);
+        mNextAction->setNextActionType(DeleteFileAction);
         mNextAction->setNextActionName(filename);
         storageServiceauthentication();
     } else {
@@ -325,7 +325,7 @@ void DropBoxStorageService::storageServicedeleteFile(const QString &filename)
 void DropBoxStorageService::storageServicedeleteFolder(const QString &foldername)
 {
     if (checkNeedAuthenticate()) {
-        mNextAction->setNextActionType(DeleteFolder);
+        mNextAction->setNextActionType(DeleteFolderAction);
         mNextAction->setNextActionFolder(foldername);
         storageServiceauthentication();
     } else {
@@ -340,7 +340,7 @@ void DropBoxStorageService::storageServicedeleteFolder(const QString &foldername
 void DropBoxStorageService::storageServiceRenameFolder(const QString &source, const QString &destination)
 {
     if (checkNeedAuthenticate()) {
-        mNextAction->setNextActionType(RenameFolder);
+        mNextAction->setNextActionType(RenameFolderAction);
         mNextAction->setRenameFolder(source, destination);
         storageServiceauthentication();
     } else {
@@ -355,7 +355,7 @@ void DropBoxStorageService::storageServiceRenameFolder(const QString &source, co
 void DropBoxStorageService::storageServiceRenameFile(const QString &source, const QString &destination)
 {
     if (checkNeedAuthenticate()) {
-        mNextAction->setNextActionType(RenameFile);
+        mNextAction->setNextActionType(RenameFileAction);
         mNextAction->setRenameFolder(source, destination);
         storageServiceauthentication();
     } else {
@@ -370,7 +370,7 @@ void DropBoxStorageService::storageServiceRenameFile(const QString &source, cons
 void DropBoxStorageService::storageServiceMoveFolder(const QString &source, const QString &destination)
 {
     if (checkNeedAuthenticate()) {
-        mNextAction->setNextActionType(MoveFolder);
+        mNextAction->setNextActionType(MoveFolderAction);
         mNextAction->setRenameFolder(source, destination);
         storageServiceauthentication();
     } else {
@@ -385,7 +385,7 @@ void DropBoxStorageService::storageServiceMoveFolder(const QString &source, cons
 void DropBoxStorageService::storageServiceMoveFile(const QString &source, const QString &destination)
 {
     if (checkNeedAuthenticate()) {
-        mNextAction->setNextActionType(RenameFolder);
+        mNextAction->setNextActionType(RenameFolderAction);
         mNextAction->setRenameFolder(source, destination);
         storageServiceauthentication();
     } else {
@@ -400,7 +400,7 @@ void DropBoxStorageService::storageServiceMoveFile(const QString &source, const
 void DropBoxStorageService::storageServiceCopyFile(const QString &source, const QString &destination)
 {
     if (checkNeedAuthenticate()) {
-        mNextAction->setNextActionType(CopyFile);
+        mNextAction->setNextActionType(CopyFileAction);
         mNextAction->setRenameFolder(source, destination);
         storageServiceauthentication();
     } else {
@@ -415,7 +415,7 @@ void DropBoxStorageService::storageServiceCopyFile(const QString &source, const
 void DropBoxStorageService::storageServiceCopyFolder(const QString &source, const QString &destination)
 {
     if (checkNeedAuthenticate()) {
-        mNextAction->setNextActionType(CopyFolder);
+        mNextAction->setNextActionType(CopyFolderAction);
         mNextAction->setRenameFolder(source, destination);
         storageServiceauthentication();
     } else {
