@@ -59,7 +59,7 @@ void HubicJob::initializeToken(const QString &refreshToken, const QString &token
 
 void HubicJob::createServiceFolder()
 {
-    mActionType = PimCommon::StorageServiceAbstract::CreateServiceFolder;
+    mActionType = PimCommon::StorageServiceAbstract::CreateServiceFolderAction;
     mError = false;
     //TODO
     Q_EMIT actionFailed(QLatin1String("Not Implemented"));
@@ -70,7 +70,7 @@ void HubicJob::createServiceFolder()
 void HubicJob::requestTokenAccess()
 {
     mError = false;
-    mActionType = PimCommon::StorageServiceAbstract::RequestToken;
+    mActionType = PimCommon::StorageServiceAbstract::RequestTokenAction;
     QUrl url(mServiceUrl + mAuthorizePath );
     url.addQueryItem(QLatin1String("response_type"), QLatin1String("code"));
     url.addQueryItem(QLatin1String("client_id"), mClientId);
@@ -130,7 +130,7 @@ void HubicJob::parseRedirectUrl(const QUrl &url)
 
 void HubicJob::getTokenAccess(const QString &authorizeCode)
 {
-    mActionType = PimCommon::StorageServiceAbstract::AccessToken;
+    mActionType = PimCommon::StorageServiceAbstract::AccessTokenAction;
     mError = false;
     QNetworkRequest request(QUrl(mServiceUrl + mPathToken));
     request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
@@ -162,37 +162,37 @@ void HubicJob::slotSendDataFinished(QNetworkReply *reply)
             case PimCommon::StorageServiceAbstract::NoneAction:
                 deleteLater();
                 break;
-            case PimCommon::StorageServiceAbstract::RequestToken:
+            case PimCommon::StorageServiceAbstract::RequestTokenAction:
                 Q_EMIT authorizationFailed(errorStr);
                 deleteLater();
                 break;
-            case PimCommon::StorageServiceAbstract::AccessToken:
+            case PimCommon::StorageServiceAbstract::AccessTokenAction:
                 Q_EMIT authorizationFailed(errorStr);
                 deleteLater();
                 break;
-            case PimCommon::StorageServiceAbstract::UploadFile:
+            case PimCommon::StorageServiceAbstract::UploadFileAction:
                 Q_EMIT uploadFileFailed(errorStr);
                 errorMessage(mActionType, errorStr);
                 deleteLater();
                 break;
-            case PimCommon::StorageServiceAbstract::DownLoadFile:
+            case PimCommon::StorageServiceAbstract::DownLoadFileAction:
                 Q_EMIT downLoadFileFailed(errorStr);
                 errorMessage(mActionType, errorStr);
                 deleteLater();
                 break;
-            case PimCommon::StorageServiceAbstract::DeleteFile:
-            case PimCommon::StorageServiceAbstract::CreateFolder:
-            case PimCommon::StorageServiceAbstract::AccountInfo:
-            case PimCommon::StorageServiceAbstract::ListFolder:
-            case PimCommon::StorageServiceAbstract::CreateServiceFolder:
-            case PimCommon::StorageServiceAbstract::DeleteFolder:
-            case PimCommon::StorageServiceAbstract::RenameFolder:
-            case PimCommon::StorageServiceAbstract::RenameFile:
-            case PimCommon::StorageServiceAbstract::MoveFolder:
-            case PimCommon::StorageServiceAbstract::MoveFile:
-            case PimCommon::StorageServiceAbstract::CopyFile:
-            case PimCommon::StorageServiceAbstract::CopyFolder:
-            case PimCommon::StorageServiceAbstract::ShareLink:
+            case PimCommon::StorageServiceAbstract::DeleteFileAction:
+            case PimCommon::StorageServiceAbstract::CreateFolderAction:
+            case PimCommon::StorageServiceAbstract::AccountInfoAction:
+            case PimCommon::StorageServiceAbstract::ListFolderAction:
+            case PimCommon::StorageServiceAbstract::CreateServiceFolderAction:
+            case PimCommon::StorageServiceAbstract::DeleteFolderAction:
+            case PimCommon::StorageServiceAbstract::RenameFolderAction:
+            case PimCommon::StorageServiceAbstract::RenameFileAction:
+            case PimCommon::StorageServiceAbstract::MoveFolderAction:
+            case PimCommon::StorageServiceAbstract::MoveFileAction:
+            case PimCommon::StorageServiceAbstract::CopyFileAction:
+            case PimCommon::StorageServiceAbstract::CopyFolderAction:
+            case PimCommon::StorageServiceAbstract::ShareLinkAction:
                 errorMessage(mActionType, errorStr);
                 deleteLater();
                 break;
@@ -212,55 +212,55 @@ void HubicJob::slotSendDataFinished(QNetworkReply *reply)
     case PimCommon::StorageServiceAbstract::NoneAction:
         deleteLater();
         break;
-    case PimCommon::StorageServiceAbstract::RequestToken:
+    case PimCommon::StorageServiceAbstract::RequestTokenAction:
         deleteLater();
         break;
-    case PimCommon::StorageServiceAbstract::AccessToken:
+    case PimCommon::StorageServiceAbstract::AccessTokenAction:
         parseAccessToken(data);
         break;
-    case PimCommon::StorageServiceAbstract::UploadFile:
+    case PimCommon::StorageServiceAbstract::UploadFileAction:
         parseUploadFile(data);
         break;
-    case PimCommon::StorageServiceAbstract::CreateFolder:
+    case PimCommon::StorageServiceAbstract::CreateFolderAction:
         parseCreateFolder(data);
         break;
-    case PimCommon::StorageServiceAbstract::AccountInfo:
+    case PimCommon::StorageServiceAbstract::AccountInfoAction:
         parseAccountInfo(data);
         break;
-    case PimCommon::StorageServiceAbstract::ListFolder:
+    case PimCommon::StorageServiceAbstract::ListFolderAction:
         parseListFolder(data);
         break;
-    case PimCommon::StorageServiceAbstract::CreateServiceFolder:
+    case PimCommon::StorageServiceAbstract::CreateServiceFolderAction:
         parseCreateServiceFolder(data);
         break;
-    case PimCommon::StorageServiceAbstract::DeleteFile:
+    case PimCommon::StorageServiceAbstract::DeleteFileAction:
         parseDeleteFile(data);
         break;
-    case PimCommon::StorageServiceAbstract::DeleteFolder:
+    case PimCommon::StorageServiceAbstract::DeleteFolderAction:
         parseDeleteFolder(data);
         break;
-    case PimCommon::StorageServiceAbstract::CopyFile:
+    case PimCommon::StorageServiceAbstract::CopyFileAction:
         parseCopyFile(data);
         break;
-    case PimCommon::StorageServiceAbstract::CopyFolder:
+    case PimCommon::StorageServiceAbstract::CopyFolderAction:
         parseCopyFolder(data);
         break;
-    case PimCommon::StorageServiceAbstract::RenameFile:
+    case PimCommon::StorageServiceAbstract::RenameFileAction:
         parseRenameFile(data);
         break;
-    case PimCommon::StorageServiceAbstract::RenameFolder:
+    case PimCommon::StorageServiceAbstract::RenameFolderAction:
         parseRenameFolder(data);
         break;
-    case PimCommon::StorageServiceAbstract::MoveFolder:
+    case PimCommon::StorageServiceAbstract::MoveFolderAction:
         parseMoveFolder(data);
         break;
-    case PimCommon::StorageServiceAbstract::MoveFile:
+    case PimCommon::StorageServiceAbstract::MoveFileAction:
         parseMoveFile(data);
         break;
-    case PimCommon::StorageServiceAbstract::ShareLink:
+    case PimCommon::StorageServiceAbstract::ShareLinkAction:
         parseShareLink(data);
         break;
-    case PimCommon::StorageServiceAbstract::DownLoadFile:
+    case PimCommon::StorageServiceAbstract::DownLoadFileAction:
         parseDownloadFile(data);
         break;
     }
@@ -287,7 +287,7 @@ void HubicJob::parseAccountInfo(const QString &data)
 
 void HubicJob::refreshToken()
 {
-    mActionType = PimCommon::StorageServiceAbstract::AccessToken;
+    mActionType = PimCommon::StorageServiceAbstract::AccessTokenAction;
     QNetworkRequest request(QUrl(QLatin1String("https://api.hubic.com/oauth/token/")));
     request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
     QUrl postData;
@@ -304,49 +304,49 @@ void HubicJob::refreshToken()
 
 void HubicJob::deleteFile(const QString &filename)
 {
-    mActionType = PimCommon::StorageServiceAbstract::DeleteFile;
+    mActionType = PimCommon::StorageServiceAbstract::DeleteFileAction;
     mError = false;
 }
 
 void HubicJob::deleteFolder(const QString &foldername)
 {
-    mActionType = PimCommon::StorageServiceAbstract::DeleteFolder;
+    mActionType = PimCommon::StorageServiceAbstract::DeleteFolderAction;
     mError = false;
 }
 
 void HubicJob::renameFolder(const QString &source, const QString &destination)
 {
-    mActionType = PimCommon::StorageServiceAbstract::RenameFolder;
+    mActionType = PimCommon::StorageServiceAbstract::RenameFolderAction;
     mError = false;
 }
 
 void HubicJob::renameFile(const QString &oldName, const QString &newName)
 {
-    mActionType = PimCommon::StorageServiceAbstract::RenameFile;
+    mActionType = PimCommon::StorageServiceAbstract::RenameFileAction;
     mError = false;
 }
 
 void HubicJob::moveFolder(const QString &source, const QString &destination)
 {
-    mActionType = PimCommon::StorageServiceAbstract::MoveFolder;
+    mActionType = PimCommon::StorageServiceAbstract::MoveFolderAction;
     mError = false;
 }
 
 void HubicJob::moveFile(const QString &source, const QString &destination)
 {
-    mActionType = PimCommon::StorageServiceAbstract::MoveFile;
+    mActionType = PimCommon::StorageServiceAbstract::MoveFileAction;
     mError = false;
 }
 
 void HubicJob::copyFile(const QString &source, const QString &destination)
 {
-    mActionType = PimCommon::StorageServiceAbstract::CopyFile;
+    mActionType = PimCommon::StorageServiceAbstract::CopyFileAction;
     mError = false;
 }
 
 void HubicJob::copyFolder(const QString &source, const QString &destination)
 {
-    mActionType = PimCommon::StorageServiceAbstract::CopyFolder;
+    mActionType = PimCommon::StorageServiceAbstract::CopyFolderAction;
     mError = false;
 }
 
@@ -354,7 +354,7 @@ QNetworkReply *HubicJob::uploadFile(const QString &filename, const QString &uplo
 {
     QFile *file = new QFile(filename);
     if (file->exists()) {
-        mActionType = PimCommon::StorageServiceAbstract::UploadFile;
+        mActionType = PimCommon::StorageServiceAbstract::UploadFileAction;
         mError = false;
         if (file->open(QIODevice::ReadOnly)) {
 #if 0
@@ -381,7 +381,7 @@ QNetworkReply *HubicJob::uploadFile(const QString &filename, const QString &uplo
 
 void HubicJob::listFolder(const QString &folder)
 {
-    mActionType = PimCommon::StorageServiceAbstract::ListFolder;
+    mActionType = PimCommon::StorageServiceAbstract::ListFolderAction;
     mError = false;
     QUrl url;
     url.setUrl(mApiUrl + mSwiftTokenPath);
@@ -405,7 +405,7 @@ void HubicJob::listFolder(const QString &folder)
 
 void HubicJob::accountInfo()
 {
-    mActionType = PimCommon::StorageServiceAbstract::AccountInfo;
+    mActionType = PimCommon::StorageServiceAbstract::AccountInfoAction;
     mError = false;
     QUrl url;
     url.setUrl(mApiUrl + mCurrentAccountInfoPath);
@@ -418,7 +418,7 @@ void HubicJob::accountInfo()
 
 void HubicJob::createFolder(const QString &foldername, const QString &destination)
 {
-    mActionType = PimCommon::StorageServiceAbstract::CreateFolder;
+    mActionType = PimCommon::StorageServiceAbstract::CreateFolderAction;
     mError = false;
 }
 
@@ -426,7 +426,7 @@ void HubicJob::createFolder(const QString &foldername, const QString &destinatio
 void HubicJob::shareLink(const QString &root, const QString &fileId)
 {
     Q_UNUSED(root);
-    mActionType = PimCommon::StorageServiceAbstract::ShareLink;
+    mActionType = PimCommon::StorageServiceAbstract::ShareLinkAction;
     mError = false;
 }
 
@@ -569,7 +569,7 @@ void HubicJob::parseDownloadFile(const QString &data)
 
 QNetworkReply * HubicJob::downloadFile(const QString &name, const QString &fileId, const QString &destination)
 {
-    mActionType = PimCommon::StorageServiceAbstract::DownLoadFile;
+    mActionType = PimCommon::StorageServiceAbstract::DownLoadFileAction;
     mError = false;
 #if 0
     mActionType = PimCommon::StorageServiceAbstract::DownLoadFile;
