@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -43,6 +43,10 @@ public:
     virtual bool addNewTemplate(QString &templateName, QString &templateScript);
     virtual bool modifyTemplate(QString &templateName, QString &templateScript, bool defaultTemplate);
 
+    void setKNewStuffConfigFile(const QString &configName);
+
+    void addDefaultTemplate(const QString &templateName, const QString &templateScript);
+
 protected:
     QStringList mimeTypes() const;
     QMimeData *mimeData( const QList<QListWidgetItem *> items ) const;
@@ -52,6 +56,7 @@ protected:
 Q_SIGNALS:
     void insertTemplate(const QString &);
     void insertNewTemplate(const QString &);
+
 private:
     friend class TemplateListWidgetPrivate;
     TemplateListWidgetPrivate * const d;
@@ -64,6 +69,7 @@ private:
     Q_PRIVATE_SLOT( d, void slotExportTemplates() )
     Q_PRIVATE_SLOT( d, void slotImportTemplates() )
     Q_PRIVATE_SLOT( d, void slotDuplicate() )
+    Q_PRIVATE_SLOT( d, void slotDownloadTemplates() )
     enum TemplateData {
         Text = Qt::UserRole + 1,
         DefaultTemplate = Qt::UserRole + 2
