@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,7 +17,7 @@
 
 #include "plaintexteditor.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <KGlobalSettings>
 #include <KIconTheme>
 #include <KStandardGuiItem>
@@ -125,16 +125,17 @@ void PlainTextEditor::contextMenuEvent( QContextMenuEvent *event )
         speakAction->setIcon(KIcon(QLatin1String("preferences-desktop-text-to-speech")));
         speakAction->setEnabled(!emptyDocument );
         connect( speakAction, SIGNAL(triggered(bool)), this, SLOT(slotSpeakText()) );
-        addExtraMenuEntry(popup);
+        addExtraMenuEntry(popup, event->pos());
         popup->exec( event->globalPos() );
 
         delete popup;
     }
 }
 
-void PlainTextEditor::addExtraMenuEntry(QMenu *menu)
+void PlainTextEditor::addExtraMenuEntry(QMenu *menu, const QPoint &pos)
 {
     Q_UNUSED(menu);
+    Q_UNUSED(pos);
 }
 
 void PlainTextEditor::slotSpeakText()
@@ -398,10 +399,12 @@ bool PlainTextEditor::handleShortcut(const QKeyEvent* event)
             redo();
         return true;
     } else if ( KStandardShortcut::deleteWordBack().contains( key ) ) {
-        deleteWordBack();
+        if (!isReadOnly())
+            deleteWordBack();
         return true;
     } else if ( KStandardShortcut::deleteWordForward().contains( key ) ) {
-        deleteWordForward();
+        if (!isReadOnly())
+            deleteWordForward();
         return true;
     } else if ( KStandardShortcut::backwardWord().contains( key ) ) {
         QTextCursor cursor = textCursor();
@@ -470,7 +473,6 @@ bool PlainTextEditor::handleShortcut(const QKeyEvent* event)
         setTextCursor( cursor );
         return true;
     } else if (d->hasSearchSupport && KStandardShortcut::find().contains(key)) {
-        qDebug()<<" findtext *************";
         Q_EMIT findText();
         return true;
     } else if (d->hasSearchSupport && KStandardShortcut::replace().contains(key)) {
@@ -500,4 +502,3 @@ void PlainTextEditor::keyPressEvent( QKeyEvent *event )
     }
 }
 
-#include "plaintexteditor.moc"
