@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,7 +17,7 @@
 
 #include "richtexteditor.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KToolInvocation>
 #include <KAction>
@@ -165,7 +165,7 @@ void RichTextEditor::defaultPopupMenu(const QPoint &pos)
         speakAction->setIcon(KIcon(QLatin1String("preferences-desktop-text-to-speech")));
         speakAction->setEnabled(!emptyDocument );
         connect( speakAction, SIGNAL(triggered(bool)), this, SLOT(slotSpeakText()) );
-        addExtraMenuEntry(popup);
+        addExtraMenuEntry(popup, pos);
         popup->exec( pos );
 
         delete popup;
@@ -211,9 +211,10 @@ void RichTextEditor::setSpellCheckingSupport( bool check )
     d->hasSpellCheckingSupport = check;
 }
 
-void RichTextEditor::addExtraMenuEntry(QMenu *menu)
+void RichTextEditor::addExtraMenuEntry(QMenu *menu, const QPoint &pos)
 {
     Q_UNUSED(menu);
+    Q_UNUSED(pos);
 }
 
 void RichTextEditor::slotUndoableClear()
@@ -579,10 +580,12 @@ bool RichTextEditor::handleShortcut(const QKeyEvent* event)
             redo();
         return true;
     } else if ( KStandardShortcut::deleteWordBack().contains( key ) ) {
-        deleteWordBack();
+        if (!isReadOnly())
+            deleteWordBack();
         return true;
     } else if ( KStandardShortcut::deleteWordForward().contains( key ) ) {
-        deleteWordForward();
+        if (!isReadOnly())
+            deleteWordForward();
         return true;
     } else if ( KStandardShortcut::backwardWord().contains( key ) ) {
         QTextCursor cursor = textCursor();
@@ -733,4 +736,3 @@ void RichTextEditor::keyPressEvent( QKeyEvent *event )
     }
 }
 
-#include "richtexteditor.moc"
