@@ -18,7 +18,7 @@
 #include "createresource.h"
 
 #include <KDebug>
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <akonadi/agenttype.h>
 #include <akonadi/agentmanager.h>
@@ -136,4 +136,3 @@ QString CreateResource::createResource( const QString &resources, const QString
     return QString();
 }
 
-#include "createresource.moc"
