@@ -30,7 +30,7 @@
 #include <kseparator.h>
 #include <KLineEdit>
 #include <KPushButton>
-#include <KLocale>
+#include <KLocalizedString>
 #include <kio/global.h>
 #include <kio/netaccess.h>
 #include <KMessageBox>
@@ -233,5 +233,4 @@ KUrl RenameFileDialog::newName() const
 }
 
 
-#include "renamefiledialog.moc"
 
