@@ -60,7 +60,17 @@ Q_SIGNALS:
     void title(const QString &);
     void endLine();
 
+    void jobFinished();
+
+private Q_SLOTS:
+    void slotAllResourceSynchronized();
+    void slotSynchronizeInstanceDone(const QString &);
+    void slotSynchronizeInstanceFailed(const QString &instance);
+
 protected:
+    void initializeListStep();
+    void startSynchronizeResources(const QStringList &listResourceToSync);
+    virtual void nextStep();
     void infoAboutNewResource(const QString &resourceName);
     void copyToDirectory(const KArchiveEntry *entry, const QString &dest);
     void extractZipFile(const KArchiveFile *file, const QString &source, const QString &destination);
@@ -76,7 +86,7 @@ protected:
     bool overwriteConfigMessageBox(const QString &configName) const;
     Akonadi::Collection::Id convertPathToId(const QString &path);
     void backupResourceFile(const Akonadi::AgentInstance &agent, const QString &defaultPath);
-    void restoreResourceFile(const QString &resourceName, const QString &defaultPath, const QString &storePath, bool overwriteResources = false);
+    QStringList restoreResourceFile(const QString &resourceName, const QString &defaultPath, const QString &storePath, bool overwriteResources = false);
     bool backupFullDirectory(const KUrl &url, const QString &archivePath, const QString &archivename);
     virtual void addSpecificResourceSettings(KSharedConfig::Ptr resourceConfig, const QString &resourceName, QMap<QString, QVariant> &settings);
     void restoreConfigFile(const QString &configNameStr);
@@ -106,6 +116,8 @@ protected:
     int mNumberOfStep;
     PimCommon::CreateResource *mCreateResource;
     QStringList mAgentPaths;
+    QList<Utils::StoredType> mListStep;
+    int mIndex;
     static int sArchiveVersion;
 };
 
