@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
   
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -33,6 +33,9 @@ public:
 
     void start();
 
+protected:
+    void nextStep();
+
 private:
     void searchAllFiles(const KArchiveDirectory *dir,const QString &prefix);
     void storeAddressBookArchiveResource(const KArchiveDirectory *dir, const QString &prefix);
