@@ -21,7 +21,7 @@
 
 #include <Akonadi/AgentManager>
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <KStandardDirs>
 #include <KTemporaryFile>
 #include <KConfigGroup>
@@ -43,12 +43,13 @@ ExportAlarmJob::~ExportAlarmJob()
 
 void ExportAlarmJob::start()
 {
-    Q_EMIT title(i18n("Start export kalarm settings..."));
+    Q_EMIT title(i18n("Start export KAlarm settings..."));
     mArchiveDirectory = archive()->directory();
     if (mTypeSelected & Utils::Resources) {
         backupResources();
         increaseProgressDialog();
         if (wasCanceled()) {
+            Q_EMIT jobFinished();
             return;
         }
     }
@@ -56,9 +57,11 @@ void ExportAlarmJob::start()
         backupConfig();
         increaseProgressDialog();
         if (wasCanceled()) {
+            Q_EMIT jobFinished();
             return;
         }
     }
+    Q_EMIT jobFinished();
 }
 
 
@@ -69,7 +72,7 @@ void ExportAlarmJob::backupResources()
 
     Akonadi::AgentManager *manager = Akonadi::AgentManager::self();
     const Akonadi::AgentInstance::List list = manager->instances();
-    foreach( const Akonadi::AgentInstance &agent, list ) {
+    Q_FOREACH ( const Akonadi::AgentInstance &agent, list ) {
         const QString identifier = agent.identifier();
         if (identifier.contains(QLatin1String("akonadi_kalarm_resource_"))) {
             backupResourceFile(agent, Utils::alarmPath());
@@ -131,4 +134,3 @@ void ExportAlarmJob::backupConfig()
 
 }
 
-#include "exportalarmjob.moc"
